Class: Google::Apis::DisplayvideoV3::AdGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single ad group associated with a line item.
Instance Attribute Summary collapse
-
#ad_group_format ⇒ String
Required.
-
#ad_group_id ⇒ Fixnum
Output only.
-
#ad_group_inventory_control ⇒ Google::Apis::DisplayvideoV3::AdGroupInventoryControl
The inventory control of the ad group.
-
#advertiser_id ⇒ Fixnum
Output only.
-
#bid_strategy ⇒ Google::Apis::DisplayvideoV3::BiddingStrategy
Settings that control the bid strategy.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#line_item_id ⇒ Fixnum
Required.
-
#name ⇒ String
Output only.
-
#product_feed_data ⇒ Google::Apis::DisplayvideoV3::ProductFeedData
The details of product feed.
-
#targeting_expansion ⇒ Google::Apis::DisplayvideoV3::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdGroup
constructor
A new instance of AdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdGroup
Returns a new instance of AdGroup.
140 141 142 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_format ⇒ String
Required. Immutable. The format of the ads in the ad group.
Corresponds to the JSON property adGroupFormat
83 84 85 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 83 def ad_group_format @ad_group_format end |
#ad_group_id ⇒ Fixnum
Output only. The unique ID of the ad group. Assigned by the system.
Corresponds to the JSON property adGroupId
88 89 90 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 88 def ad_group_id @ad_group_id end |
#ad_group_inventory_control ⇒ Google::Apis::DisplayvideoV3::AdGroupInventoryControl
The inventory control of the ad group.
Corresponds to the JSON property adGroupInventoryControl
93 94 95 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 93 def ad_group_inventory_control @ad_group_inventory_control end |
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the ad group belongs to.
Corresponds to the JSON property advertiserId
98 99 100 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 98 def advertiser_id @advertiser_id end |
#bid_strategy ⇒ Google::Apis::DisplayvideoV3::BiddingStrategy
Settings that control the bid strategy. Bid strategy determines the bid price.
Corresponds to the JSON property bidStrategy
103 104 105 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 103 def bid_strategy @bid_strategy end |
#display_name ⇒ String
Required. The display name of the ad group. Must be UTF-8 encoded with a
maximum size of 255 bytes.
Corresponds to the JSON property displayName
109 110 111 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 109 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the ad group can spend its budget and bid on
inventory. If the ad group's parent line item is not active, the ad group can'
t spend its budget even if its own status is ENTITY_STATUS_ACTIVE.
Corresponds to the JSON property entityStatus
116 117 118 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 116 def entity_status @entity_status end |
#line_item_id ⇒ Fixnum
Required. Immutable. The unique ID of the line item that the ad group belongs
to.
Corresponds to the JSON property lineItemId
122 123 124 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 122 def line_item_id @line_item_id end |
#name ⇒ String
Output only. Identifier. The resource name of the ad group.
Corresponds to the JSON property name
127 128 129 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 127 def name @name end |
#product_feed_data ⇒ Google::Apis::DisplayvideoV3::ProductFeedData
The details of product feed.
Corresponds to the JSON property productFeedData
132 133 134 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 132 def product_feed_data @product_feed_data end |
#targeting_expansion ⇒ Google::Apis::DisplayvideoV3::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
Corresponds to the JSON property targetingExpansion
138 139 140 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 138 def targeting_expansion @targeting_expansion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 145 def update!(**args) @ad_group_format = args[:ad_group_format] if args.key?(:ad_group_format) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @ad_group_inventory_control = args[:ad_group_inventory_control] if args.key?(:ad_group_inventory_control) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @line_item_id = args[:line_item_id] if args.key?(:line_item_id) @name = args[:name] if args.key?(:name) @product_feed_data = args[:product_feed_data] if args.key?(:product_feed_data) @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion) end |