Class: Google::Apis::DisplayvideoV3::AdGroupAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single ad associated with an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdGroupAd

Returns a new instance of AdGroupAd.



270
271
272
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_ad_idFixnum

Output only. The unique ID of the ad. Assigned by the system. Corresponds to the JSON property adGroupAdId

Returns:

  • (Fixnum)


167
168
169
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 167

def ad_group_ad_id
  @ad_group_ad_id
end

#ad_group_idFixnum

Required. Immutable. The unique ID of the ad group that the ad belongs to. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


172
173
174
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 172

def ad_group_id
  @ad_group_id
end

#ad_policyGoogle::Apis::DisplayvideoV3::AdPolicy

A single ad policy associated with an ad group ad. Corresponds to the JSON property adPolicy



177
178
179
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 177

def ad_policy
  @ad_policy
end

#ad_urlsArray<Google::Apis::DisplayvideoV3::AdUrl>

Output only. List of URLs used by the ad. Corresponds to the JSON property adUrls



182
183
184
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 182

def ad_urls
  @ad_urls
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser the ad belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


187
188
189
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 187

def advertiser_id
  @advertiser_id
end

#audio_adGoogle::Apis::DisplayvideoV3::AudioAd

Details for an audio ad. Corresponds to the JSON property audioAd



192
193
194
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 192

def audio_ad
  @audio_ad
end

#bumper_adGoogle::Apis::DisplayvideoV3::BumperAd

Details for a bumper ad. Corresponds to the JSON property bumperAd



197
198
199
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 197

def bumper_ad
  @bumper_ad
end

#dcm_tracking_infoGoogle::Apis::DisplayvideoV3::DcmTrackingInfo

Details on the DCM tracking. Corresponds to the JSON property dcmTrackingInfo



202
203
204
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 202

def dcm_tracking_info
  @dcm_tracking_info
end

Details for a Demand Gen carousel ad. Corresponds to the JSON property demandGenCarouselAd



207
208
209
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 207

def demand_gen_carousel_ad
  @demand_gen_carousel_ad
end

#demand_gen_image_adGoogle::Apis::DisplayvideoV3::DemandGenImageAd

Details for a Demand Gen image ad. Corresponds to the JSON property demandGenImageAd



212
213
214
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 212

def demand_gen_image_ad
  @demand_gen_image_ad
end

#demand_gen_product_adGoogle::Apis::DisplayvideoV3::DemandGenProductAd

Details for a Demand Gen product ad. Corresponds to the JSON property demandGenProductAd



217
218
219
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 217

def demand_gen_product_ad
  @demand_gen_product_ad
end

#demand_gen_video_adGoogle::Apis::DisplayvideoV3::DemandGenVideoAd

Details for a Demand Gen video ad. Corresponds to the JSON property demandGenVideoAd



222
223
224
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 222

def demand_gen_video_ad
  @demand_gen_video_ad
end

#display_nameString

Required. The display name of the ad. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


228
229
230
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 228

def display_name
  @display_name
end

#display_video_source_adGoogle::Apis::DisplayvideoV3::DisplayVideoSourceAd

The ad sourced from a DV360 creative. Corresponds to the JSON property displayVideoSourceAd



233
234
235
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 233

def display_video_source_ad
  @display_video_source_ad
end

#entity_statusString

Required. The entity status of the ad. Corresponds to the JSON property entityStatus

Returns:

  • (String)


238
239
240
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 238

def entity_status
  @entity_status
end

#in_stream_adGoogle::Apis::DisplayvideoV3::InStreamAd

Details for an in-stream ad. Corresponds to the JSON property inStreamAd



243
244
245
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 243

def in_stream_ad
  @in_stream_ad
end

#masthead_adGoogle::Apis::DisplayvideoV3::MastheadAd

Details for a Masthead Ad. Corresponds to the JSON property mastheadAd



248
249
250
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 248

def masthead_ad
  @masthead_ad
end

#nameString

Output only. The resource name of the ad. Corresponds to the JSON property name

Returns:

  • (String)


253
254
255
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 253

def name
  @name
end

#non_skippable_adGoogle::Apis::DisplayvideoV3::NonSkippableAd

Details for a non-skippable ad. Corresponds to the JSON property nonSkippableAd



258
259
260
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 258

def non_skippable_ad
  @non_skippable_ad
end

#video_discover_adGoogle::Apis::DisplayvideoV3::VideoDiscoveryAd

Details for a video discovery ad. Corresponds to the JSON property videoDiscoverAd



263
264
265
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 263

def video_discover_ad
  @video_discover_ad
end

#video_performance_adGoogle::Apis::DisplayvideoV3::VideoPerformanceAd

Details for a video performance ad. Corresponds to the JSON property videoPerformanceAd



268
269
270
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 268

def video_performance_ad
  @video_performance_ad
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 275

def update!(**args)
  @ad_group_ad_id = args[:ad_group_ad_id] if args.key?(:ad_group_ad_id)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @ad_policy = args[:ad_policy] if args.key?(:ad_policy)
  @ad_urls = args[:ad_urls] if args.key?(:ad_urls)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @audio_ad = args[:audio_ad] if args.key?(:audio_ad)
  @bumper_ad = args[:bumper_ad] if args.key?(:bumper_ad)
  @dcm_tracking_info = args[:dcm_tracking_info] if args.key?(:dcm_tracking_info)
  @demand_gen_carousel_ad = args[:demand_gen_carousel_ad] if args.key?(:demand_gen_carousel_ad)
  @demand_gen_image_ad = args[:demand_gen_image_ad] if args.key?(:demand_gen_image_ad)
  @demand_gen_product_ad = args[:demand_gen_product_ad] if args.key?(:demand_gen_product_ad)
  @demand_gen_video_ad = args[:demand_gen_video_ad] if args.key?(:demand_gen_video_ad)
  @display_name = args[:display_name] if args.key?(:display_name)
  @display_video_source_ad = args[:display_video_source_ad] if args.key?(:display_video_source_ad)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @in_stream_ad = args[:in_stream_ad] if args.key?(:in_stream_ad)
  @masthead_ad = args[:masthead_ad] if args.key?(:masthead_ad)
  @name = args[:name] if args.key?(:name)
  @non_skippable_ad = args[:non_skippable_ad] if args.key?(:non_skippable_ad)
  @video_discover_ad = args[:video_discover_ad] if args.key?(:video_discover_ad)
  @video_performance_ad = args[:video_performance_ad] if args.key?(:video_performance_ad)
end