Class: Google::Apis::DisplayvideoV3::AdPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single ad policy associated with an ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicy

Returns a new instance of AdPolicy.



374
375
376
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_policy_approval_statusString

The policy approval status of an ad, indicating the approval decision. Corresponds to the JSON property adPolicyApprovalStatus

Returns:

  • (String)


359
360
361
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 359

def ad_policy_approval_status
  @ad_policy_approval_status
end

#ad_policy_review_statusString

The policy review status of an ad, indicating where in the review process the ad is currently. Corresponds to the JSON property adPolicyReviewStatus

Returns:

  • (String)


365
366
367
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 365

def ad_policy_review_status
  @ad_policy_review_status
end

#ad_policy_topic_entryArray<Google::Apis::DisplayvideoV3::AdPolicyTopicEntry>

The entries for each policy topic identified as relating to the ad. Each entry includes the topic, restriction level, and guidance on how to fix policy issues. Corresponds to the JSON property adPolicyTopicEntry



372
373
374
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 372

def ad_policy_topic_entry
  @ad_policy_topic_entry
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



379
380
381
382
383
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 379

def update!(**args)
  @ad_policy_approval_status = args[:ad_policy_approval_status] if args.key?(:ad_policy_approval_status)
  @ad_policy_review_status = args[:ad_policy_review_status] if args.key?(:ad_policy_review_status)
  @ad_policy_topic_entry = args[:ad_policy_topic_entry] if args.key?(:ad_policy_topic_entry)
end