Class: Google::Apis::DisplayvideoV3::AdPolicyTopicConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details on ad serving constraints.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicConstraint

Returns a new instance of AdPolicyTopicConstraint.



478
479
480
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_domain_mismatch_country_listGoogle::Apis::DisplayvideoV3::AdPolicyTopicConstraintAdPolicyCountryConstraintList

A list of countries where the ad cannot serve due to policy constraints. Corresponds to the JSON property certificateDomainMismatchCountryList



444
445
446
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 444

def certificate_domain_mismatch_country_list
  @certificate_domain_mismatch_country_list
end

#certificate_missing_country_listGoogle::Apis::DisplayvideoV3::AdPolicyTopicConstraintAdPolicyCountryConstraintList

A list of countries where the ad cannot serve due to policy constraints. Corresponds to the JSON property certificateMissingCountryList



449
450
451
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 449

def certificate_missing_country_list
  @certificate_missing_country_list
end

#country_constraintGoogle::Apis::DisplayvideoV3::AdPolicyTopicConstraintAdPolicyCountryConstraintList

A list of countries where the ad cannot serve due to policy constraints. Corresponds to the JSON property countryConstraint



454
455
456
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 454

def country_constraint
  @country_constraint
end

#global_certificate_domain_mismatchGoogle::Apis::DisplayvideoV3::AdPolicyTopicConstraintAdPolicyGlobalCertificateDomainMismatchConstraint

Certificate is required to serve in any country and the existing certificate does not cover the ad's domain. Corresponds to the JSON property globalCertificateDomainMismatch



460
461
462
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 460

def global_certificate_domain_mismatch
  @global_certificate_domain_mismatch
end

#global_certificate_missingGoogle::Apis::DisplayvideoV3::AdPolicyTopicConstraintAdPolicyGlobalCertificateMissingConstraint

Certificate is required to serve in any country. Corresponds to the JSON property globalCertificateMissing



465
466
467
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 465

def global_certificate_missing
  @global_certificate_missing
end

Link to the form to request a certificate for the constraint. Corresponds to the JSON property requestCertificateFormLink

Returns:

  • (String)


470
471
472
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 470

def request_certificate_form_link
  @request_certificate_form_link
end

#reseller_constraintGoogle::Apis::DisplayvideoV3::AdPolicyTopicConstraintAdPolicyResellerConstraint

Policy topic was constrained due to disapproval of the website for reseller purposes. Corresponds to the JSON property resellerConstraint



476
477
478
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 476

def reseller_constraint
  @reseller_constraint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



483
484
485
486
487
488
489
490
491
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 483

def update!(**args)
  @certificate_domain_mismatch_country_list = args[:certificate_domain_mismatch_country_list] if args.key?(:certificate_domain_mismatch_country_list)
  @certificate_missing_country_list = args[:certificate_missing_country_list] if args.key?(:certificate_missing_country_list)
  @country_constraint = args[:country_constraint] if args.key?(:country_constraint)
  @global_certificate_domain_mismatch = args[:global_certificate_domain_mismatch] if args.key?(:global_certificate_domain_mismatch)
  @global_certificate_missing = args[:global_certificate_missing] if args.key?(:global_certificate_missing)
  @request_certificate_form_link = args[:request_certificate_form_link] if args.key?(:request_certificate_form_link)
  @reseller_constraint = args[:reseller_constraint] if args.key?(:reseller_constraint)
end