Class: Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceCounterfeit
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceCounterfeit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details on the counterfeit enforcement that caused a policy violation.
Instance Attribute Summary collapse
-
#owners ⇒ Array<String>
The content or product owners that made a complaint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEvidenceCounterfeit
constructor
A new instance of AdPolicyTopicEvidenceCounterfeit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEvidenceCounterfeit
Returns a new instance of AdPolicyTopicEvidenceCounterfeit.
720 721 722 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#owners ⇒ Array<String>
The content or product owners that made a complaint.
Corresponds to the JSON property owners
718 719 720 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 718 def owners @owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
725 726 727 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 725 def update!(**args) @owners = args[:owners] if args.key?(:owners) end |