Class: Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationNotWorking
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationNotWorking
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for on HTTP or DNS errors related to the ad destination.
Instance Attribute Summary collapse
-
#device ⇒ String
The device where visiting the URL resulted in the error.
-
#dns_error_type ⇒ String
The type of DNS error.
-
#expanded_uri ⇒ String
The full URL that didn't work.
-
#http_error_code ⇒ Fixnum
The HTTP error code.
-
#last_checked_time ⇒ String
The last time the error was seen when navigating to URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEvidenceDestinationNotWorking
constructor
A new instance of AdPolicyTopicEvidenceDestinationNotWorking.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEvidenceDestinationNotWorking
Returns a new instance of AdPolicyTopicEvidenceDestinationNotWorking.
781 782 783 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device ⇒ String
The device where visiting the URL resulted in the error.
Corresponds to the JSON property device
759 760 761 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 759 def device @device end |
#dns_error_type ⇒ String
The type of DNS error.
Corresponds to the JSON property dnsErrorType
764 765 766 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 764 def dns_error_type @dns_error_type end |
#expanded_uri ⇒ String
The full URL that didn't work.
Corresponds to the JSON property expandedUri
769 770 771 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 769 def @expanded_uri end |
#http_error_code ⇒ Fixnum
The HTTP error code.
Corresponds to the JSON property httpErrorCode
774 775 776 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 774 def http_error_code @http_error_code end |
#last_checked_time ⇒ String
The last time the error was seen when navigating to URL.
Corresponds to the JSON property lastCheckedTime
779 780 781 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 779 def last_checked_time @last_checked_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
786 787 788 789 790 791 792 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 786 def update!(**args) @device = args[:device] if args.key?(:device) @dns_error_type = args[:dns_error_type] if args.key?(:dns_error_type) @expanded_uri = args[:expanded_uri] if args.key?(:expanded_uri) @http_error_code = args[:http_error_code] if args.key?(:http_error_code) @last_checked_time = args[:last_checked_time] if args.key?(:last_checked_time) end |