Class: Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceTextList
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceTextList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A list of fragments of text that violated the policy.
Instance Attribute Summary collapse
-
#texts ⇒ Array<String>
The fragments of text from the resource that caused the policy finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEvidenceTextList
constructor
A new instance of AdPolicyTopicEvidenceTextList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEvidenceTextList
Returns a new instance of AdPolicyTopicEvidenceTextList.
951 952 953 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#texts ⇒ Array<String>
The fragments of text from the resource that caused the policy finding.
Corresponds to the JSON property texts
949 950 951 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 949 def texts @texts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
956 957 958 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 956 def update!(**args) @texts = args[:texts] if args.key?(:texts) end |