Class: Google::Apis::DisplayvideoV3::AdvertiserCreativeConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdvertiserCreativeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Creatives related settings of an advertiser.
Instance Attribute Summary collapse
-
#dynamic_creative_enabled ⇒ Boolean
(also: #dynamic_creative_enabled?)
Whether or not the advertiser is enabled for dynamic creatives.
-
#ias_client_id ⇒ Fixnum
An ID for configuring campaign monitoring provided by Integral Ad Service (IAS) .
-
#oba_compliance_disabled ⇒ Boolean
(also: #oba_compliance_disabled?)
Whether or not to disable Google's About this Ad feature that adds badging (to identify the content as an ad) and transparency information (on interaction with About this Ad) to your ads for Online Behavioral Advertising (OBA) and regulatory requirements.
-
#video_creative_data_sharing_authorized ⇒ Boolean
(also: #video_creative_data_sharing_authorized?)
By setting this field to
true, you, on behalf of your company, authorize Google to use video creatives associated with this Display & Video 360 advertiser to provide reporting and features related to the advertiser's television campaigns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdvertiserCreativeConfig
constructor
A new instance of AdvertiserCreativeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdvertiserCreativeConfig
Returns a new instance of AdvertiserCreativeConfig.
1389 1390 1391 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_creative_enabled ⇒ Boolean Also known as: dynamic_creative_enabled?
Whether or not the advertiser is enabled for dynamic creatives.
Corresponds to the JSON property dynamicCreativeEnabled
1348 1349 1350 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1348 def dynamic_creative_enabled @dynamic_creative_enabled end |
#ias_client_id ⇒ Fixnum
An ID for configuring campaign monitoring provided by Integral Ad Service (IAS)
. The DV360 system will append an IAS "Campaign Monitor" tag containing this
ID to the creative tag.
Corresponds to the JSON property iasClientId
1356 1357 1358 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1356 def ias_client_id @ias_client_id end |
#oba_compliance_disabled ⇒ Boolean Also known as: oba_compliance_disabled?
Whether or not to disable Google's About this Ad feature that adds badging (to
identify the content as an ad) and transparency information (on interaction
with About this Ad) to your ads for Online Behavioral Advertising (OBA) and
regulatory requirements. About this Ad gives users greater control over the
ads they see and helps you explain why they're seeing your ad. Learn more. If you choose to set this
field to true, note that ads served through Display & Video 360 must comply
to the following: * Be Online Behavioral Advertising (OBA) compliant, as per
your contract with Google Marketing Platform. * In the European Economic Area (
EEA), include transparency information and a mechanism for users to report
illegal content in ads. If using an alternative ad badging, transparency, and
reporting solution, you must ensure it includes the required transparency
information and illegal content flagging mechanism and that you notify Google
of any illegal content reports using the appropriate form.
Corresponds to the JSON property obaComplianceDisabled
1376 1377 1378 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1376 def oba_compliance_disabled @oba_compliance_disabled end |
#video_creative_data_sharing_authorized ⇒ Boolean Also known as:
By setting this field to true, you, on behalf of your company, authorize
Google to use video creatives associated with this Display & Video 360
advertiser to provide reporting and features related to the advertiser's
television campaigns. Applicable only when the advertiser has a CM360 hybrid
ad server configuration.
Corresponds to the JSON property videoCreativeDataSharingAuthorized
1386 1387 1388 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1386 def @video_creative_data_sharing_authorized end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1394 1395 1396 1397 1398 1399 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1394 def update!(**args) @dynamic_creative_enabled = args[:dynamic_creative_enabled] if args.key?(:dynamic_creative_enabled) @ias_client_id = args[:ias_client_id] if args.key?(:ias_client_id) @oba_compliance_disabled = args[:oba_compliance_disabled] if args.key?(:oba_compliance_disabled) @video_creative_data_sharing_authorized = args[:video_creative_data_sharing_authorized] if args.key?(:video_creative_data_sharing_authorized) end |