Class: Google::Apis::DisplayvideoV3::AdvertiserSdfConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Structured Data Files (SDF) settings of an advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvertiserSdfConfig

Returns a new instance of AdvertiserSdfConfig.



1489
1490
1491
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#override_partner_sdf_configBoolean Also known as: override_partner_sdf_config?

Whether or not this advertiser overrides the SDF configuration of its parent partner. By default, an advertiser inherits the SDF configuration from the parent partner. To override the partner configuration, set this field to true and provide the new configuration in sdfConfig. Corresponds to the JSON property overridePartnerSdfConfig

Returns:

  • (Boolean)


1481
1482
1483
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1481

def override_partner_sdf_config
  @override_partner_sdf_config
end

#sdf_configGoogle::Apis::DisplayvideoV3::SdfConfig

Structured Data File (SDF) related settings. Corresponds to the JSON property sdfConfig



1487
1488
1489
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1487

def sdf_config
  @sdf_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1494
1495
1496
1497
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1494

def update!(**args)
  @override_partner_sdf_config = args[:override_partner_sdf_config] if args.key?(:override_partner_sdf_config)
  @sdf_config = args[:sdf_config] if args.key?(:sdf_config)
end