Class: Google::Apis::DisplayvideoV3::AdvertiserTargetingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Targeting settings related to ad serving of an advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvertiserTargetingConfig

Returns a new instance of AdvertiserTargetingConfig.



1432
1433
1434
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempt_tv_from_viewability_targetingBoolean Also known as: exempt_tv_from_viewability_targeting?

Whether or not connected TV devices are exempt from viewability targeting for all video line items under the advertiser. Corresponds to the JSON property exemptTvFromViewabilityTargeting

Returns:

  • (Boolean)


1429
1430
1431
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1429

def exempt_tv_from_viewability_targeting
  @exempt_tv_from_viewability_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1437
1438
1439
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1437

def update!(**args)
  @exempt_tv_from_viewability_targeting = args[:exempt_tv_from_viewability_targeting] if args.key?(:exempt_tv_from_viewability_targeting)
end