Class: Google::Apis::DisplayvideoV3::AlgorithmRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Rule-based algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRules

Returns a new instance of AlgorithmRules.



1571
1572
1573
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_model_idFixnum

Attribution model for the algorithm. This field is only supported for allowlisted partners. Corresponds to the JSON property attributionModelId

Returns:

  • (Fixnum)


1557
1558
1559
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1557

def attribution_model_id
  @attribution_model_id
end

#impression_signal_rulesetGoogle::Apis::DisplayvideoV3::AlgorithmRulesRuleset

A ruleset consisting of a list of rules and how to aggregate the resulting values. Corresponds to the JSON property impressionSignalRuleset



1563
1564
1565
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1563

def impression_signal_ruleset
  @impression_signal_ruleset
end

#post_impression_signal_rulesetGoogle::Apis::DisplayvideoV3::AlgorithmRulesRuleset

A ruleset consisting of a list of rules and how to aggregate the resulting values. Corresponds to the JSON property postImpressionSignalRuleset



1569
1570
1571
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1569

def post_impression_signal_ruleset
  @post_impression_signal_ruleset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1576
1577
1578
1579
1580
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1576

def update!(**args)
  @attribution_model_id = args[:attribution_model_id] if args.key?(:attribution_model_id)
  @impression_signal_ruleset = args[:impression_signal_ruleset] if args.key?(:impression_signal_ruleset)
  @post_impression_signal_ruleset = args[:post_impression_signal_ruleset] if args.key?(:post_impression_signal_ruleset)
end