Class: Google::Apis::DisplayvideoV3::AlgorithmRulesComparisonValue
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AlgorithmRulesComparisonValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A value to compare the signal to.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#content_duration_value ⇒ String
Video content duration value.
-
#content_genre_id_value ⇒ Fixnum
Video genre id value.
-
#content_stream_type_value ⇒ String
Video delivery type value.
-
#creative_dimension_value ⇒ Google::Apis::DisplayvideoV3::Dimensions
Dimensions.
-
#day_and_time_value ⇒ Google::Apis::DisplayvideoV3::DayAndTime
Representation of time defined by day of the week and hour of the day.
-
#device_type_value ⇒ String
Device type value.
-
#double_value ⇒ Float
Double value.
-
#environment_value ⇒ String
Environment value.
-
#exchange_value ⇒ String
Exchange value.
-
#int64_value ⇒ Fixnum
Integer value.
-
#on_screen_position_value ⇒ String
Ad position value.
-
#string_value ⇒ String
String value.
-
#video_player_size_value ⇒ String
Video player size value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlgorithmRulesComparisonValue
constructor
A new instance of AlgorithmRulesComparisonValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlgorithmRulesComparisonValue
Returns a new instance of AlgorithmRulesComparisonValue.
1675 1676 1677 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
1607 1608 1609 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1607 def bool_value @bool_value end |
#content_duration_value ⇒ String
Video content duration value.
Corresponds to the JSON property contentDurationValue
1613 1614 1615 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1613 def content_duration_value @content_duration_value end |
#content_genre_id_value ⇒ Fixnum
Video genre id value.
Corresponds to the JSON property contentGenreIdValue
1618 1619 1620 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1618 def content_genre_id_value @content_genre_id_value end |
#content_stream_type_value ⇒ String
Video delivery type value.
Corresponds to the JSON property contentStreamTypeValue
1623 1624 1625 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1623 def content_stream_type_value @content_stream_type_value end |
#creative_dimension_value ⇒ Google::Apis::DisplayvideoV3::Dimensions
Dimensions.
Corresponds to the JSON property creativeDimensionValue
1628 1629 1630 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1628 def creative_dimension_value @creative_dimension_value end |
#day_and_time_value ⇒ Google::Apis::DisplayvideoV3::DayAndTime
Representation of time defined by day of the week and hour of the day.
Corresponds to the JSON property dayAndTimeValue
1633 1634 1635 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1633 def day_and_time_value @day_and_time_value end |
#device_type_value ⇒ String
Device type value.
Corresponds to the JSON property deviceTypeValue
1638 1639 1640 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1638 def device_type_value @device_type_value end |
#double_value ⇒ Float
Double value.
Corresponds to the JSON property doubleValue
1643 1644 1645 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1643 def double_value @double_value end |
#environment_value ⇒ String
Environment value.
Corresponds to the JSON property environmentValue
1648 1649 1650 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1648 def environment_value @environment_value end |
#exchange_value ⇒ String
Exchange value.
Corresponds to the JSON property exchangeValue
1653 1654 1655 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1653 def exchange_value @exchange_value end |
#int64_value ⇒ Fixnum
Integer value.
Corresponds to the JSON property int64Value
1658 1659 1660 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1658 def int64_value @int64_value end |
#on_screen_position_value ⇒ String
Ad position value.
Corresponds to the JSON property onScreenPositionValue
1663 1664 1665 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1663 def on_screen_position_value @on_screen_position_value end |
#string_value ⇒ String
String value.
Corresponds to the JSON property stringValue
1668 1669 1670 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1668 def string_value @string_value end |
#video_player_size_value ⇒ String
Video player size value. This field is only supported for allowlisted partners.
Corresponds to the JSON property videoPlayerSizeValue
1673 1674 1675 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1673 def video_player_size_value @video_player_size_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1680 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @content_duration_value = args[:content_duration_value] if args.key?(:content_duration_value) @content_genre_id_value = args[:content_genre_id_value] if args.key?(:content_genre_id_value) @content_stream_type_value = args[:content_stream_type_value] if args.key?(:content_stream_type_value) @creative_dimension_value = args[:creative_dimension_value] if args.key?(:creative_dimension_value) @day_and_time_value = args[:day_and_time_value] if args.key?(:day_and_time_value) @device_type_value = args[:device_type_value] if args.key?(:device_type_value) @double_value = args[:double_value] if args.key?(:double_value) @environment_value = args[:environment_value] if args.key?(:environment_value) @exchange_value = args[:exchange_value] if args.key?(:exchange_value) @int64_value = args[:int64_value] if args.key?(:int64_value) @on_screen_position_value = args[:on_screen_position_value] if args.key?(:on_screen_position_value) @string_value = args[:string_value] if args.key?(:string_value) @video_player_size_value = args[:video_player_size_value] if args.key?(:video_player_size_value) end |