Class: Google::Apis::DisplayvideoV3::AlgorithmRulesFloodlightActivityConversionSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

The rule to score impressions based on Floodlight conversion events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRulesFloodlightActivityConversionSignal

Returns a new instance of AlgorithmRulesFloodlightActivityConversionSignal.



1719
1720
1721
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_countingString

Required. The type of conversions to be used in impression value computation, for example, post-click conversions. Corresponds to the JSON property conversionCounting

Returns:

  • (String)


1706
1707
1708
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1706

def conversion_counting
  @conversion_counting
end

#counting_methodString

Required. The way to acquire value from the floodlight activity, for example, count of the conversion. Corresponds to the JSON property countingMethod

Returns:

  • (String)


1712
1713
1714
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1712

def counting_method
  @counting_method
end

#floodlight_activity_idFixnum

Required. Id of the floodlight activity. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


1717
1718
1719
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1717

def floodlight_activity_id
  @floodlight_activity_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1724
1725
1726
1727
1728
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1724

def update!(**args)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
end