Class: Google::Apis::DisplayvideoV3::AlgorithmRulesRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Set of conditions. The return value of the rule is either: * The return value for single met condition or * The defined default return value if no conditions are met.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRulesRule

Returns a new instance of AlgorithmRulesRule.



1748
1749
1750
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsArray<Google::Apis::DisplayvideoV3::AlgorithmRulesRuleCondition>

List of conditions in this rule. The criteria among conditions should be mutually exclusive. Corresponds to the JSON property conditions



1741
1742
1743
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1741

def conditions
  @conditions
end

#default_return_valueGoogle::Apis::DisplayvideoV3::AlgorithmRulesSignalValue

Adjusted value of the signal used for rule evaluation. Corresponds to the JSON property defaultReturnValue



1746
1747
1748
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1746

def default_return_value
  @default_return_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1753
1754
1755
1756
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1753

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @default_return_value = args[:default_return_value] if args.key?(:default_return_value)
end