Class: Google::Apis::DisplayvideoV3::AlgorithmRulesRuleCondition
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AlgorithmRulesRuleCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Set of signal comparisons. Equivalent of an if statement.
Instance Attribute Summary collapse
-
#return_value ⇒ Google::Apis::DisplayvideoV3::AlgorithmRulesSignalValue
Adjusted value of the signal used for rule evaluation.
-
#signal_comparisons ⇒ Array<Google::Apis::DisplayvideoV3::AlgorithmRulesSignalComparison>
List of comparisons that build
ifstatement condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlgorithmRulesRuleCondition
constructor
A new instance of AlgorithmRulesRuleCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlgorithmRulesRuleCondition
Returns a new instance of AlgorithmRulesRuleCondition.
1757 1758 1759 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#return_value ⇒ Google::Apis::DisplayvideoV3::AlgorithmRulesSignalValue
Adjusted value of the signal used for rule evaluation.
Corresponds to the JSON property returnValue
1749 1750 1751 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1749 def return_value @return_value end |
#signal_comparisons ⇒ Array<Google::Apis::DisplayvideoV3::AlgorithmRulesSignalComparison>
List of comparisons that build if statement condition. The comparisons are
combined into a single condition with AND logical operators.
Corresponds to the JSON property signalComparisons
1755 1756 1757 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1755 def signal_comparisons @signal_comparisons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1762 1763 1764 1765 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1762 def update!(**args) @return_value = args[:return_value] if args.key?(:return_value) @signal_comparisons = args[:signal_comparisons] if args.key?(:signal_comparisons) end |