Class: Google::Apis::DisplayvideoV3::AudioAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AudioAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for an audio ad.
Instance Attribute Summary collapse
-
#display_url ⇒ String
The webpage address that appears with the ad.
-
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
-
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
-
#video ⇒ Google::Apis::DisplayvideoV3::YoutubeVideoDetails
Details of a YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudioAd
constructor
A new instance of AudioAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudioAd
Returns a new instance of AudioAd.
2738 2739 2740 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2738 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_url ⇒ String
The webpage address that appears with the ad.
Corresponds to the JSON property displayUrl
2721 2722 2723 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2721 def display_url @display_url end |
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
Corresponds to the JSON property finalUrl
2726 2727 2728 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2726 def final_url @final_url end |
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
2731 2732 2733 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2731 def tracking_url @tracking_url end |
#video ⇒ Google::Apis::DisplayvideoV3::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
2736 2737 2738 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2736 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2743 2744 2745 2746 2747 2748 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2743 def update!(**args) @display_url = args[:display_url] if args.key?(:display_url) @final_url = args[:final_url] if args.key?(:final_url) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @video = args[:video] if args.key?(:video) end |