Class: Google::Apis::DisplayvideoV3::AudioVideoOffset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

The length an audio or a video has been played.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AudioVideoOffset

Returns a new instance of AudioVideoOffset.



2722
2723
2724
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentageFixnum

Optional. The offset in percentage of the audio or video duration. Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


2715
2716
2717
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2715

def percentage
  @percentage
end

#secondsFixnum

Optional. The offset in seconds from the start of the audio or video. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


2720
2721
2722
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2720

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2727
2728
2729
2730
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2727

def update!(**args)
  @percentage = args[:percentage] if args.key?(:percentage)
  @seconds = args[:seconds] if args.key?(:seconds)
end