Class: Google::Apis::DisplayvideoV3::BiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the bid strategy. Bid strategy determines the bid price.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiddingStrategy

Returns a new instance of BiddingStrategy.



2984
2985
2986
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#demand_gen_bidGoogle::Apis::DisplayvideoV3::DemandGenBiddingStrategy

Settings that control the bid strategy for Demand Gen resources. Corresponds to the JSON property demandGenBid



2960
2961
2962
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2960

def demand_gen_bid
  @demand_gen_bid
end

#fixed_bidGoogle::Apis::DisplayvideoV3::FixedBidStrategy

A strategy that uses a fixed bidding price. Corresponds to the JSON property fixedBid



2965
2966
2967
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2965

def fixed_bid
  @fixed_bid
end

#maximize_spend_auto_bidGoogle::Apis::DisplayvideoV3::MaximizeSpendBidStrategy

A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget. Corresponds to the JSON property maximizeSpendAutoBid



2971
2972
2973
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2971

def maximize_spend_auto_bid
  @maximize_spend_auto_bid
end

#performance_goal_auto_bidGoogle::Apis::DisplayvideoV3::PerformanceGoalBidStrategy

A strategy that automatically adjusts the bid to meet or beat a specified performance goal. Corresponds to the JSON property performanceGoalAutoBid



2977
2978
2979
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2977

def performance_goal_auto_bid
  @performance_goal_auto_bid
end

#youtube_and_partners_bidGoogle::Apis::DisplayvideoV3::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property youtubeAndPartnersBid



2982
2983
2984
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2982

def youtube_and_partners_bid
  @youtube_and_partners_bid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2989
2990
2991
2992
2993
2994
2995
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2989

def update!(**args)
  @demand_gen_bid = args[:demand_gen_bid] if args.key?(:demand_gen_bid)
  @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid)
  @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid)
  @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid)
  @youtube_and_partners_bid = args[:youtube_and_partners_bid] if args.key?(:youtube_and_partners_bid)
end