Class: Google::Apis::DisplayvideoV3::BrowserAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for assigned browser targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_BROWSER.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BrowserAssignedTargetingOptionDetails

Returns a new instance of BrowserAssignedTargetingOptionDetails.



3005
3006
3007
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the browser. Corresponds to the JSON property displayName

Returns:

  • (String)


2990
2991
2992
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2990

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned browser targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


2996
2997
2998
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2996

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_BROWSER. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


3003
3004
3005
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3003

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3010
3011
3012
3013
3014
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3010

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end