Class: Google::Apis::DisplayvideoV3::BulkEditAdGroupAssignedTargetingOptionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::BulkEditAdGroupAssignedTargetingOptionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Request message for BulkEditAdGroupAssignedTargetingOptions.
Instance Attribute Summary collapse
-
#ad_group_ids ⇒ Array<Fixnum>
Required.
-
#create_requests ⇒ Array<Google::Apis::DisplayvideoV3::CreateAssignedTargetingOptionsRequest>
Optional.
-
#delete_requests ⇒ Array<Google::Apis::DisplayvideoV3::DeleteAssignedTargetingOptionsRequest>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsRequest
constructor
A new instance of BulkEditAdGroupAssignedTargetingOptionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsRequest
Returns a new instance of BulkEditAdGroupAssignedTargetingOptionsRequest.
3141 3142 3143 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ids ⇒ Array<Fixnum>
Required. The IDs of the ad groups the assigned targeting options will belong
to. A maximum of 25 ad group IDs can be specified.
Corresponds to the JSON property adGroupIds
3113 3114 3115 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3113 def ad_group_ids @ad_group_ids end |
#create_requests ⇒ Array<Google::Apis::DisplayvideoV3::CreateAssignedTargetingOptionsRequest>
Optional. The assigned targeting options to create in batch, specified as a
list of CreateAssignedTargetingOptionRequest. Supported targeting types: *
TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_APP *
TARGETING_TYPE_APP_CATEGORY * TARGETING_TYPE_AUDIENCE_GROUP *
TARGETING_TYPE_CATEGORY * TARGETING_TYPE_GENDER *
TARGETING_TYPE_GEO_REGION * TARGETING_TYPE_HOUSEHOLD_INCOME *
TARGETING_TYPE_KEYWORD * TARGETING_TYPE_LANGUAGE *
TARGETING_TYPE_PARENTAL_STATUS * TARGETING_TYPE_URL *
TARGETING_TYPE_YOUTUBE_CHANNEL * TARGETING_TYPE_YOUTUBE_VIDEO
Corresponds to the JSON property createRequests
3126 3127 3128 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3126 def create_requests @create_requests end |
#delete_requests ⇒ Array<Google::Apis::DisplayvideoV3::DeleteAssignedTargetingOptionsRequest>
Optional. The assigned targeting options to delete in batch, specified as a
list of DeleteAssignedTargetingOptionsRequest. Supported targeting types: *
TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_APP *
TARGETING_TYPE_APP_CATEGORY * TARGETING_TYPE_AUDIENCE_GROUP *
TARGETING_TYPE_CATEGORY * TARGETING_TYPE_GENDER *
TARGETING_TYPE_GEO_REGION * TARGETING_TYPE_HOUSEHOLD_INCOME *
TARGETING_TYPE_KEYWORD * TARGETING_TYPE_LANGUAGE *
TARGETING_TYPE_PARENTAL_STATUS * TARGETING_TYPE_URL *
TARGETING_TYPE_YOUTUBE_CHANNEL * TARGETING_TYPE_YOUTUBE_VIDEO
Corresponds to the JSON property deleteRequests
3139 3140 3141 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3139 def delete_requests @delete_requests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3146 3147 3148 3149 3150 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3146 def update!(**args) @ad_group_ids = args[:ad_group_ids] if args.key?(:ad_group_ids) @create_requests = args[:create_requests] if args.key?(:create_requests) @delete_requests = args[:delete_requests] if args.key?(:delete_requests) end |