Class: Google::Apis::DisplayvideoV3::BulkEditAdvertiserAssignedTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Request message for BulkEditAdvertiserAssignedTargetingOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditAdvertiserAssignedTargetingOptionsRequest

Returns a new instance of BulkEditAdvertiserAssignedTargetingOptionsRequest.



3206
3207
3208
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_requestsArray<Google::Apis::DisplayvideoV3::CreateAssignedTargetingOptionsRequest>

The assigned targeting options to create in batch, specified as a list of CreateAssignedTargetingOptionsRequest. Supported targeting types: * TARGETING_TYPE_CHANNEL * TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION * TARGETING_TYPE_OMID * TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION * TARGETING_TYPE_KEYWORD Corresponds to the JSON property createRequests



3195
3196
3197
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3195

def create_requests
  @create_requests
end

#delete_requestsArray<Google::Apis::DisplayvideoV3::DeleteAssignedTargetingOptionsRequest>

The assigned targeting options to delete in batch, specified as a list of DeleteAssignedTargetingOptionsRequest. Supported targeting types: * TARGETING_TYPE_CHANNEL * TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION * TARGETING_TYPE_OMID * TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION * TARGETING_TYPE_KEYWORD Corresponds to the JSON property deleteRequests



3204
3205
3206
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3204

def delete_requests
  @delete_requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3211
3212
3213
3214
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3211

def update!(**args)
  @create_requests = args[:create_requests] if args.key?(:create_requests)
  @delete_requests = args[:delete_requests] if args.key?(:delete_requests)
end