Class: Google::Apis::DisplayvideoV3::BulkEditNegativeKeywordsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Request message for NegativeKeywordService.BulkEditNegativeKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditNegativeKeywordsRequest

Returns a new instance of BulkEditNegativeKeywordsRequest.



3351
3352
3353
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_negative_keywordsArray<Google::Apis::DisplayvideoV3::NegativeKeyword>

The negative keywords to create in batch, specified as a list of NegativeKeywords. Corresponds to the JSON property createdNegativeKeywords



3343
3344
3345
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3343

def created_negative_keywords
  @created_negative_keywords
end

#deleted_negative_keywordsArray<String>

The negative keywords to delete in batch, specified as a list of keyword_values. Corresponds to the JSON property deletedNegativeKeywords

Returns:

  • (Array<String>)


3349
3350
3351
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3349

def deleted_negative_keywords
  @deleted_negative_keywords
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3356
3357
3358
3359
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3356

def update!(**args)
  @created_negative_keywords = args[:created_negative_keywords] if args.key?(:created_negative_keywords)
  @deleted_negative_keywords = args[:deleted_negative_keywords] if args.key?(:deleted_negative_keywords)
end