Class: Google::Apis::DisplayvideoV3::BulkEditNegativeKeywordsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::BulkEditNegativeKeywordsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Response message for NegativeKeywordService.BulkEditNegativeKeywords.
Instance Attribute Summary collapse
-
#negative_keywords ⇒ Array<Google::Apis::DisplayvideoV3::NegativeKeyword>
The list of negative keywords that have been successfully created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditNegativeKeywordsResponse
constructor
A new instance of BulkEditNegativeKeywordsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditNegativeKeywordsResponse
Returns a new instance of BulkEditNegativeKeywordsResponse.
3527 3528 3529 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#negative_keywords ⇒ Array<Google::Apis::DisplayvideoV3::NegativeKeyword>
The list of negative keywords that have been successfully created. This list
will be absent if empty.
Corresponds to the JSON property negativeKeywords
3525 3526 3527 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3525 def negative_keywords @negative_keywords end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3532 3533 3534 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3532 def update!(**args) @negative_keywords = args[:negative_keywords] if args.key?(:negative_keywords) end |