Class: Google::Apis::DisplayvideoV3::BulkEditSitesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::BulkEditSitesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Response message for SiteService.BulkEditSites.
Instance Attribute Summary collapse
-
#sites ⇒ Array<Google::Apis::DisplayvideoV3::Site>
The list of sites that have been successfully created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditSitesResponse
constructor
A new instance of BulkEditSitesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditSitesResponse
Returns a new instance of BulkEditSitesResponse.
3650 3651 3652 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sites ⇒ Array<Google::Apis::DisplayvideoV3::Site>
The list of sites that have been successfully created. This list will be
absent if empty.
Corresponds to the JSON property sites
3648 3649 3650 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3648 def sites @sites end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3655 3656 3657 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3655 def update!(**args) @sites = args[:sites] if args.key?(:sites) end |