Class: Google::Apis::DisplayvideoV3::BulkListAdGroupAssignedTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::BulkListAdGroupAssignedTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#ad_group_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV3::AdGroupAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and the ad group it is assigned to.
-
#next_page_token ⇒ String
A token identifying the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkListAdGroupAssignedTargetingOptionsResponse
constructor
A new instance of BulkListAdGroupAssignedTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkListAdGroupAssignedTargetingOptionsResponse
Returns a new instance of BulkListAdGroupAssignedTargetingOptionsResponse.
3679 3680 3681 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV3::AdGroupAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and
the ad group it is assigned to. This list will be absent if empty.
Corresponds to the JSON property adGroupAssignedTargetingOptions
3668 3669 3670 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3668 def @ad_group_assigned_targeting_options end |
#next_page_token ⇒ String
A token identifying the next page of results. This value should be specified
as the pageToken in a subsequent call to
BulkListAdGroupAssignedTargetingOptions to fetch the next page of results.
This token will be absent if there are no more AdGroupAssignedTargetingOption
resources to return.
Corresponds to the JSON property nextPageToken
3677 3678 3679 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3677 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3684 3685 3686 3687 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3684 def update!(**args) @ad_group_assigned_targeting_options = args[:ad_group_assigned_targeting_options] if args.key?(:ad_group_assigned_targeting_options) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |