Class: Google::Apis::DisplayvideoV3::BulkUpdateLineItemsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::BulkUpdateLineItemsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Response message for LineItemService.BulkUpdateLineItems.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::DisplayvideoV3::Status>
Errors returned by line items that failed to update.
-
#failed_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that failed to update.
-
#skipped_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that are skipped for updates.
-
#updated_line_item_ids ⇒ Array<Fixnum>
The IDs of successfully updated line items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkUpdateLineItemsResponse
constructor
A new instance of BulkUpdateLineItemsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkUpdateLineItemsResponse
Returns a new instance of BulkUpdateLineItemsResponse.
3789 3790 3791 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::DisplayvideoV3::Status>
Errors returned by line items that failed to update.
Corresponds to the JSON property errors
3770 3771 3772 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3770 def errors @errors end |
#failed_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that failed to update.
Corresponds to the JSON property failedLineItemIds
3775 3776 3777 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3775 def failed_line_item_ids @failed_line_item_ids end |
#skipped_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that are skipped for updates. For example, unnecessary
mutates that will result in effectively no changes to line items will be
skipped and corresponding line item IDs can be tracked here.
Corresponds to the JSON property skippedLineItemIds
3782 3783 3784 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3782 def skipped_line_item_ids @skipped_line_item_ids end |
#updated_line_item_ids ⇒ Array<Fixnum>
The IDs of successfully updated line items.
Corresponds to the JSON property updatedLineItemIds
3787 3788 3789 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3787 def updated_line_item_ids @updated_line_item_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3794 3795 3796 3797 3798 3799 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3794 def update!(**args) @errors = args[:errors] if args.key?(:errors) @failed_line_item_ids = args[:failed_line_item_ids] if args.key?(:failed_line_item_ids) @skipped_line_item_ids = args[:skipped_line_item_ids] if args.key?(:skipped_line_item_ids) @updated_line_item_ids = args[:updated_line_item_ids] if args.key?(:updated_line_item_ids) end |