Class: Google::Apis::DisplayvideoV3::Campaign
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::Campaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single campaign.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV3::CampaignBudget>
The list of budgets available to this campaign.
-
#campaign_flight ⇒ Google::Apis::DisplayvideoV3::CampaignFlight
Settings that track the planned spend and duration of a campaign.
-
#campaign_goal ⇒ Google::Apis::DisplayvideoV3::CampaignGoal
Settings that control the goal of a campaign.
-
#campaign_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Campaign
constructor
A new instance of Campaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Campaign
Returns a new instance of Campaign.
4005 4006 4007 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the campaign belongs to.
Corresponds to the JSON property advertiserId
3951 3952 3953 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3951 def advertiser_id @advertiser_id end |
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV3::CampaignBudget>
The list of budgets available to this campaign. If this field is not set, the
campaign uses an unlimited budget.
Corresponds to the JSON property campaignBudgets
3957 3958 3959 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3957 def campaign_budgets @campaign_budgets end |
#campaign_flight ⇒ Google::Apis::DisplayvideoV3::CampaignFlight
Settings that track the planned spend and duration of a campaign.
Corresponds to the JSON property campaignFlight
3962 3963 3964 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3962 def campaign_flight @campaign_flight end |
#campaign_goal ⇒ Google::Apis::DisplayvideoV3::CampaignGoal
Settings that control the goal of a campaign.
Corresponds to the JSON property campaignGoal
3967 3968 3969 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3967 def campaign_goal @campaign_goal end |
#campaign_id ⇒ Fixnum
Output only. The unique ID of the campaign. Assigned by the system.
Corresponds to the JSON property campaignId
3972 3973 3974 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3972 def campaign_id @campaign_id end |
#display_name ⇒ String
Required. The display name of the campaign. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
3978 3979 3980 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3978 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the insertion orders under this campaign can
spend their budgets and bid on inventory. * Accepted values are
ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. *
For CreateCampaign method, ENTITY_STATUS_ARCHIVED is not allowed.
Corresponds to the JSON property entityStatus
3986 3987 3988 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3986 def entity_status @entity_status end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
3992 3993 3994 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3992 def frequency_cap @frequency_cap end |
#name ⇒ String
Output only. The resource name of the campaign.
Corresponds to the JSON property name
3997 3998 3999 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3997 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the campaign was last updated. Assigned by the
system.
Corresponds to the JSON property updateTime
4003 4004 4005 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4003 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4010 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @campaign_budgets = args[:campaign_budgets] if args.key?(:campaign_budgets) @campaign_flight = args[:campaign_flight] if args.key?(:campaign_flight) @campaign_goal = args[:campaign_goal] if args.key?(:campaign_goal) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |