Class: Google::Apis::DisplayvideoV3::CarouselCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a Demand Gen carousel card.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarouselCard

Returns a new instance of CarouselCard.



4181
4182
4183
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionString

Required. The text on the call-to-action button shown on the card. Must use 10 characters or less. Corresponds to the JSON property callToAction

Returns:

  • (String)


4147
4148
4149
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4147

def call_to_action
  @call_to_action
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the card on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4153

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the card. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4159
4160
4161
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4159

def final_url
  @final_url
end

#headlineString

Required. The headline of the card. Corresponds to the JSON property headline

Returns:

  • (String)


4164
4165
4166
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4164

def headline
  @headline
end

#marketing_imageGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property marketingImage



4169
4170
4171
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4169

def marketing_image
  @marketing_image
end

#portrait_marketing_imageGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property portraitMarketingImage



4174
4175
4176
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4174

def portrait_marketing_image
  @portrait_marketing_image
end

#square_marketing_imageGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property squareMarketingImage



4179
4180
4181
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4179

def square_marketing_image
  @square_marketing_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4186
4187
4188
4189
4190
4191
4192
4193
4194
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4186

def update!(**args)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headline = args[:headline] if args.key?(:headline)
  @marketing_image = args[:marketing_image] if args.key?(:marketing_image)
  @portrait_marketing_image = args[:portrait_marketing_image] if args.key?(:portrait_marketing_image)
  @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image)
end