Class: Google::Apis::DisplayvideoV3::Channel
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single channel. Channels are custom groups of related websites and apps.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the channel.
-
#channel_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#negatively_targeted_line_item_count ⇒ Fixnum
Output only.
-
#partner_id ⇒ Fixnum
The ID of the partner that owns the channel.
-
#positively_targeted_line_item_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
4145 4146 4147 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the channel.
Corresponds to the JSON property advertiserId
4110 4111 4112 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4110 def advertiser_id @advertiser_id end |
#channel_id ⇒ Fixnum
Output only. The unique ID of the channel. Assigned by the system.
Corresponds to the JSON property channelId
4115 4116 4117 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4115 def channel_id @channel_id end |
#display_name ⇒ String
Required. The display name of the channel. Must be UTF-8 encoded with a
maximum length of 240 bytes.
Corresponds to the JSON property displayName
4121 4122 4123 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4121 def display_name @display_name end |
#name ⇒ String
Output only. The resource name of the channel.
Corresponds to the JSON property name
4126 4127 4128 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4126 def name @name end |
#negatively_targeted_line_item_count ⇒ Fixnum
Output only. Number of line items that are directly targeting this channel
negatively.
Corresponds to the JSON property negativelyTargetedLineItemCount
4132 4133 4134 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4132 def negatively_targeted_line_item_count @negatively_targeted_line_item_count end |
#partner_id ⇒ Fixnum
The ID of the partner that owns the channel.
Corresponds to the JSON property partnerId
4137 4138 4139 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4137 def partner_id @partner_id end |
#positively_targeted_line_item_count ⇒ Fixnum
Output only. Number of line items that are directly targeting this channel
positively.
Corresponds to the JSON property positivelyTargetedLineItemCount
4143 4144 4145 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4143 def positively_targeted_line_item_count @positively_targeted_line_item_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4150 4151 4152 4153 4154 4155 4156 4157 4158 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4150 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @channel_id = args[:channel_id] if args.key?(:channel_id) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @negatively_targeted_line_item_count = args[:negatively_targeted_line_item_count] if args.key?(:negatively_targeted_line_item_count) @partner_id = args[:partner_id] if args.key?(:partner_id) @positively_targeted_line_item_count = args[:positively_targeted_line_item_count] if args.key?(:positively_targeted_line_item_count) end |