Class: Google::Apis::DisplayvideoV3::ContactInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Contact information defining a Customer Match audience member.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContactInfo

Returns a new instance of ContactInfo.



4487
4488
4489
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the member. Must also be set with the following fields: * hashed_first_name * hashed_last_name * zip_codes Corresponds to the JSON property countryCode

Returns:

  • (String)


4452
4453
4454
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4452

def country_code
  @country_code
end

#hashed_emailsArray<String>

A list of SHA256 hashed email of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Corresponds to the JSON property hashedEmails

Returns:

  • (Array<String>)


4458
4459
4460
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4458

def hashed_emails
  @hashed_emails
end

#hashed_first_nameString

SHA256 hashed first name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_last_name * zip_codes Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


4465
4466
4467
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4465

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

SHA256 hashed last name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_first_name * zip_codes Corresponds to the JSON property hashedLastName

Returns:

  • (String)


4472
4473
4474
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4472

def hashed_last_name
  @hashed_last_name
end

#hashed_phone_numbersArray<String>

A list of SHA256 hashed phone numbers of the member. Before hashing, all phone numbers must be formatted using the E.164 format and include the country calling code. Corresponds to the JSON property hashedPhoneNumbers

Returns:

  • (Array<String>)


4479
4480
4481
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4479

def hashed_phone_numbers
  @hashed_phone_numbers
end

#zip_codesArray<String>

A list of zip codes of the member. Must also be set with the following fields:

  • country_code * hashed_first_name * hashed_last_name Corresponds to the JSON property zipCodes

Returns:

  • (Array<String>)


4485
4486
4487
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4485

def zip_codes
  @zip_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4492
4493
4494
4495
4496
4497
4498
4499
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4492

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_emails = args[:hashed_emails] if args.key?(:hashed_emails)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_phone_numbers = args[:hashed_phone_numbers] if args.key?(:hashed_phone_numbers)
  @zip_codes = args[:zip_codes] if args.key?(:zip_codes)
end