Class: Google::Apis::DisplayvideoV3::ContentInstreamPositionAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ContentInstreamPositionAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Assigned content instream position targeting option details. This will be
populated in the content_instream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Instance Attribute Summary collapse
-
#ad_type ⇒ String
Output only.
-
#content_instream_position ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails
constructor
A new instance of ContentInstreamPositionAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails
Returns a new instance of ContentInstreamPositionAssignedTargetingOptionDetails.
4779 4780 4781 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_type ⇒ String
Output only. The ad type to target. Only applicable to insertion order
targeting and new line items supporting the specified ad type will inherit
this targeting option by default. Possible values are: * AD_TYPE_VIDEO, the
setting will be inherited by new line item when line_item_type is
LINE_ITEM_TYPE_VIDEO_DEFAULT. * AD_TYPE_AUDIO, the setting will be
inherited by new line item when line_item_type is
LINE_ITEM_TYPE_AUDIO_DEFAULT.
Corresponds to the JSON property adType
4772 4773 4774 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4772 def ad_type @ad_type end |
#content_instream_position ⇒ String
Required. The content instream position for video or audio ads.
Corresponds to the JSON property contentInstreamPosition
4777 4778 4779 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4777 def content_instream_position @content_instream_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4784 4785 4786 4787 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4784 def update!(**args) @ad_type = args[:ad_type] if args.key?(:ad_type) @content_instream_position = args[:content_instream_position] if args.key?(:content_instream_position) end |