Class: Google::Apis::DisplayvideoV3::ContentOutstreamPositionAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Assigned content outstream position targeting option details. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentOutstreamPositionAssignedTargetingOptionDetails

Returns a new instance of ContentOutstreamPositionAssignedTargetingOptionDetails.



4834
4835
4836
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_typeString

Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * AD_TYPE_DISPLAY, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_DISPLAY_DEFAULT. * AD_TYPE_VIDEO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_VIDEO_DEFAULT. Corresponds to the JSON property adType

Returns:

  • (String)


4827
4828
4829
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4827

def ad_type
  @ad_type
end

#content_outstream_positionString

Required. The content outstream position. Corresponds to the JSON property contentOutstreamPosition

Returns:

  • (String)


4832
4833
4834
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4832

def content_outstream_position
  @content_outstream_position
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4839
4840
4841
4842
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4839

def update!(**args)
  @ad_type = args[:ad_type] if args.key?(:ad_type)
  @content_outstream_position = args[:content_outstream_position] if args.key?(:content_outstream_position)
end