Class: Google::Apis::DisplayvideoV3::CreateAssignedTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A request listing which assigned targeting options of a given targeting type should be created and added.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateAssignedTargetingOptionsRequest

Returns a new instance of CreateAssignedTargetingOptionsRequest.



5095
5096
5097
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_targeting_optionsArray<Google::Apis::DisplayvideoV3::AssignedTargetingOption>

Required. The assigned targeting options to create and add. Corresponds to the JSON property assignedTargetingOptions



5088
5089
5090
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5088

def assigned_targeting_options
  @assigned_targeting_options
end

#targeting_typeString

Required. Identifies the type of this assigned targeting option. Corresponds to the JSON property targetingType

Returns:

  • (String)


5093
5094
5095
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5093

def targeting_type
  @targeting_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5100
5101
5102
5103
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5100

def update!(**args)
  @assigned_targeting_options = args[:assigned_targeting_options] if args.key?(:assigned_targeting_options)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
end