Class: Google::Apis::DisplayvideoV3::CreateSdfDownloadTaskRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Request message for [SdfDownloadTaskService.CreateSdfDownloadTask].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateSdfDownloadTaskRequest

Returns a new instance of CreateSdfDownloadTaskRequest.



5015
5016
5017
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser to download SDF for. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


4984
4985
4986
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4984

def advertiser_id
  @advertiser_id
end

#id_filterGoogle::Apis::DisplayvideoV3::IdFilter

A filtering option that filters entities by their entity IDs. Corresponds to the JSON property idFilter



4989
4990
4991
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4989

def id_filter
  @id_filter
end

#inventory_source_filterGoogle::Apis::DisplayvideoV3::InventorySourceFilter

A filtering option for filtering on Inventory Source entities. Corresponds to the JSON property inventorySourceFilter



4994
4995
4996
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4994

def inventory_source_filter
  @inventory_source_filter
end

#parent_entity_filterGoogle::Apis::DisplayvideoV3::ParentEntityFilter

A filtering option that filters on selected file types belonging to a chosen set of filter entities. Corresponds to the JSON property parentEntityFilter



5000
5001
5002
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5000

def parent_entity_filter
  @parent_entity_filter
end

#partner_idFixnum

The ID of the partner to download SDF for. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


5005
5006
5007
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5005

def partner_id
  @partner_id
end

#versionString

Required. The SDF version of the downloaded file. If set to SDF_VERSION_UNSPECIFIED, this will default to the version specified by the advertiser or partner identified by root_id. An advertiser inherits its SDF version from its partner unless configured otherwise. Corresponds to the JSON property version

Returns:

  • (String)


5013
5014
5015
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5013

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5020
5021
5022
5023
5024
5025
5026
5027
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5020

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @id_filter = args[:id_filter] if args.key?(:id_filter)
  @inventory_source_filter = args[:inventory_source_filter] if args.key?(:inventory_source_filter)
  @parent_entity_filter = args[:parent_entity_filter] if args.key?(:parent_entity_filter)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @version = args[:version] if args.key?(:version)
end