Class: Google::Apis::DisplayvideoV3::CustomBiddingAlgorithm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single custom bidding algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingAlgorithm

Returns a new instance of CustomBiddingAlgorithm.



5647
5648
5649
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Immutable. The unique ID of the advertiser that owns the custom bidding algorithm. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


5589
5590
5591
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5589

def advertiser_id
  @advertiser_id
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm. Assigned by the system. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


5595
5596
5597
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5595

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_algorithm_typeString

Required. Immutable. The type of custom bidding algorithm. Corresponds to the JSON property customBiddingAlgorithmType

Returns:

  • (String)


5600
5601
5602
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5600

def custom_bidding_algorithm_type
  @custom_bidding_algorithm_type
end

#display_nameString

Required. The display name of the custom bidding algorithm. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


5606
5607
5608
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5606

def display_name
  @display_name
end

#entity_statusString

Controls whether or not the custom bidding algorithm can be used as a bidding strategy. Accepted values are: * ENTITY_STATUS_ACTIVE * ENTITY_STATUS_ARCHIVED Corresponds to the JSON property entityStatus

Returns:

  • (String)


5613
5614
5615
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5613

def entity_status
  @entity_status
end

#model_detailsArray<Google::Apis::DisplayvideoV3::CustomBiddingModelDetails>

Output only. The details of custom bidding models for each advertiser who has access. This field may only include the details of the queried advertiser if the algorithm owner is a partner and is being retrieved using an advertiser accessor. Corresponds to the JSON property modelDetails



5624
5625
5626
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5624

def model_details
  @model_details
end

#nameString

Output only. The resource name of the custom bidding algorithm. Corresponds to the JSON property name

Returns:

  • (String)


5629
5630
5631
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5629

def name
  @name
end

#partner_idFixnum

Immutable. The unique ID of the partner that owns the custom bidding algorithm. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


5634
5635
5636
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5634

def partner_id
  @partner_id
end

#shared_advertiser_idsArray<Fixnum>

The IDs of the advertisers who have access to this algorithm. If advertiser_id is set, this field will only consist of that value. This field will not be set if the algorithm owner is a partner and is being retrieved using an advertiser accessor. Corresponds to the JSON property sharedAdvertiserIds

Returns:

  • (Array<Fixnum>)


5645
5646
5647
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5645

def shared_advertiser_ids
  @shared_advertiser_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5652

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_algorithm_type = args[:custom_bidding_algorithm_type] if args.key?(:custom_bidding_algorithm_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @model_details = args[:model_details] if args.key?(:model_details)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids)
end