Class: Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRules
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single custom bidding algorithm rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only.
-
#error ⇒ Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
-
#name ⇒ String
Output only.
-
#rules ⇒ Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
constructor
A new instance of CustomBiddingAlgorithmRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
Returns a new instance of CustomBiddingAlgorithmRules.
5713 5714 5715 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the rules resource is currently being used for scoring by
the parent algorithm.
Corresponds to the JSON property active
5673 5674 5675 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5673 def active @active end |
#create_time ⇒ String
Output only. The time when the rules resource was created.
Corresponds to the JSON property createTime
5679 5680 5681 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5679 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm that the rules
resource belongs to.
Corresponds to the JSON property customBiddingAlgorithmId
5685 5686 5687 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5685 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only. The unique ID of the rules resource.
Corresponds to the JSON property customBiddingAlgorithmRulesId
5690 5691 5692 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5690 def custom_bidding_algorithm_rules_id @custom_bidding_algorithm_rules_id end |
#error ⇒ Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
Corresponds to the JSON property error
5695 5696 5697 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5695 def error @error end |
#name ⇒ String
Output only. The resource name of the rules resource.
Corresponds to the JSON property name
5700 5701 5702 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5700 def name @name end |
#rules ⇒ Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file. Retrieve the location to
upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules.
Corresponds to the JSON property rules
5706 5707 5708 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5706 def rules @rules end |
#state ⇒ String
Output only. The state of the rules resource.
Corresponds to the JSON property state
5711 5712 5713 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5711 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5718 5719 5720 5721 5722 5723 5724 5725 5726 5727 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5718 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id) @error = args[:error] if args.key?(:error) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @state = args[:state] if args.key?(:state) end |