Class: Google::Apis::DisplayvideoV3::CustomBiddingScript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingScript

Returns a new instance of CustomBiddingScript.



5850
5851
5852
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the script is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


5810
5811
5812
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5810

def active
  @active
end

#create_timeString

Output only. The time when the script was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5816
5817
5818
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5816

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm the script belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


5822
5823
5824
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5822

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_script_idFixnum

Output only. The unique ID of the custom bidding script. Corresponds to the JSON property customBiddingScriptId

Returns:

  • (Fixnum)


5827
5828
5829
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5827

def custom_bidding_script_id
  @custom_bidding_script_id
end

#errorsArray<Google::Apis::DisplayvideoV3::ScriptError>

Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED. Corresponds to the JSON property errors



5833
5834
5835
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5833

def errors
  @errors
end

#nameString

Output only. The resource name of the custom bidding script. Corresponds to the JSON property name

Returns:

  • (String)


5838
5839
5840
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5838

def name
  @name
end

#scriptGoogle::Apis::DisplayvideoV3::CustomBiddingScriptRef

The reference to the uploaded custom bidding script file. Corresponds to the JSON property script



5843
5844
5845
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5843

def script
  @script
end

#stateString

Output only. The state of the custom bidding script. Corresponds to the JSON property state

Returns:

  • (String)


5848
5849
5850
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5848

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5855

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @script = args[:script] if args.key?(:script)
  @state = args[:state] if args.key?(:state)
end