Class: Google::Apis::DisplayvideoV3::CustomListGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details of custom list group. All custom list targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomListGroup

Returns a new instance of CustomListGroup.



5956
5957
5958
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV3::CustomListTargetingSetting>

Required. All custom list targeting settings in custom list group. Repeated settings with the same id will be ignored. Corresponds to the JSON property settings



5954
5955
5956
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5954

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5961
5962
5963
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5961

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end