Class: Google::Apis::DisplayvideoV3::DemandGenBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the bid strategy for Demand Gen resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenBiddingStrategy

Returns a new instance of DemandGenBiddingStrategy.



6233
6234
6235
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_bidding_valueFixnum

Output only. The value effectively used by the bidding strategy. This field will be the same as value if set. If value is not set and the strategy is assigned to an ad group, this field will be inherited from the line item's bidding strategy. If type is not DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA or DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS, this field will be 0. Corresponds to the JSON property effectiveBiddingValue

Returns:

  • (Fixnum)


6208
6209
6210
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6208

def effective_bidding_value
  @effective_bidding_value
end

#effective_bidding_value_sourceString

Output only. Source of the effective bidding value. Corresponds to the JSON property effectiveBiddingValueSource

Returns:

  • (String)


6213
6214
6215
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6213

def effective_bidding_value_source
  @effective_bidding_value_source
end

#typeString

Optional. The type of the bidding strategy. This can only be set when assigned to a line item. Ad groups will inherit this value from their line item. Corresponds to the JSON property type

Returns:

  • (String)


6219
6220
6221
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6219

def type
  @type
end

#valueFixnum

Optional. The value used by the bidding strategy. This can be set when assigned to line items or ad groups. This field is only applicable for the following strategy types: * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPC * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS Value of this field is in micros of the advertiser's currency or ROAS value. For example, 1000000 represents 1. 0 standard units of the currency or 100% ROAS value. If not using an applicable strategy, the value of this field will be 0. Corresponds to the JSON property value

Returns:

  • (Fixnum)


6231
6232
6233
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6231

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6238
6239
6240
6241
6242
6243
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6238

def update!(**args)
  @effective_bidding_value = args[:effective_bidding_value] if args.key?(:effective_bidding_value)
  @effective_bidding_value_source = args[:effective_bidding_value_source] if args.key?(:effective_bidding_value_source)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end