Class: Google::Apis::DisplayvideoV3::DemandGenCarouselAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a Demand Gen carousel ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenCarouselAd

Returns a new instance of DemandGenCarouselAd.



6297
6298
6299
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Optional. The business name shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6248
6249
6250
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6248

def business_name
  @business_name
end

#cardsArray<Google::Apis::DisplayvideoV3::CarouselCard>

Required. The list of cards shown on the ad. Corresponds to the JSON property cards



6253
6254
6255
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6253

def cards
  @cards
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6259
6260
6261
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6259

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6264
6265
6266
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6264

def description
  @description
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6270
6271
6272
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6270

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6275
6276
6277
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6275

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6280
6281
6282
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6280

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6285
6286
6287
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6285

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6290
6291
6292
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6290

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6295
6296
6297
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6295

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6302

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @cards = args[:cards] if args.key?(:cards)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end