Class: Google::Apis::DisplayvideoV3::DemandGenProductAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::DemandGenProductAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for a Demand Gen product ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Optional.
-
#call_to_action ⇒ String
Required.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#description ⇒ String
Required.
-
#display_url_breadcrumb1 ⇒ String
Optional.
-
#display_url_breadcrumb2 ⇒ String
Optional.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headline ⇒ String
Required.
-
#logo ⇒ Google::Apis::DisplayvideoV3::ImageAsset
Meta data of an image asset.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenProductAd
constructor
A new instance of DemandGenProductAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenProductAd
Returns a new instance of DemandGenProductAd.
6490 6491 6492 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Optional. The business name shown on the ad. This setting is required unless a
default value is set at the advertiser level. If left unset, the default value
will be applied.
Corresponds to the JSON property businessName
6429 6430 6431 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6429 def business_name @business_name end |
#call_to_action ⇒ String
Required. The call-to-action button shown on the ad. The supported values are:
AUTOMATED*APPLY_NOW*BOOK_NOW*CONTACT_US*DOWNLOAD*GET_QUOTE*LEARN_MORE*SHOP_NOW*SIGN_UP*SUBSCRIBECorresponds to the JSON propertycallToAction
6436 6437 6438 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6436 def call_to_action @call_to_action end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6442 6443 6444 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6442 def custom_parameters @custom_parameters end |
#description ⇒ String
Required. The description of the ad.
Corresponds to the JSON property description
6447 6448 6449 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6447 def description @description end |
#display_url_breadcrumb1 ⇒ String
Optional. The first piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb1
6452 6453 6454 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6452 def @display_url_breadcrumb1 end |
#display_url_breadcrumb2 ⇒ String
Optional. The second piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb2
6457 6458 6459 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6457 def @display_url_breadcrumb2 end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6463 6464 6465 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6463 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6468 6469 6470 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6468 def final_url_suffix @final_url_suffix end |
#headline ⇒ String
Required. The headline of the ad.
Corresponds to the JSON property headline
6473 6474 6475 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6473 def headline @headline end |
#logo ⇒ Google::Apis::DisplayvideoV3::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property logo
6478 6479 6480 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6478 def logo @logo end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6483 6484 6485 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6483 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6488 6489 6490 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6488 def user_specified_tracking_url @user_specified_tracking_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 6508 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6495 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @description = args[:description] if args.key?(:description) @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1) @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headline = args[:headline] if args.key?(:headline) @logo = args[:logo] if args.key?(:logo) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) end |