Class: Google::Apis::DisplayvideoV3::DigitalContentLabelAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Targeting details for digital content label. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DigitalContentLabelAssignedTargetingOptionDetails

Returns a new instance of DigitalContentLabelAssignedTargetingOptionDetails.



6184
6185
6186
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_content_rating_tierString

Required. The display name of the digital content label rating tier to be EXCLUDED. Corresponds to the JSON property excludedContentRatingTier

Returns:

  • (String)


6182
6183
6184
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6182

def excluded_content_rating_tier
  @excluded_content_rating_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6189
6190
6191
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6189

def update!(**args)
  @excluded_content_rating_tier = args[:excluded_content_rating_tier] if args.key?(:excluded_content_rating_tier)
end