Class: Google::Apis::DisplayvideoV3::EditCustomerMatchMembersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Request message for FirstAndThirdPartyAudienceService.EditCustomerMatchMembers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EditCustomerMatchMembersRequest

Returns a new instance of EditCustomerMatchMembersRequest.



7231
7232
7233
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#added_contact_info_listGoogle::Apis::DisplayvideoV3::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property addedContactInfoList



7205
7206
7207
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7205

def added_contact_info_list
  @added_contact_info_list
end

#added_mobile_device_id_listGoogle::Apis::DisplayvideoV3::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property addedMobileDeviceIdList



7211
7212
7213
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7211

def added_mobile_device_id_list
  @added_mobile_device_id_list
end

#advertiser_idFixnum

Required. The ID of the owner advertiser of the updated Customer Match FirstAndThirdPartyAudience. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7217
7218
7219
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7217

def advertiser_id
  @advertiser_id
end

#removed_contact_info_listGoogle::Apis::DisplayvideoV3::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property removedContactInfoList



7223
7224
7225
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7223

def removed_contact_info_list
  @removed_contact_info_list
end

#removed_mobile_device_id_listGoogle::Apis::DisplayvideoV3::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property removedMobileDeviceIdList



7229
7230
7231
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7229

def removed_mobile_device_id_list
  @removed_mobile_device_id_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7236
7237
7238
7239
7240
7241
7242
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7236

def update!(**args)
  @added_contact_info_list = args[:added_contact_info_list] if args.key?(:added_contact_info_list)
  @added_mobile_device_id_list = args[:added_mobile_device_id_list] if args.key?(:added_mobile_device_id_list)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @removed_contact_info_list = args[:removed_contact_info_list] if args.key?(:removed_contact_info_list)
  @removed_mobile_device_id_list = args[:removed_mobile_device_id_list] if args.key?(:removed_mobile_device_id_list)
end