Class: Google::Apis::DisplayvideoV3::ExchangeConfigEnabledExchange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

An enabled exchange in the partner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangeConfigEnabledExchange

Returns a new instance of ExchangeConfigEnabledExchange.



7303
7304
7305
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exchangeString

The enabled exchange. Corresponds to the JSON property exchange

Returns:

  • (String)


7284
7285
7286
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7284

def exchange
  @exchange
end

Output only. Agency ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerAgencyId

Returns:

  • (String)


7290
7291
7292
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7290

def google_ad_manager_agency_id
  @google_ad_manager_agency_id
end

Output only. Network ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerBuyerNetworkId

Returns:

  • (String)


7296
7297
7298
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7296

def google_ad_manager_buyer_network_id
  @google_ad_manager_buyer_network_id
end

#seat_idString

Output only. Seat ID of the enabled exchange. Corresponds to the JSON property seatId

Returns:

  • (String)


7301
7302
7303
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7301

def seat_id
  @seat_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7308
7309
7310
7311
7312
7313
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7308

def update!(**args)
  @exchange = args[:exchange] if args.key?(:exchange)
  @google_ad_manager_agency_id = args[:google_ad_manager_agency_id] if args.key?(:google_ad_manager_agency_id)
  @google_ad_manager_buyer_network_id = args[:google_ad_manager_buyer_network_id] if args.key?(:google_ad_manager_buyer_network_id)
  @seat_id = args[:seat_id] if args.key?(:seat_id)
end