Class: Google::Apis::DisplayvideoV3::ExitEvent
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ExitEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Exit event of the creative.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#reporting_name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExitEvent
constructor
A new instance of ExitEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExitEvent
Returns a new instance of ExitEvent.
7397 7398 7399 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. The name of the click tag of the exit event. The name must be unique
within one creative. Leave it empty or unset for creatives containing image
assets only.
Corresponds to the JSON property name
7378 7379 7380 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7378 def name @name end |
#reporting_name ⇒ String
Optional. The name used to identify this event in reports. Leave it empty or
unset for creatives containing image assets only.
Corresponds to the JSON property reportingName
7384 7385 7386 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7384 def reporting_name @reporting_name end |
#type ⇒ String
Required. The type of the exit event.
Corresponds to the JSON property type
7389 7390 7391 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7389 def type @type end |
#url ⇒ String
Required. The click through URL of the exit event. This is required when type
is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP
Corresponds to the JSON property url
7395 7396 7397 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7395 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7402 7403 7404 7405 7406 7407 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7402 def update!(**args) @name = args[:name] if args.key?(:name) @reporting_name = args[:reporting_name] if args.key?(:reporting_name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |