Class: Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Describes a first or third party audience list used for targeting. First party audiences are created via usage of client data. Third party audiences are provided by Third Party data providers and can only be licensed to customers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstAndThirdPartyAudience

Returns a new instance of FirstAndThirdPartyAudience.



7685
7686
7687
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_display_audience_sizeFixnum

Output only. The estimated audience size for the Display network in the past month. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property activeDisplayAudienceSize

Returns:

  • (Fixnum)


7568
7569
7570
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7568

def active_display_audience_size
  @active_display_audience_size
end

#app_idString

The app_id matches with the type of the mobile_device_ids being uploaded. Only applicable to audience_type CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property appId

Returns:

  • (String)


7574
7575
7576
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7574

def app_id
  @app_id
end

#audience_sourceString

Output only. The source of the audience. Corresponds to the JSON property audienceSource

Returns:

  • (String)


7579
7580
7581
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7579

def audience_source
  @audience_source
end

#audience_typeString

The type of the audience. Corresponds to the JSON property audienceType

Returns:

  • (String)


7584
7585
7586
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7584

def audience_type
  @audience_type
end

#contact_info_listGoogle::Apis::DisplayvideoV3::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property contactInfoList



7590
7591
7592
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7590

def contact_info_list
  @contact_info_list
end

#descriptionString

The user-provided description of the audience. Only applicable to first party audiences. Corresponds to the JSON property description

Returns:

  • (String)


7596
7597
7598
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7596

def description
  @description
end

#display_audience_sizeFixnum

Output only. The estimated audience size for the Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property displayAudienceSize

Returns:

  • (Fixnum)


7604
7605
7606
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7604

def display_audience_size
  @display_audience_size
end

#display_desktop_audience_sizeFixnum

Output only. The estimated desktop audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayDesktopAudienceSize

Returns:

  • (Fixnum)


7613
7614
7615
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7613

def display_desktop_audience_size
  @display_desktop_audience_size
end

#display_mobile_app_audience_sizeFixnum

Output only. The estimated mobile app audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileAppAudienceSize

Returns:

  • (Fixnum)


7622
7623
7624
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7622

def display_mobile_app_audience_size
  @display_mobile_app_audience_size
end

#display_mobile_web_audience_sizeFixnum

Output only. The estimated mobile web audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileWebAudienceSize

Returns:

  • (Fixnum)


7631
7632
7633
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7631

def display_mobile_web_audience_size
  @display_mobile_web_audience_size
end

#display_nameString

The display name of the first and third party audience. Corresponds to the JSON property displayName

Returns:

  • (String)


7636
7637
7638
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7636

def display_name
  @display_name
end

#first_and_third_party_audience_idFixnum

Output only. The unique ID of the first and third party audience. Assigned by the system. Corresponds to the JSON property firstAndThirdPartyAudienceId

Returns:

  • (Fixnum)


7642
7643
7644
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7642

def first_and_third_party_audience_id
  @first_and_third_party_audience_id
end

#first_and_third_party_audience_typeString

Whether the audience is a first or third party audience. Corresponds to the JSON property firstAndThirdPartyAudienceType

Returns:

  • (String)


7647
7648
7649
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7647

def first_and_third_party_audience_type
  @first_and_third_party_audience_type
end

#gmail_audience_sizeFixnum

Output only. The estimated audience size for Gmail network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property gmailAudienceSize

Returns:

  • (Fixnum)


7655
7656
7657
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7655

def gmail_audience_size
  @gmail_audience_size
end

#membership_duration_daysFixnum

The duration in days that an entry remains in the audience after the qualifying event. The set value must be greater than 0 and less than or equal to 540. Only applicable to first party audiences. This field is required if one of the following audience_type is used: * CUSTOMER_MATCH_CONTACT_INFO * CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property membershipDurationDays

Returns:

  • (Fixnum)


7664
7665
7666
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7664

def membership_duration_days
  @membership_duration_days
end

#mobile_device_id_listGoogle::Apis::DisplayvideoV3::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property mobileDeviceIdList



7670
7671
7672
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7670

def mobile_device_id_list
  @mobile_device_id_list
end

#nameString

Output only. The resource name of the first and third party audience. Corresponds to the JSON property name

Returns:

  • (String)


7675
7676
7677
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7675

def name
  @name
end

#youtube_audience_sizeFixnum

Output only. The estimated audience size for YouTube network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property youtubeAudienceSize

Returns:

  • (Fixnum)


7683
7684
7685
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7683

def youtube_audience_size
  @youtube_audience_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7690
7691
7692
7693
7694
7695
7696
7697
7698
7699
7700
7701
7702
7703
7704
7705
7706
7707
7708
7709
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7690

def update!(**args)
  @active_display_audience_size = args[:active_display_audience_size] if args.key?(:active_display_audience_size)
  @app_id = args[:app_id] if args.key?(:app_id)
  @audience_source = args[:audience_source] if args.key?(:audience_source)
  @audience_type = args[:audience_type] if args.key?(:audience_type)
  @contact_info_list = args[:contact_info_list] if args.key?(:contact_info_list)
  @description = args[:description] if args.key?(:description)
  @display_audience_size = args[:display_audience_size] if args.key?(:display_audience_size)
  @display_desktop_audience_size = args[:display_desktop_audience_size] if args.key?(:display_desktop_audience_size)
  @display_mobile_app_audience_size = args[:display_mobile_app_audience_size] if args.key?(:display_mobile_app_audience_size)
  @display_mobile_web_audience_size = args[:display_mobile_web_audience_size] if args.key?(:display_mobile_web_audience_size)
  @display_name = args[:display_name] if args.key?(:display_name)
  @first_and_third_party_audience_id = args[:first_and_third_party_audience_id] if args.key?(:first_and_third_party_audience_id)
  @first_and_third_party_audience_type = args[:first_and_third_party_audience_type] if args.key?(:first_and_third_party_audience_type)
  @gmail_audience_size = args[:gmail_audience_size] if args.key?(:gmail_audience_size)
  @membership_duration_days = args[:membership_duration_days] if args.key?(:membership_duration_days)
  @mobile_device_id_list = args[:mobile_device_id_list] if args.key?(:mobile_device_id_list)
  @name = args[:name] if args.key?(:name)
  @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size)
end