Class: Google::Apis::DisplayvideoV3::FloodlightActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single Floodlight activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivity

Returns a new instance of FloodlightActivity.



7533
7534
7535
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idsArray<Fixnum>

Output only. IDs of the advertisers that have access to the parent Floodlight group. Only advertisers under the provided partner ID will be listed in this field. Corresponds to the JSON property advertiserIds

Returns:

  • (Array<Fixnum>)


7492
7493
7494
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7492

def advertiser_ids
  @advertiser_ids
end

#display_nameString

Required. The display name of the Floodlight activity. Corresponds to the JSON property displayName

Returns:

  • (String)


7497
7498
7499
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7497

def display_name
  @display_name
end

#floodlight_activity_idFixnum

Output only. The unique ID of the Floodlight activity. Assigned by the system. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


7502
7503
7504
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7502

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_group_idFixnum

Required. Immutable. The ID of the parent Floodlight group. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


7507
7508
7509
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7507

def floodlight_group_id
  @floodlight_group_id
end

#nameString

Output only. The resource name of the Floodlight activity. Corresponds to the JSON property name

Returns:

  • (String)


7512
7513
7514
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7512

def name
  @name
end

#remarketing_configsArray<Google::Apis::DisplayvideoV3::RemarketingConfig>

Output only. A list of configuration objects designating whether remarketing for this Floodlight Activity is enabled and available for a specifc advertiser. If enabled, this Floodlight Activity generates a remarketing user list that is able to be used in targeting under the advertiser. Corresponds to the JSON property remarketingConfigs



7520
7521
7522
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7520

def remarketing_configs
  @remarketing_configs
end

#serving_statusString

Optional. Whether the Floodlight activity is served. Corresponds to the JSON property servingStatus

Returns:

  • (String)


7525
7526
7527
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7525

def serving_status
  @serving_status
end

#ssl_requiredBoolean Also known as: ssl_required?

Output only. Whether tags are required to be compliant. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


7530
7531
7532
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7530

def ssl_required
  @ssl_required
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7538

def update!(**args)
  @advertiser_ids = args[:advertiser_ids] if args.key?(:advertiser_ids)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @name = args[:name] if args.key?(:name)
  @remarketing_configs = args[:remarketing_configs] if args.key?(:remarketing_configs)
  @serving_status = args[:serving_status] if args.key?(:serving_status)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
end