Class: Google::Apis::DisplayvideoV3::FloodlightGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::FloodlightGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single Floodlight group.
Instance Attribute Summary collapse
-
#active_view_config ⇒ Google::Apis::DisplayvideoV3::ActiveViewVideoViewabilityMetricConfig
Configuration for custom Active View video viewability metrics.
-
#custom_variables ⇒ Hash<String,Object>
User-defined custom variables owned by the Floodlight group.
-
#display_name ⇒ String
Required.
-
#floodlight_group_id ⇒ Fixnum
Output only.
-
#lookback_window ⇒ Google::Apis::DisplayvideoV3::LookbackWindow
Specifies how many days into the past to look when determining whether to record a conversion.
-
#name ⇒ String
Output only.
-
#web_tag_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightGroup
constructor
A new instance of FloodlightGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightGroup
Returns a new instance of FloodlightGroup.
7602 7603 7604 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_view_config ⇒ Google::Apis::DisplayvideoV3::ActiveViewVideoViewabilityMetricConfig
Configuration for custom Active View video viewability metrics.
Corresponds to the JSON property activeViewConfig
7557 7558 7559 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7557 def active_view_config @active_view_config end |
#custom_variables ⇒ Hash<String,Object>
User-defined custom variables owned by the Floodlight group. Use custom
Floodlight variables to create reporting data that is tailored to your unique
business needs. Custom Floodlight variables use the keys U1=, U2=, and so
on, and can take any values that you choose to pass to them. You can use them
to track virtually any type of data that you collect about your customers,
such as the genre of movie that a customer purchases, the country to which the
item is shipped, and so on. Custom Floodlight variables may not be used to
pass any data that could be used or recognized as personally identifiable
information (PII). Example: custom_variables fields "U1": value
number_value: 123.4 , "U2": value string_value: "MyVariable2" , "U3":
value string_value: "MyVariable3" `Acceptable values for keys are "U1"
through "U100", inclusive. String values must be less than 64 characters long,
and cannot contain the following characters:"<>.
Corresponds to the JSON propertycustomVariables`
7574 7575 7576 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7574 def custom_variables @custom_variables end |
#display_name ⇒ String
Required. The display name of the Floodlight group.
Corresponds to the JSON property displayName
7579 7580 7581 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7579 def display_name @display_name end |
#floodlight_group_id ⇒ Fixnum
Output only. The unique ID of the Floodlight group. Assigned by the system.
Corresponds to the JSON property floodlightGroupId
7584 7585 7586 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7584 def floodlight_group_id @floodlight_group_id end |
#lookback_window ⇒ Google::Apis::DisplayvideoV3::LookbackWindow
Specifies how many days into the past to look when determining whether to
record a conversion.
Corresponds to the JSON property lookbackWindow
7590 7591 7592 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7590 def lookback_window @lookback_window end |
#name ⇒ String
Output only. The resource name of the Floodlight group.
Corresponds to the JSON property name
7595 7596 7597 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7595 def name @name end |
#web_tag_type ⇒ String
Required. The web tag type enabled for the Floodlight group.
Corresponds to the JSON property webTagType
7600 7601 7602 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7600 def web_tag_type @web_tag_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7607 7608 7609 7610 7611 7612 7613 7614 7615 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7607 def update!(**args) @active_view_config = args[:active_view_config] if args.key?(:active_view_config) @custom_variables = args[:custom_variables] if args.key?(:custom_variables) @display_name = args[:display_name] if args.key?(:display_name) @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id) @lookback_window = args[:lookback_window] if args.key?(:lookback_window) @name = args[:name] if args.key?(:name) @web_tag_type = args[:web_tag_type] if args.key?(:web_tag_type) end |