Class: Google::Apis::DisplayvideoV3::GoogleAudienceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details of Google audience group. All Google audience targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAudienceGroup

Returns a new instance of GoogleAudienceGroup.



7852
7853
7854
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV3::GoogleAudienceTargetingSetting>

Required. All Google audience targeting settings in Google audience group. Repeated settings with the same id will be ignored. Corresponds to the JSON property settings



7850
7851
7852
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7850

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7857
7858
7859
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7857

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end