Class: Google::Apis::DisplayvideoV3::InStreamAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::InStreamAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for an in-stream ad.
Instance Attribute Summary collapse
-
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV3::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
-
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InStreamAd
constructor
A new instance of InStreamAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InStreamAd
Returns a new instance of InStreamAd.
8521 8522 8523 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV3::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
Corresponds to the JSON property commonInStreamAttribute
8514 8515 8516 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8514 def common_in_stream_attribute @common_in_stream_attribute end |
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Corresponds to the JSON property customParameters
8519 8520 8521 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8519 def custom_parameters @custom_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8526 8527 8528 8529 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8526 def update!(**args) @common_in_stream_attribute = args[:common_in_stream_attribute] if args.key?(:common_in_stream_attribute) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) end |