Class: Google::Apis::DisplayvideoV3::InsertionOrder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single insertion order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrder

Returns a new instance of InsertionOrder.



8333
8334
8335
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the insertion order belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8237
8238
8239
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8237

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV3::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



8242
8243
8244
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8242

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV3::InsertionOrderBudget

Settings that control how insertion order budget is allocated. Corresponds to the JSON property budget



8247
8248
8249
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8247

def budget
  @budget
end

#campaign_idFixnum

Required. Immutable. The unique ID of the campaign that the insertion order belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


8253
8254
8255
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8253

def campaign_id
  @campaign_id
end

#display_nameString

Required. The display name of the insertion order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


8259
8260
8261
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8259

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the insertion order can spend its budget and bid on inventory. * For CreateInsertionOrder method, only ENTITY_STATUS_DRAFT is allowed. To activate an insertion order, use UpdateInsertionOrder method and update the status to ENTITY_STATUS_ACTIVE after creation. * An insertion order cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * An insertion order cannot be set to ENTITY_STATUS_ACTIVE if its parent campaign is not active. Corresponds to the JSON property entityStatus

Returns:

  • (String)


8270
8271
8272
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8270

def entity_status
  @entity_status
end

#frequency_capGoogle::Apis::DisplayvideoV3::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



8276
8277
8278
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8276

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Output only. The unique ID of the insertion order. Assigned by the system. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


8281
8282
8283
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8281

def insertion_order_id
  @insertion_order_id
end

#insertion_order_typeString

Optional. The type of insertion order. If this field is unspecified in creation, the value defaults to RTB. Corresponds to the JSON property insertionOrderType

Returns:

  • (String)


8287
8288
8289
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8287

def insertion_order_type
  @insertion_order_type
end

#integration_detailsGoogle::Apis::DisplayvideoV3::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



8292
8293
8294
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8292

def integration_details
  @integration_details
end

#kpiGoogle::Apis::DisplayvideoV3::Kpi

Settings that control the key performance indicator, or KPI, of an insertion order. Corresponds to the JSON property kpi



8298
8299
8300
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8298

def kpi
  @kpi
end

#nameString

Output only. The resource name of the insertion order. Corresponds to the JSON property name

Returns:

  • (String)


8303
8304
8305
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8303

def name
  @name
end

#optimization_objectiveString

Optional. Required. The optimization objective of the insertion order. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


8308
8309
8310
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8308

def optimization_objective
  @optimization_objective
end

#pacingGoogle::Apis::DisplayvideoV3::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



8313
8314
8315
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8313

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV3::PartnerCost>

Optional. The partner costs associated with the insertion order. If absent or empty in CreateInsertionOrder method, the newly created insertion order will inherit partner costs from the partner settings. Corresponds to the JSON property partnerCosts



8320
8321
8322
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8320

def partner_costs
  @partner_costs
end

#reservation_typeString

Output only. The reservation type of the insertion order. Corresponds to the JSON property reservationType

Returns:

  • (String)


8325
8326
8327
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8325

def reservation_type
  @reservation_type
end

#update_timeString

Output only. The timestamp when the insertion order was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


8331
8332
8333
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8331

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8338

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @insertion_order_type = args[:insertion_order_type] if args.key?(:insertion_order_type)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @kpi = args[:kpi] if args.key?(:kpi)
  @name = args[:name] if args.key?(:name)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end