Class: Google::Apis::DisplayvideoV3::InsertionOrderBudget
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::InsertionOrderBudget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings that control how insertion order budget is allocated.
Instance Attribute Summary collapse
-
#automation_type ⇒ String
Optional.
-
#budget_segments ⇒ Array<Google::Apis::DisplayvideoV3::InsertionOrderBudgetSegment>
Required.
-
#budget_unit ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertionOrderBudget
constructor
A new instance of InsertionOrderBudget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertionOrderBudget
Returns a new instance of InsertionOrderBudget.
8684 8685 8686 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automation_type ⇒ String
Optional. The type of automation used to manage bid and budget for the
insertion order. If this field is unspecified in creation, the value defaults
to INSERTION_ORDER_AUTOMATION_TYPE_NONE.
Corresponds to the JSON property automationType
8670 8671 8672 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8670 def automation_type @automation_type end |
#budget_segments ⇒ Array<Google::Apis::DisplayvideoV3::InsertionOrderBudgetSegment>
Required. The list of budget segments. Use a budget segment to specify a
specific budget for a given period of time an insertion order is running.
Corresponds to the JSON property budgetSegments
8676 8677 8678 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8676 def budget_segments @budget_segments end |
#budget_unit ⇒ String
Required. Immutable. The budget unit specifies whether the budget is currency
based or impression based.
Corresponds to the JSON property budgetUnit
8682 8683 8684 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8682 def budget_unit @budget_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8689 8690 8691 8692 8693 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8689 def update!(**args) @automation_type = args[:automation_type] if args.key?(:automation_type) @budget_segments = args[:budget_segments] if args.key?(:budget_segments) @budget_unit = args[:budget_unit] if args.key?(:budget_unit) end |