Class: Google::Apis::DisplayvideoV3::InsertionOrderBudgetSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the budget of a single budget segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrderBudgetSegment

Returns a new instance of InsertionOrderBudgetSegment.



8416
8417
8418
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_amount_microsFixnum

Required. The budget amount the insertion order will spend for the given date_range. The amount is in micros. Must be greater than 0. For example, 500000000 represents 500 standard units of the currency. Corresponds to the JSON property budgetAmountMicros

Returns:

  • (Fixnum)


8396
8397
8398
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8396

def budget_amount_micros
  @budget_amount_micros
end

#campaign_budget_idFixnum

Optional. The budget_id of the campaign budget that this insertion order budget segment is a part of. Corresponds to the JSON property campaignBudgetId

Returns:

  • (Fixnum)


8402
8403
8404
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8402

def campaign_budget_id
  @campaign_budget_id
end

#date_rangeGoogle::Apis::DisplayvideoV3::DateRange

A date range. Corresponds to the JSON property dateRange



8407
8408
8409
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8407

def date_range
  @date_range
end

#descriptionString

Optional. The budget segment description. It can be used to enter Purchase Order information for each budget segment and have that information printed on the invoices. Must be UTF-8 encoded. Corresponds to the JSON property description

Returns:

  • (String)


8414
8415
8416
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8414

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8421
8422
8423
8424
8425
8426
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8421

def update!(**args)
  @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros)
  @campaign_budget_id = args[:campaign_budget_id] if args.key?(:campaign_budget_id)
  @date_range = args[:date_range] if args.key?(:date_range)
  @description = args[:description] if args.key?(:description)
end