Class: Google::Apis::DisplayvideoV3::InventorySourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::InventorySourceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
The status related settings of the inventory source.
Instance Attribute Summary collapse
-
#config_status ⇒ String
Output only.
-
#entity_pause_reason ⇒ String
The user-provided reason for pausing this inventory source.
-
#entity_status ⇒ String
Whether or not the inventory source is servable.
-
#seller_pause_reason ⇒ String
Output only.
-
#seller_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InventorySourceStatus
constructor
A new instance of InventorySourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InventorySourceStatus
Returns a new instance of InventorySourceStatus.
8602 8603 8604 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_status ⇒ String
Output only. The configuration status of the inventory source. Only applicable
for guaranteed inventory sources. Acceptable values are
INVENTORY_SOURCE_CONFIG_STATUS_PENDING and
INVENTORY_SOURCE_CONFIG_STATUS_COMPLETED. An inventory source must be
configured (fill in the required fields, choose creatives, and select a
default campaign) before it can serve.
Corresponds to the JSON property configStatus
8572 8573 8574 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8572 def config_status @config_status end |
#entity_pause_reason ⇒ String
The user-provided reason for pausing this inventory source. Must not exceed
100 characters. Only applicable when entity_status is set to
ENTITY_STATUS_PAUSED.
Corresponds to the JSON property entityPauseReason
8579 8580 8581 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8579 def entity_pause_reason @entity_pause_reason end |
#entity_status ⇒ String
Whether or not the inventory source is servable. Acceptable values are
ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED.
Default value is ENTITY_STATUS_ACTIVE.
Corresponds to the JSON property entityStatus
8586 8587 8588 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8586 def entity_status @entity_status end |
#seller_pause_reason ⇒ String
Output only. The seller-provided reason for pausing this inventory source.
Only applicable for inventory sources synced directly from the publishers and
when seller_status is set to ENTITY_STATUS_PAUSED.
Corresponds to the JSON property sellerPauseReason
8593 8594 8595 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8593 def seller_pause_reason @seller_pause_reason end |
#seller_status ⇒ String
Output only. The status set by the seller for the inventory source. Only
applicable for inventory sources synced directly from the publishers.
Acceptable values are ENTITY_STATUS_ACTIVE and ENTITY_STATUS_PAUSED.
Corresponds to the JSON property sellerStatus
8600 8601 8602 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8600 def seller_status @seller_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8607 8608 8609 8610 8611 8612 8613 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8607 def update!(**args) @config_status = args[:config_status] if args.key?(:config_status) @entity_pause_reason = args[:entity_pause_reason] if args.key?(:entity_pause_reason) @entity_status = args[:entity_status] if args.key?(:entity_status) @seller_pause_reason = args[:seller_pause_reason] if args.key?(:seller_pause_reason) @seller_status = args[:seller_status] if args.key?(:seller_status) end |