Class: Google::Apis::DisplayvideoV3::Invoice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single invoice.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Invoice

Returns a new instance of Invoice.



8809
8810
8811
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_invoice_grouping_idString

The budget grouping ID for this invoice. This field will only be set if the invoice level of the corresponding billing profile was set to "Budget invoice grouping ID". Corresponds to the JSON property budgetInvoiceGroupingId

Returns:

  • (String)


8677
8678
8679
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8677

def budget_invoice_grouping_id
  @budget_invoice_grouping_id
end

#budget_summariesArray<Google::Apis::DisplayvideoV3::BudgetSummary>

The list of summarized information for each budget associated with this invoice. This field will only be set if the invoice detail level of the corresponding billing profile was set to "Budget level PO". Corresponds to the JSON property budgetSummaries



8684
8685
8686
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8684

def budget_summaries
  @budget_summaries
end

#corrected_invoice_idString

The ID of the original invoice being adjusted by this invoice, if applicable. May appear on the invoice PDF as Reference invoice number. If replaced_invoice_ids is set, this field will be empty. Corresponds to the JSON property correctedInvoiceId

Returns:

  • (String)


8691
8692
8693
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8691

def corrected_invoice_id
  @corrected_invoice_id
end

#currency_codeString

The currency used in the invoice in ISO 4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


8696
8697
8698
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8696

def currency_code
  @currency_code
end

#display_nameString

The display name of the invoice. Corresponds to the JSON property displayName

Returns:

  • (String)


8701
8702
8703
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8701

def display_name
  @display_name
end

#due_dateGoogle::Apis::DisplayvideoV3::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property dueDate



8713
8714
8715
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8713

def due_date
  @due_date
end

#invoice_idString

The unique ID of the invoice. Corresponds to the JSON property invoiceId

Returns:

  • (String)


8718
8719
8720
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8718

def invoice_id
  @invoice_id
end

#invoice_typeString

The type of invoice document. Corresponds to the JSON property invoiceType

Returns:

  • (String)


8723
8724
8725
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8723

def invoice_type
  @invoice_type
end

#issue_dateGoogle::Apis::DisplayvideoV3::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property issueDate



8735
8736
8737
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8735

def issue_date
  @issue_date
end

#nameString

The resource name of the invoice. Corresponds to the JSON property name

Returns:

  • (String)


8740
8741
8742
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8740

def name
  @name
end

#non_budget_microsFixnum

The total amount of costs or adjustments not tied to a particular budget, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property nonBudgetMicros

Returns:

  • (Fixnum)


8747
8748
8749
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8747

def non_budget_micros
  @non_budget_micros
end

#payments_account_idString

The ID of the payments account the invoice belongs to. Appears on the invoice PDF as Billing Account Number. Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


8753
8754
8755
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8753

def 
  @payments_account_id
end

#payments_profile_idString

The ID of the payments profile the invoice belongs to. Appears on the invoice PDF as Billing ID. Corresponds to the JSON property paymentsProfileId

Returns:

  • (String)


8759
8760
8761
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8759

def payments_profile_id
  @payments_profile_id
end

#pdf_urlString

The URL to download a PDF copy of the invoice. This URL is user specific and requires a valid OAuth 2.0 access token to access. The access token must be provided in an Authorization: Bearer HTTP header and be authorized for one of the following scopes: * https://www.googleapis.com/auth/display-video- mediaplanning * https://www.googleapis.com/auth/display-video The URL will be valid for 7 days after retrieval of this invoice object or until this invoice is retrieved again. Corresponds to the JSON property pdfUrl

Returns:

  • (String)


8770
8771
8772
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8770

def pdf_url
  @pdf_url
end

#purchase_order_numberString

Purchase order number associated with the invoice. Corresponds to the JSON property purchaseOrderNumber

Returns:

  • (String)


8775
8776
8777
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8775

def purchase_order_number
  @purchase_order_number
end

#replaced_invoice_idsArray<String>

The ID(s) of any originally issued invoice that is being cancelled by this invoice, if applicable. Multiple invoices may be listed if those invoices are being consolidated into a single invoice. May appear on invoice PDF as Replaced invoice numbers. If corrected_invoice_id is set, this field will be empty. Corresponds to the JSON property replacedInvoiceIds

Returns:

  • (Array<String>)


8784
8785
8786
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8784

def replaced_invoice_ids
  @replaced_invoice_ids
end

#service_date_rangeGoogle::Apis::DisplayvideoV3::DateRange

A date range. Corresponds to the JSON property serviceDateRange



8789
8790
8791
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8789

def service_date_range
  @service_date_range
end

#subtotal_amount_microsFixnum

The pre-tax subtotal amount, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


8795
8796
8797
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8795

def subtotal_amount_micros
  @subtotal_amount_micros
end

#total_amount_microsFixnum

The invoice total amount, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


8801
8802
8803
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8801

def total_amount_micros
  @total_amount_micros
end

#total_tax_amount_microsFixnum

The sum of all taxes in invoice, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property totalTaxAmountMicros

Returns:

  • (Fixnum)


8807
8808
8809
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8807

def total_tax_amount_micros
  @total_tax_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8814

def update!(**args)
  @budget_invoice_grouping_id = args[:budget_invoice_grouping_id] if args.key?(:budget_invoice_grouping_id)
  @budget_summaries = args[:budget_summaries] if args.key?(:budget_summaries)
  @corrected_invoice_id = args[:corrected_invoice_id] if args.key?(:corrected_invoice_id)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @display_name = args[:display_name] if args.key?(:display_name)
  @due_date = args[:due_date] if args.key?(:due_date)
  @invoice_id = args[:invoice_id] if args.key?(:invoice_id)
  @invoice_type = args[:invoice_type] if args.key?(:invoice_type)
  @issue_date = args[:issue_date] if args.key?(:issue_date)
  @name = args[:name] if args.key?(:name)
  @non_budget_micros = args[:non_budget_micros] if args.key?(:non_budget_micros)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id)
  @pdf_url = args[:pdf_url] if args.key?(:pdf_url)
  @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number)
  @replaced_invoice_ids = args[:replaced_invoice_ids] if args.key?(:replaced_invoice_ids)
  @service_date_range = args[:service_date_range] if args.key?(:service_date_range)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
  @total_tax_amount_micros = args[:total_tax_amount_micros] if args.key?(:total_tax_amount_micros)
end