Class: Google::Apis::DisplayvideoV3::LineItemAssignedTargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Wrapper object associating an assigned_targeting_option resource and the line item it is assigned to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItemAssignedTargetingOption

Returns a new instance of LineItemAssignedTargetingOption.



9521
9522
9523
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_targeting_optionGoogle::Apis::DisplayvideoV3::AssignedTargetingOption

A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings. Corresponds to the JSON property assignedTargetingOption



9514
9515
9516
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9514

def assigned_targeting_option
  @assigned_targeting_option
end

#line_item_idFixnum

The ID of the line item the assigned targeting option is assigned to. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


9519
9520
9521
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9519

def line_item_id
  @line_item_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9526
9527
9528
9529
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9526

def update!(**args)
  @assigned_targeting_option = args[:assigned_targeting_option] if args.key?(:assigned_targeting_option)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
end