Class: Google::Apis::DisplayvideoV3::ListAdGroupAdsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdGroupAdsResponse

Returns a new instance of ListAdGroupAdsResponse.



9251
9252
9253
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adsArray<Google::Apis::DisplayvideoV3::AdGroupAd>

The list of ads. This list will be absent if empty. Corresponds to the JSON property adGroupAds



9242
9243
9244
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9242

def ad_group_ads
  @ad_group_ads
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdGroupAds method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9249
9250
9251
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9249

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9256
9257
9258
9259
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9256

def update!(**args)
  @ad_group_ads = args[:ad_group_ads] if args.key?(:ad_group_ads)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end