Class: Google::Apis::DisplayvideoV3::ListAdGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdGroupsResponse

Returns a new instance of ListAdGroupsResponse.



9306
9307
9308
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupsArray<Google::Apis::DisplayvideoV3::AdGroup>

The list of ad groups. This list will be absent if empty. Corresponds to the JSON property adGroups



9297
9298
9299
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9297

def ad_groups
  @ad_groups
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdGroups method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9304
9305
9306
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9304

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9311
9312
9313
9314
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9311

def update!(**args)
  @ad_groups = args[:ad_groups] if args.key?(:ad_groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end