Class: Google::Apis::DisplayvideoV3::ListAdvertisersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdvertisersResponse

Returns a new instance of ListAdvertisersResponse.



9727
9728
9729
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertisersArray<Google::Apis::DisplayvideoV3::Advertiser>

The list of advertisers. This list will be absent if empty. Corresponds to the JSON property advertisers



9718
9719
9720
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9718

def advertisers
  @advertisers
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdvertisers method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9725
9726
9727
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9725

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9732
9733
9734
9735
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9732

def update!(**args)
  @advertisers = args[:advertisers] if args.key?(:advertisers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end