Class: Google::Apis::DisplayvideoV3::ListCampaignsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListCampaignsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#campaigns ⇒ Array<Google::Apis::DisplayvideoV3::Campaign>
The list of campaigns.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCampaignsResponse
constructor
A new instance of ListCampaignsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCampaignsResponse
Returns a new instance of ListCampaignsResponse.
9443 9444 9445 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaigns ⇒ Array<Google::Apis::DisplayvideoV3::Campaign>
The list of campaigns. This list will be absent if empty.
Corresponds to the JSON property campaigns
9434 9435 9436 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9434 def campaigns @campaigns end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCampaigns method to retrieve
the next page of results.
Corresponds to the JSON property nextPageToken
9441 9442 9443 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9441 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9448 9449 9450 9451 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9448 def update!(**args) @campaigns = args[:campaigns] if args.key?(:campaigns) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |