Class: Google::Apis::DisplayvideoV3::ListGoogleAudiencesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGoogleAudiencesResponse

Returns a new instance of ListGoogleAudiencesResponse.



9748
9749
9750
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_audiencesArray<Google::Apis::DisplayvideoV3::GoogleAudience>

The list of Google audiences. This list will be absent if empty. Corresponds to the JSON property googleAudiences



9739
9740
9741
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9739

def google_audiences
  @google_audiences
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListGoogleAudiences method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9746
9747
9748
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9746

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9753
9754
9755
9756
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9753

def update!(**args)
  @google_audiences = args[:google_audiences] if args.key?(:google_audiences)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end