Class: Google::Apis::DisplayvideoV3::MaximizeSpendBidStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaximizeSpendBidStrategy

Returns a new instance of MaximizeSpendBidStrategy.



10349
10350
10351
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_bidding_algorithm_idFixnum

The ID of the Custom Bidding Algorithm used by this strategy. Only applicable when performance_goal_type is set to BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO. Assigning a custom bidding algorithm that uses floodlight activities not identified in floodlightActivityConfigs will return an error. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


10326
10327
10328
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10326

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#max_average_cpm_bid_amount_microsFixnum

The maximum average CPM that may be bid, in micros of the advertiser's currency. Must be greater than or equal to a billable unit of the given currency. For example, 1500000 represents 1.5 standard units of the currency. Corresponds to the JSON property maxAverageCpmBidAmountMicros

Returns:

  • (Fixnum)


10333
10334
10335
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10333

def max_average_cpm_bid_amount_micros
  @max_average_cpm_bid_amount_micros
end

#performance_goal_typeString

Required. The type of the performance goal that the bidding strategy tries to minimize while spending the full budget. BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM is not supported for this strategy. Corresponds to the JSON property performanceGoalType

Returns:

  • (String)


10341
10342
10343
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10341

def performance_goal_type
  @performance_goal_type
end

#raise_bid_for_dealsBoolean Also known as: raise_bid_for_deals?

Whether the strategy takes deal floor prices into account. Corresponds to the JSON property raiseBidForDeals

Returns:

  • (Boolean)


10346
10347
10348
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10346

def raise_bid_for_deals
  @raise_bid_for_deals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10354
10355
10356
10357
10358
10359
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10354

def update!(**args)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @max_average_cpm_bid_amount_micros = args[:max_average_cpm_bid_amount_micros] if args.key?(:max_average_cpm_bid_amount_micros)
  @performance_goal_type = args[:performance_goal_type] if args.key?(:performance_goal_type)
  @raise_bid_for_deals = args[:raise_bid_for_deals] if args.key?(:raise_bid_for_deals)
end