Class: Google::Apis::DisplayvideoV3::NegativeKeywordList
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::NegativeKeywordList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A list of negative keywords used for targeting.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#negative_keyword_list_id ⇒ Fixnum
Output only.
-
#targeted_line_item_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NegativeKeywordList
constructor
A new instance of NegativeKeywordList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NegativeKeywordList
Returns a new instance of NegativeKeywordList.
10545 10546 10547 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the negative keyword list belongs
to.
Corresponds to the JSON property advertiserId
10520 10521 10522 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10520 def advertiser_id @advertiser_id end |
#display_name ⇒ String
Required. The display name of the negative keyword list. Must be UTF-8 encoded
with a maximum size of 255 bytes.
Corresponds to the JSON property displayName
10526 10527 10528 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10526 def display_name @display_name end |
#name ⇒ String
Output only. The resource name of the negative keyword list.
Corresponds to the JSON property name
10531 10532 10533 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10531 def name @name end |
#negative_keyword_list_id ⇒ Fixnum
Output only. The unique ID of the negative keyword list. Assigned by the
system.
Corresponds to the JSON property negativeKeywordListId
10537 10538 10539 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10537 def negative_keyword_list_id @negative_keyword_list_id end |
#targeted_line_item_count ⇒ Fixnum
Output only. Number of line items that are directly targeting this negative
keyword list.
Corresponds to the JSON property targetedLineItemCount
10543 10544 10545 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10543 def targeted_line_item_count @targeted_line_item_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10550 10551 10552 10553 10554 10555 10556 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10550 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @negative_keyword_list_id = args[:negative_keyword_list_id] if args.key?(:negative_keyword_list_id) @targeted_line_item_count = args[:targeted_line_item_count] if args.key?(:targeted_line_item_count) end |