Class: Google::Apis::DisplayvideoV3::ParentEntityFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A filtering option that filters on selected file types belonging to a chosen set of filter entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParentEntityFilter

Returns a new instance of ParentEntityFilter.



11321
11322
11323
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_typeArray<String>

Required. File types that will be returned. Corresponds to the JSON property fileType

Returns:

  • (Array<String>)


11308
11309
11310
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11308

def file_type
  @file_type
end

#filter_idsArray<Fixnum>

The IDs of the specified filter type. This is used to filter entities to fetch. If filter type is not FILTER_TYPE_NONE, at least one ID must be specified. Corresponds to the JSON property filterIds

Returns:

  • (Array<Fixnum>)


11314
11315
11316
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11314

def filter_ids
  @filter_ids
end

#filter_typeString

Required. Filter type used to filter fetched entities. Corresponds to the JSON property filterType

Returns:

  • (String)


11319
11320
11321
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11319

def filter_type
  @filter_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11326
11327
11328
11329
11330
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11326

def update!(**args)
  @file_type = args[:file_type] if args.key?(:file_type)
  @filter_ids = args[:filter_ids] if args.key?(:filter_ids)
  @filter_type = args[:filter_type] if args.key?(:filter_type)
end