Class: Google::Apis::DisplayvideoV3::PartnerCost
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::PartnerCost
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings that control a partner cost. A partner cost is any type of expense involved in running a campaign, other than the costs of purchasing impressions (which is called the media cost) and using third-party audience segment data ( data fee). Some examples of partner costs include the fees for using DV360, a third-party ad server, or a third-party ad serving verification service.
Instance Attribute Summary collapse
-
#cost_type ⇒ String
Required.
-
#fee_amount ⇒ Fixnum
The CPM fee amount in micros of advertiser's currency.
-
#fee_percentage_millis ⇒ Fixnum
The media fee percentage in millis (1/1000 of a percent).
-
#fee_type ⇒ String
Required.
-
#invoice_type ⇒ String
The invoice type for this partner cost.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartnerCost
constructor
A new instance of PartnerCost.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartnerCost
Returns a new instance of PartnerCost.
11164 11165 11166 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost_type ⇒ String
Required. The type of the partner cost.
Corresponds to the JSON property costType
11135 11136 11137 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11135 def cost_type @cost_type end |
#fee_amount ⇒ Fixnum
The CPM fee amount in micros of advertiser's currency. Applicable when the
fee_type is PARTNER_FEE_TYPE_CPM_FEE. Must be greater than or equal to 0.
For example, for 1.5 standard unit of the advertiser's currency, set this
field to 1500000.
Corresponds to the JSON property feeAmount
11143 11144 11145 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11143 def fee_amount @fee_amount end |
#fee_percentage_millis ⇒ Fixnum
The media fee percentage in millis (1/1000 of a percent). Applicable when the
fee_type is PARTNER_FEE_TYPE_MEDIA_FEE. Must be greater than or equal to 0.
For example: 100 represents 0.1%.
Corresponds to the JSON property feePercentageMillis
11150 11151 11152 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11150 def fee_percentage_millis @fee_percentage_millis end |
#fee_type ⇒ String
Required. The fee type for this partner cost.
Corresponds to the JSON property feeType
11155 11156 11157 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11155 def fee_type @fee_type end |
#invoice_type ⇒ String
The invoice type for this partner cost. * Required when cost_type is one of: -
PARTNER_COST_TYPE_ADLOOX - PARTNER_COST_TYPE_DOUBLE_VERIFY -
PARTNER_COST_TYPE_INTEGRAL_AD_SCIENCE. * Output only for other types.
Corresponds to the JSON property invoiceType
11162 11163 11164 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11162 def invoice_type @invoice_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11169 11170 11171 11172 11173 11174 11175 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11169 def update!(**args) @cost_type = args[:cost_type] if args.key?(:cost_type) @fee_amount = args[:fee_amount] if args.key?(:fee_amount) @fee_percentage_millis = args[:fee_percentage_millis] if args.key?(:fee_percentage_millis) @fee_type = args[:fee_type] if args.key?(:fee_type) @invoice_type = args[:invoice_type] if args.key?(:invoice_type) end |