Class: Google::Apis::DisplayvideoV3::PerformanceGoal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the performance goal of a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerformanceGoal

Returns a new instance of PerformanceGoal.



11297
11298
11299
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#performance_goal_amount_microsFixnum

The goal amount, in micros of the advertiser's currency. Applicable when performance_goal_type is one of: * PERFORMANCE_GOAL_TYPE_CPM * PERFORMANCE_GOAL_TYPE_CPC * PERFORMANCE_GOAL_TYPE_CPA * PERFORMANCE_GOAL_TYPE_CPIAVC * PERFORMANCE_GOAL_TYPE_VCPM For example 1500000 represents 1.5 standard units of the currency. Corresponds to the JSON property performanceGoalAmountMicros

Returns:

  • (Fixnum)


11272
11273
11274
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11272

def performance_goal_amount_micros
  @performance_goal_amount_micros
end

#performance_goal_percentage_microsFixnum

The decimal representation of the goal percentage in micros. Applicable when performance_goal_type is one of: * PERFORMANCE_GOAL_TYPE_CTR * PERFORMANCE_GOAL_TYPE_VIEWABILITY * PERFORMANCE_GOAL_TYPE_CLICK_CVR * PERFORMANCE_GOAL_TYPE_IMPRESSION_CVR * PERFORMANCE_GOAL_TYPE_VTR * PERFORMANCE_GOAL_TYPE_AUDIO_COMPLETION_RATE * PERFORMANCE_GOAL_TYPE_VIDEO_COMPLETION_RATE For example, 70000 represents 7% ( decimal 0.07). Corresponds to the JSON property performanceGoalPercentageMicros

Returns:

  • (Fixnum)


11283
11284
11285
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11283

def performance_goal_percentage_micros
  @performance_goal_percentage_micros
end

#performance_goal_stringString

A key performance indicator (KPI) string, which can be empty. Must be UTF-8 encoded with a length of no more than 100 characters. Applicable when performance_goal_type is set to PERFORMANCE_GOAL_TYPE_OTHER. Corresponds to the JSON property performanceGoalString

Returns:

  • (String)


11290
11291
11292
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11290

def performance_goal_string
  @performance_goal_string
end

#performance_goal_typeString

Required. The type of the performance goal. Corresponds to the JSON property performanceGoalType

Returns:

  • (String)


11295
11296
11297
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11295

def performance_goal_type
  @performance_goal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11302
11303
11304
11305
11306
11307
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11302

def update!(**args)
  @performance_goal_amount_micros = args[:performance_goal_amount_micros] if args.key?(:performance_goal_amount_micros)
  @performance_goal_percentage_micros = args[:performance_goal_percentage_micros] if args.key?(:performance_goal_percentage_micros)
  @performance_goal_string = args[:performance_goal_string] if args.key?(:performance_goal_string)
  @performance_goal_type = args[:performance_goal_type] if args.key?(:performance_goal_type)
end