Class: Google::Apis::DisplayvideoV3::PrismaConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::PrismaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings specific to the Mediaocean Prisma tool.
Instance Attribute Summary collapse
-
#prisma_cpe_code ⇒ Google::Apis::DisplayvideoV3::PrismaCpeCode
Google Payments Center supports searching and filtering on the component fields of this code.
-
#prisma_type ⇒ String
Required.
-
#supplier ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrismaConfig
constructor
A new instance of PrismaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrismaConfig
Returns a new instance of PrismaConfig.
11881 11882 11883 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prisma_cpe_code ⇒ Google::Apis::DisplayvideoV3::PrismaCpeCode
Google Payments Center supports searching and filtering on the component
fields of this code.
Corresponds to the JSON property prismaCpeCode
11869 11870 11871 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11869 def prisma_cpe_code @prisma_cpe_code end |
#prisma_type ⇒ String
Required. The Prisma type.
Corresponds to the JSON property prismaType
11874 11875 11876 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11874 def prisma_type @prisma_type end |
#supplier ⇒ String
Required. The entity allocated this budget (DSP, site, etc.).
Corresponds to the JSON property supplier
11879 11880 11881 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11879 def supplier @supplier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11886 11887 11888 11889 11890 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11886 def update!(**args) @prisma_cpe_code = args[:prisma_cpe_code] if args.key?(:prisma_cpe_code) @prisma_type = args[:prisma_type] if args.key?(:prisma_type) @supplier = args[:supplier] if args.key?(:supplier) end |