Class: Google::Apis::DisplayvideoV3::RateDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

The rate related settings of the inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RateDetails

Returns a new instance of RateDetails.



11765
11766
11767
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inventory_source_rate_typeString

The rate type. Acceptable values are INVENTORY_SOURCE_RATE_TYPE_CPM_FIXED, INVENTORY_SOURCE_RATE_TYPE_CPM_FLOOR, and INVENTORY_SOURCE_RATE_TYPE_CPD. Corresponds to the JSON property inventorySourceRateType

Returns:

  • (String)


11747
11748
11749
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11747

def inventory_source_rate_type
  @inventory_source_rate_type
end

#minimum_spendGoogle::Apis::DisplayvideoV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property minimumSpend



11752
11753
11754
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11752

def minimum_spend
  @minimum_spend
end

#rateGoogle::Apis::DisplayvideoV3::Money

Represents an amount of money with its currency type. Corresponds to the JSON property rate



11757
11758
11759
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11757

def rate
  @rate
end

#units_purchasedFixnum

Required for guaranteed inventory sources. The number of impressions guaranteed by the seller. Corresponds to the JSON property unitsPurchased

Returns:

  • (Fixnum)


11763
11764
11765
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11763

def units_purchased
  @units_purchased
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11770
11771
11772
11773
11774
11775
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11770

def update!(**args)
  @inventory_source_rate_type = args[:inventory_source_rate_type] if args.key?(:inventory_source_rate_type)
  @minimum_spend = args[:minimum_spend] if args.key?(:minimum_spend)
  @rate = args[:rate] if args.key?(:rate)
  @units_purchased = args[:units_purchased] if args.key?(:units_purchased)
end