Class: Google::Apis::DisplayvideoV3::ReplaceSitesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ReplaceSitesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Request message for SiteService.ReplaceSites.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent channel.
-
#new_sites ⇒ Array<Google::Apis::DisplayvideoV3::Site>
The sites that will replace the existing sites assigned to the channel, specified as a list of Sites.
-
#partner_id ⇒ Fixnum
The ID of the partner that owns the parent channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceSitesRequest
constructor
A new instance of ReplaceSitesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceSitesRequest
Returns a new instance of ReplaceSitesRequest.
11895 11896 11897 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent channel.
Corresponds to the JSON property advertiserId
11882 11883 11884 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11882 def advertiser_id @advertiser_id end |
#new_sites ⇒ Array<Google::Apis::DisplayvideoV3::Site>
The sites that will replace the existing sites assigned to the channel,
specified as a list of Sites.
Corresponds to the JSON property newSites
11888 11889 11890 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11888 def new_sites @new_sites end |
#partner_id ⇒ Fixnum
The ID of the partner that owns the parent channel.
Corresponds to the JSON property partnerId
11893 11894 11895 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11893 def partner_id @partner_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11900 11901 11902 11903 11904 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11900 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @new_sites = args[:new_sites] if args.key?(:new_sites) @partner_id = args[:partner_id] if args.key?(:partner_id) end |