Class: Google::Apis::DisplayvideoV3::ScriptError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

An error message for a custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScriptError

Returns a new instance of ScriptError.



11897
11898
11899
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnFixnum

The column number in the script where the error was thrown. Corresponds to the JSON property column

Returns:

  • (Fixnum)


11880
11881
11882
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11880

def column
  @column
end

#error_codeString

The type of error. Corresponds to the JSON property errorCode

Returns:

  • (String)


11885
11886
11887
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11885

def error_code
  @error_code
end

#error_messageString

The detailed error message. Corresponds to the JSON property errorMessage

Returns:

  • (String)


11890
11891
11892
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11890

def error_message
  @error_message
end

#lineFixnum

The line number in the script where the error was thrown. Corresponds to the JSON property line

Returns:

  • (Fixnum)


11895
11896
11897
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11895

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11902
11903
11904
11905
11906
11907
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11902

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @line = args[:line] if args.key?(:line)
end