Class: Google::Apis::DisplayvideoV3::SearchTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Request message for SearchTargetingOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchTargetingOptionsRequest

Returns a new instance of SearchTargetingOptionsRequest.



12127
12128
12129
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Required. The Advertiser this request is being made in the context of. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


12094
12095
12096
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12094

def advertiser_id
  @advertiser_id
end

#business_chain_search_termsGoogle::Apis::DisplayvideoV3::BusinessChainSearchTerms

Search terms for Business Chain targeting options. At least one of the field should be populated. Corresponds to the JSON property businessChainSearchTerms



12100
12101
12102
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12100

def business_chain_search_terms
  @business_chain_search_terms
end

#geo_region_search_termsGoogle::Apis::DisplayvideoV3::GeoRegionSearchTerms

Search terms for geo region targeting options. Corresponds to the JSON property geoRegionSearchTerms



12105
12106
12107
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12105

def geo_region_search_terms
  @geo_region_search_terms
end

#page_sizeFixnum

Requested page size. Must be between 1 and 200. If unspecified will default to 100. Returns error code INVALID_ARGUMENT if an invalid value is specified. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


12112
12113
12114
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12112

def page_size
  @page_size
end

#page_tokenString

A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to SearchTargetingOptions method. If not specified, the first page of results will be returned. Corresponds to the JSON property pageToken

Returns:

  • (String)


12120
12121
12122
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12120

def page_token
  @page_token
end

#poi_search_termsGoogle::Apis::DisplayvideoV3::PoiSearchTerms

Search terms for POI targeting options. Corresponds to the JSON property poiSearchTerms



12125
12126
12127
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12125

def poi_search_terms
  @poi_search_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12132
12133
12134
12135
12136
12137
12138
12139
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12132

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @business_chain_search_terms = args[:business_chain_search_terms] if args.key?(:business_chain_search_terms)
  @geo_region_search_terms = args[:geo_region_search_terms] if args.key?(:geo_region_search_terms)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @poi_search_terms = args[:poi_search_terms] if args.key?(:poi_search_terms)
end