Class: Google::Apis::DisplayvideoV3::TargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Represents a single targeting option, which is a targetable concept in DV360.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingOption

Returns a new instance of TargetingOption.



12656
12657
12658
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_range_detailsGoogle::Apis::DisplayvideoV3::AgeRangeTargetingOptionDetails

Represents a targetable age range. This will be populated in the age_range_details field when targeting_type is TARGETING_TYPE_AGE_RANGE. Corresponds to the JSON property ageRangeDetails



12408
12409
12410
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12408

def age_range_details
  @age_range_details
end

#app_category_detailsGoogle::Apis::DisplayvideoV3::AppCategoryTargetingOptionDetails

Represents a targetable collection of apps. A collection lets you target dynamic groups of related apps that are maintained by the platform, for example All Apps/Google Play/Games. This will be populated in the app_category_details field when targeting_type is TARGETING_TYPE_APP_CATEGORY . Corresponds to the JSON property appCategoryDetails



12417
12418
12419
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12417

def app_category_details
  @app_category_details
end

#audio_content_type_detailsGoogle::Apis::DisplayvideoV3::AudioContentTypeTargetingOptionDetails

Represents a targetable audio content type. This will be populated in the audio_content_type_details field when targeting_type is TARGETING_TYPE_AUDIO_CONTENT_TYPE. Corresponds to the JSON property audioContentTypeDetails



12424
12425
12426
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12424

def audio_content_type_details
  @audio_content_type_details
end

#authorized_seller_status_detailsGoogle::Apis::DisplayvideoV3::AuthorizedSellerStatusTargetingOptionDetails

Represents a targetable authorized seller status. This will be populated in the authorized_seller_status_details field when targeting_type is TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. Corresponds to the JSON property authorizedSellerStatusDetails



12431
12432
12433
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12431

def authorized_seller_status_details
  @authorized_seller_status_details
end

#browser_detailsGoogle::Apis::DisplayvideoV3::BrowserTargetingOptionDetails

Represents a targetable browser. This will be populated in the browser_details field when targeting_type is TARGETING_TYPE_BROWSER. Corresponds to the JSON property browserDetails



12437
12438
12439
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12437

def browser_details
  @browser_details
end

#business_chain_detailsGoogle::Apis::DisplayvideoV3::BusinessChainTargetingOptionDetails

Represents a targetable business chain within a geo region. This will be populated in the business_chain_details field when targeting_type is TARGETING_TYPE_BUSINESS_CHAIN. Corresponds to the JSON property businessChainDetails



12444
12445
12446
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12444

def business_chain_details
  @business_chain_details
end

#carrier_and_isp_detailsGoogle::Apis::DisplayvideoV3::CarrierAndIspTargetingOptionDetails

Represents a targetable carrier or ISP. This will be populated in the carrier_and_isp_details field of a TargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property carrierAndIspDetails



12451
12452
12453
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12451

def carrier_and_isp_details
  @carrier_and_isp_details
end

#category_detailsGoogle::Apis::DisplayvideoV3::CategoryTargetingOptionDetails

Represents a targetable category. This will be populated in the category_details field of a TargetingOption when targeting_type is TARGETING_TYPE_CATEGORY. Corresponds to the JSON property categoryDetails



12458
12459
12460
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12458

def category_details
  @category_details
end

#content_duration_detailsGoogle::Apis::DisplayvideoV3::ContentDurationTargetingOptionDetails

Represents a targetable content duration. This will be populated in the content_duration_details field when targeting_type is TARGETING_TYPE_CONTENT_DURATION. Corresponds to the JSON property contentDurationDetails



12465
12466
12467
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12465

def content_duration_details
  @content_duration_details
end

#content_genre_detailsGoogle::Apis::DisplayvideoV3::ContentGenreTargetingOptionDetails

Represents a targetable content genre. This will be populated in the content_genre_details field when targeting_type is TARGETING_TYPE_CONTENT_GENRE. Corresponds to the JSON property contentGenreDetails



12472
12473
12474
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12472

def content_genre_details
  @content_genre_details
end

#content_instream_position_detailsGoogle::Apis::DisplayvideoV3::ContentInstreamPositionTargetingOptionDetails

Represents a targetable content instream position, which could be used by video and audio ads. This will be populated in the content_instream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION. Corresponds to the JSON property contentInstreamPositionDetails



12480
12481
12482
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12480

def content_instream_position_details
  @content_instream_position_details
end

#content_outstream_position_detailsGoogle::Apis::DisplayvideoV3::ContentOutstreamPositionTargetingOptionDetails

Represents a targetable content outstream position, which could be used by display and video ads. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION. Corresponds to the JSON property contentOutstreamPositionDetails



12488
12489
12490
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12488

def content_outstream_position_details
  @content_outstream_position_details
end

#content_stream_type_detailsGoogle::Apis::DisplayvideoV3::ContentStreamTypeTargetingOptionDetails

Represents a targetable content stream type. This will be populated in the content_stream_type_details field when targeting_type is TARGETING_TYPE_CONTENT_STREAM_TYPE. Corresponds to the JSON property contentStreamTypeDetails



12495
12496
12497
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12495

def content_stream_type_details
  @content_stream_type_details
end

#content_theme_detailsGoogle::Apis::DisplayvideoV3::ContentThemeTargetingOptionDetails

Represents a targetable content theme. This will be populated in the content_theme_details field of the TargetingOption when targeting_type is TARGETING_TYPE_CONTENT_THEME_EXCLUSION. Corresponds to the JSON property contentThemeDetails



12502
12503
12504
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12502

def content_theme_details
  @content_theme_details
end

#device_make_model_detailsGoogle::Apis::DisplayvideoV3::DeviceMakeModelTargetingOptionDetails

Represents a targetable device make and model. This will be populated in the device_make_model_details field of a TargetingOption when targeting_type is TARGETING_TYPE_DEVICE_MAKE_MODEL. Corresponds to the JSON property deviceMakeModelDetails



12509
12510
12511
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12509

def device_make_model_details
  @device_make_model_details
end

#device_type_detailsGoogle::Apis::DisplayvideoV3::DeviceTypeTargetingOptionDetails

Represents a targetable device type. This will be populated in the device_type_details field of a TargetingOption when targeting_type is TARGETING_TYPE_DEVICE_TYPE. Corresponds to the JSON property deviceTypeDetails



12516
12517
12518
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12516

def device_type_details
  @device_type_details
end

#digital_content_label_detailsGoogle::Apis::DisplayvideoV3::DigitalContentLabelTargetingOptionDetails

Represents a targetable digital content label rating tier. This will be populated in the digital_content_label_details field of the TargetingOption when targeting_type is TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION. Corresponds to the JSON property digitalContentLabelDetails



12523
12524
12525
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12523

def 
  @digital_content_label_details
end

#environment_detailsGoogle::Apis::DisplayvideoV3::EnvironmentTargetingOptionDetails

Represents a targetable environment. This will be populated in the environment_details field of a TargetingOption when targeting_type is TARGETING_TYPE_ENVIRONMENT. Corresponds to the JSON property environmentDetails



12530
12531
12532
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12530

def environment_details
  @environment_details
end

#exchange_detailsGoogle::Apis::DisplayvideoV3::ExchangeTargetingOptionDetails

Represents a targetable exchange. This will be populated in the exchange_details field of a TargetingOption when targeting_type is TARGETING_TYPE_EXCHANGE. Corresponds to the JSON property exchangeDetails



12537
12538
12539
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12537

def exchange_details
  @exchange_details
end

#gender_detailsGoogle::Apis::DisplayvideoV3::GenderTargetingOptionDetails

Represents a targetable gender. This will be populated in the gender_details field of a TargetingOption when targeting_type is TARGETING_TYPE_GENDER. Corresponds to the JSON property genderDetails



12543
12544
12545
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12543

def gender_details
  @gender_details
end

#geo_region_detailsGoogle::Apis::DisplayvideoV3::GeoRegionTargetingOptionDetails

Represents a targetable geographic region. This will be populated in the geo_region_details field when targeting_type is TARGETING_TYPE_GEO_REGION. Corresponds to the JSON property geoRegionDetails



12549
12550
12551
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12549

def geo_region_details
  @geo_region_details
end

#household_income_detailsGoogle::Apis::DisplayvideoV3::HouseholdIncomeTargetingOptionDetails

Represents a targetable household income. This will be populated in the household_income_details field of a TargetingOption when targeting_type is TARGETING_TYPE_HOUSEHOLD_INCOME. Corresponds to the JSON property householdIncomeDetails



12556
12557
12558
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12556

def household_income_details
  @household_income_details
end

#language_detailsGoogle::Apis::DisplayvideoV3::LanguageTargetingOptionDetails

Represents a targetable language. This will be populated in the language_details field when targeting_type is TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property languageDetails



12562
12563
12564
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12562

def language_details
  @language_details
end

#nameString

Output only. The resource name for this targeting option. Corresponds to the JSON property name

Returns:

  • (String)


12567
12568
12569
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12567

def name
  @name
end

#native_content_position_detailsGoogle::Apis::DisplayvideoV3::NativeContentPositionTargetingOptionDetails

Represents a targetable native content position. This will be populated in the native_content_position_details field when targeting_type is TARGETING_TYPE_NATIVE_CONTENT_POSITION. Corresponds to the JSON property nativeContentPositionDetails



12574
12575
12576
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12574

def native_content_position_details
  @native_content_position_details
end

#omid_detailsGoogle::Apis::DisplayvideoV3::OmidTargetingOptionDetails

Represents a targetable Open Measurement enabled inventory type. This will be populated in the omid_details field when targeting_type is TARGETING_TYPE_OMID. Corresponds to the JSON property omidDetails



12581
12582
12583
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12581

def omid_details
  @omid_details
end

#on_screen_position_detailsGoogle::Apis::DisplayvideoV3::OnScreenPositionTargetingOptionDetails

Represents a targetable on screen position, which could be used by display and video ads. This will be populated in the on_screen_position_details field when targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION. Corresponds to the JSON property onScreenPositionDetails



12588
12589
12590
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12588

def on_screen_position_details
  @on_screen_position_details
end

#operating_system_detailsGoogle::Apis::DisplayvideoV3::OperatingSystemTargetingOptionDetails

Represents a targetable operating system. This will be populated in the operating_system_details field of a TargetingOption when targeting_type is TARGETING_TYPE_OPERATING_SYSTEM. Corresponds to the JSON property operatingSystemDetails



12595
12596
12597
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12595

def operating_system_details
  @operating_system_details
end

#parental_status_detailsGoogle::Apis::DisplayvideoV3::ParentalStatusTargetingOptionDetails

Represents a targetable parental status. This will be populated in the parental_status_details field of a TargetingOption when targeting_type is TARGETING_TYPE_PARENTAL_STATUS. Corresponds to the JSON property parentalStatusDetails



12602
12603
12604
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12602

def parental_status_details
  @parental_status_details
end

#poi_detailsGoogle::Apis::DisplayvideoV3::PoiTargetingOptionDetails

Represents a targetable point of interest(POI). This will be populated in the poi_details field when targeting_type is TARGETING_TYPE_POI. Corresponds to the JSON property poiDetails



12608
12609
12610
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12608

def poi_details
  @poi_details
end

#sensitive_category_detailsGoogle::Apis::DisplayvideoV3::SensitiveCategoryTargetingOptionDetails

Represents a targetable sensitive category. This will be populated in the sensitive_category_details field of the TargetingOption when targeting_type is TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION. Corresponds to the JSON property sensitiveCategoryDetails



12615
12616
12617
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12615

def sensitive_category_details
  @sensitive_category_details
end

#sub_exchange_detailsGoogle::Apis::DisplayvideoV3::SubExchangeTargetingOptionDetails

Represents a targetable sub-exchange. This will be populated in the sub_exchange_details field of a TargetingOption when targeting_type is TARGETING_TYPE_SUB_EXCHANGE. Corresponds to the JSON property subExchangeDetails



12622
12623
12624
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12622

def sub_exchange_details
  @sub_exchange_details
end

#targeting_option_idString

Output only. A unique identifier for this targeting option. The tuple targeting_type`, `targeting_option_id will be unique. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


12628
12629
12630
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12628

def targeting_option_id
  @targeting_option_id
end

#targeting_typeString

Output only. The type of this targeting option. Corresponds to the JSON property targetingType

Returns:

  • (String)


12633
12634
12635
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12633

def targeting_type
  @targeting_type
end

#user_rewarded_content_detailsGoogle::Apis::DisplayvideoV3::UserRewardedContentTargetingOptionDetails

Represents a targetable user rewarded content status for video ads only. This will be populated in the user_rewarded_content_details field when targeting_type is TARGETING_TYPE_USER_REWARDED_CONTENT. Corresponds to the JSON property userRewardedContentDetails



12640
12641
12642
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12640

def user_rewarded_content_details
  @user_rewarded_content_details
end

#video_player_size_detailsGoogle::Apis::DisplayvideoV3::VideoPlayerSizeTargetingOptionDetails

Represents a targetable video player size. This will be populated in the video_player_size_details field when targeting_type is TARGETING_TYPE_VIDEO_PLAYER_SIZE. Corresponds to the JSON property videoPlayerSizeDetails



12647
12648
12649
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12647

def video_player_size_details
  @video_player_size_details
end

#viewability_detailsGoogle::Apis::DisplayvideoV3::ViewabilityTargetingOptionDetails

Represents a targetable viewability. This will be populated in the viewability_details field of a TargetingOption when targeting_type is TARGETING_TYPE_VIEWABILITY. Corresponds to the JSON property viewabilityDetails



12654
12655
12656
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12654

def viewability_details
  @viewability_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
12686
12687
12688
12689
12690
12691
12692
12693
12694
12695
12696
12697
12698
12699
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12661

def update!(**args)
  @age_range_details = args[:age_range_details] if args.key?(:age_range_details)
  @app_category_details = args[:app_category_details] if args.key?(:app_category_details)
  @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details)
  @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details)
  @browser_details = args[:browser_details] if args.key?(:browser_details)
  @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details)
  @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details)
  @category_details = args[:category_details] if args.key?(:category_details)
  @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details)
  @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details)
  @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details)
  @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details)
  @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details)
  @content_theme_details = args[:content_theme_details] if args.key?(:content_theme_details)
  @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details)
  @device_type_details = args[:device_type_details] if args.key?(:device_type_details)
  @digital_content_label_details = args[:digital_content_label_details] if args.key?(:digital_content_label_details)
  @environment_details = args[:environment_details] if args.key?(:environment_details)
  @exchange_details = args[:exchange_details] if args.key?(:exchange_details)
  @gender_details = args[:gender_details] if args.key?(:gender_details)
  @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details)
  @household_income_details = args[:household_income_details] if args.key?(:household_income_details)
  @language_details = args[:language_details] if args.key?(:language_details)
  @name = args[:name] if args.key?(:name)
  @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details)
  @omid_details = args[:omid_details] if args.key?(:omid_details)
  @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details)
  @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details)
  @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details)
  @poi_details = args[:poi_details] if args.key?(:poi_details)
  @sensitive_category_details = args[:sensitive_category_details] if args.key?(:sensitive_category_details)
  @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
  @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details)
  @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details)
  @viewability_details = args[:viewability_details] if args.key?(:viewability_details)
end