Class: Google::Apis::DisplayvideoV3::ThirdPartyUrl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Tracking URLs from third parties to track interactions with an audio or a video creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyUrl

Returns a new instance of ThirdPartyUrl.



12785
12786
12787
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

Optional. The type of interaction needs to be tracked by the tracking URL Corresponds to the JSON property type

Returns:

  • (String)


12776
12777
12778
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12776

def type
  @type
end

#urlString

Optional. Tracking URL used to track the interaction. Provide a URL with optional path or query string, beginning with https:. For example, https:// www.example.com/path Corresponds to the JSON property url

Returns:

  • (String)


12783
12784
12785
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12783

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12790
12791
12792
12793
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12790

def update!(**args)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end