Class: Google::Apis::DisplayvideoV3::TrackingFloodlightActivityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the behavior of a single Floodlight activity config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackingFloodlightActivityConfig

Returns a new instance of TrackingFloodlightActivityConfig.



13268
13269
13270
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Required. The ID of the Floodlight activity. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


13254
13255
13256
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13254

def floodlight_activity_id
  @floodlight_activity_id
end

#post_click_lookback_window_daysFixnum

Required. The number of days after an ad has been clicked in which a conversion may be counted. Must be between 0 and 90 inclusive. Corresponds to the JSON property postClickLookbackWindowDays

Returns:

  • (Fixnum)


13260
13261
13262
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13260

def post_click_lookback_window_days
  @post_click_lookback_window_days
end

#post_view_lookback_window_daysFixnum

Required. The number of days after an ad has been viewed in which a conversion may be counted. Must be between 0 and 90 inclusive. Corresponds to the JSON property postViewLookbackWindowDays

Returns:

  • (Fixnum)


13266
13267
13268
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13266

def post_view_lookback_window_days
  @post_view_lookback_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13273
13274
13275
13276
13277
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13273

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @post_click_lookback_window_days = args[:post_click_lookback_window_days] if args.key?(:post_click_lookback_window_days)
  @post_view_lookback_window_days = args[:post_view_lookback_window_days] if args.key?(:post_view_lookback_window_days)
end