Class: Google::Apis::DisplayvideoV3::VideoAdSequenceStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

The detail of a single step in a VideoAdSequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoAdSequenceStep

Returns a new instance of VideoAdSequenceStep.



13232
13233
13234
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idFixnum

The ID of the corresponding ad group of the step. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


13214
13215
13216
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13214

def ad_group_id
  @ad_group_id
end

#interaction_typeString

The interaction on the previous step that will lead the viewer to this step. The first step does not have interaction_type. Corresponds to the JSON property interactionType

Returns:

  • (String)


13220
13221
13222
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13220

def interaction_type
  @interaction_type
end

#previous_step_idFixnum

The ID of the previous step. The first step does not have previous step. Corresponds to the JSON property previousStepId

Returns:

  • (Fixnum)


13225
13226
13227
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13225

def previous_step_id
  @previous_step_id
end

#step_idFixnum

The ID of the step. Corresponds to the JSON property stepId

Returns:

  • (Fixnum)


13230
13231
13232
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13230

def step_id
  @step_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13237
13238
13239
13240
13241
13242
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13237

def update!(**args)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @interaction_type = args[:interaction_type] if args.key?(:interaction_type)
  @previous_step_id = args[:previous_step_id] if args.key?(:previous_step_id)
  @step_id = args[:step_id] if args.key?(:step_id)
end