Class: Google::Apis::DisplayvideoV3::VideoPerformanceAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a video performance ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPerformanceAd

Returns a new instance of VideoPerformanceAd.



13352
13353
13354
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelsArray<String>

The list of text assets shown on the call-to-action button. Corresponds to the JSON property actionButtonLabels

Returns:

  • (Array<String>)


13295
13296
13297
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13295

def action_button_labels
  @action_button_labels
end

#companion_bannersArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of companion banners used by this ad. Corresponds to the JSON property companionBanners



13300
13301
13302
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13300

def companion_banners
  @companion_banners
end

#custom_parametersHash<String,String>

The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


13305
13306
13307
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13305

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

The list of descriptions shown on the call-to-action banner. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


13310
13311
13312
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13310

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


13315
13316
13317
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13315

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


13320
13321
13322
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13320

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#domainString

The domain of the display URL. Corresponds to the JSON property domain

Returns:

  • (String)


13325
13326
13327
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13325

def domain
  @domain
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


13330
13331
13332
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13330

def final_url
  @final_url
end

#headlinesArray<String>

The list of headlines shown on the call-to-action banner. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


13335
13336
13337
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13335

def headlines
  @headlines
end

#long_headlinesArray<String>

The list of long headlines shown on the call-to-action banner. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


13340
13341
13342
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13340

def long_headlines
  @long_headlines
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


13345
13346
13347
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13345

def tracking_url
  @tracking_url
end

#videosArray<Google::Apis::DisplayvideoV3::YoutubeVideoDetails>

The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



13350
13351
13352
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13350

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13357

def update!(**args)
  @action_button_labels = args[:action_button_labels] if args.key?(:action_button_labels)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @domain = args[:domain] if args.key?(:domain)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headlines = args[:headlines] if args.key?(:headlines)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end