Class: Google::Apis::DisplayvideoV3::YoutubeAndPartnersBiddingStrategy
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::YoutubeAndPartnersBiddingStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings that control the bid strategy for YouTube and Partners resources.
Instance Attribute Summary collapse
-
#ad_group_effective_target_cpa_source ⇒ String
Output only.
-
#ad_group_effective_target_cpa_value ⇒ Fixnum
Output only.
-
#type ⇒ String
The type of the bidding strategy.
-
#value ⇒ Fixnum
The value used by the bidding strategy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAndPartnersBiddingStrategy
constructor
A new instance of YoutubeAndPartnersBiddingStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAndPartnersBiddingStrategy
Returns a new instance of YoutubeAndPartnersBiddingStrategy.
13863 13864 13865 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_effective_target_cpa_source ⇒ String
Output only. Source of the effective target CPA value for ad group.
Corresponds to the JSON property adGroupEffectiveTargetCpaSource
13833 13834 13835 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13833 def ad_group_effective_target_cpa_source @ad_group_effective_target_cpa_source end |
#ad_group_effective_target_cpa_value ⇒ Fixnum
Output only. The effective target CPA for ad group, in micros of advertiser's
currency.
Corresponds to the JSON property adGroupEffectiveTargetCpaValue
13839 13840 13841 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13839 def ad_group_effective_target_cpa_value @ad_group_effective_target_cpa_value end |
#type ⇒ String
The type of the bidding strategy.
Corresponds to the JSON property type
13844 13845 13846 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13844 def type @type end |
#value ⇒ Fixnum
The value used by the bidding strategy. When the bidding strategy is assigned
at the line item level, this field is only applicable for the following
strategy types: * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_CPA *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_ROAS When the bidding
strategy is assigned at the ad group level, this field is only applicable for
the following strategy types: *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_MANUAL_CPM *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_MANUAL_CPV *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_CPA *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_CPM *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_RESERVE_CPM *
YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_ROAS If not using an
applicable strategy, the value of this field will be 0.
Corresponds to the JSON property value
13861 13862 13863 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13861 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13868 13869 13870 13871 13872 13873 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13868 def update!(**args) @ad_group_effective_target_cpa_source = args[:ad_group_effective_target_cpa_source] if args.key?(:ad_group_effective_target_cpa_source) @ad_group_effective_target_cpa_value = args[:ad_group_effective_target_cpa_value] if args.key?(:ad_group_effective_target_cpa_value) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |