Class: Google::Apis::DisplayvideoV3::AdPolicyTopicEntry
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdPolicyTopicEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
An entry describing how an ad has been identified as relating to an ad policy.
Instance Attribute Summary collapse
-
#appeal_info ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicAppealInfo
Information on how to appeal a policy decision.
-
#help_center_link ⇒ String
Ad policy help center link for the policy topic.
-
#policy_decision_type ⇒ String
The source of the policy decision.
-
#policy_enforcement_means ⇒ String
The policy enforcement means used in the policy review.
-
#policy_label ⇒ String
Localized label text for policy.
-
#policy_topic ⇒ String
The policy topic.
-
#policy_topic_constraints ⇒ Array<Google::Apis::DisplayvideoV3::AdPolicyTopicConstraint>
The serving constraints relevant to the policy decision.
-
#policy_topic_description ⇒ String
A short summary description of the policy topic.
-
#policy_topic_evidences ⇒ Array<Google::Apis::DisplayvideoV3::AdPolicyTopicEvidence>
The evidence used in the policy decision.
-
#policy_topic_type ⇒ String
How ad serving will be affected due to the relation to the ad policy topic.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEntry
constructor
A new instance of AdPolicyTopicEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEntry
Returns a new instance of AdPolicyTopicEntry.
547 548 549 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appeal_info ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicAppealInfo
Information on how to appeal a policy decision.
Corresponds to the JSON property appealInfo
499 500 501 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 499 def appeal_info @appeal_info end |
#help_center_link ⇒ String
Ad policy help center link for the policy topic.
Corresponds to the JSON property helpCenterLink
504 505 506 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 504 def help_center_link @help_center_link end |
#policy_decision_type ⇒ String
The source of the policy decision.
Corresponds to the JSON property policyDecisionType
509 510 511 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 509 def policy_decision_type @policy_decision_type end |
#policy_enforcement_means ⇒ String
The policy enforcement means used in the policy review.
Corresponds to the JSON property policyEnforcementMeans
514 515 516 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 514 def policy_enforcement_means @policy_enforcement_means end |
#policy_label ⇒ String
Localized label text for policy. Examples include "Trademarks in text", "
Contains Alcohol", etc.
Corresponds to the JSON property policyLabel
520 521 522 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 520 def policy_label @policy_label end |
#policy_topic ⇒ String
The policy topic. Examples include "TRADEMARKS", "ALCOHOL", etc.
Corresponds to the JSON property policyTopic
525 526 527 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 525 def policy_topic @policy_topic end |
#policy_topic_constraints ⇒ Array<Google::Apis::DisplayvideoV3::AdPolicyTopicConstraint>
The serving constraints relevant to the policy decision.
Corresponds to the JSON property policyTopicConstraints
530 531 532 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 530 def policy_topic_constraints @policy_topic_constraints end |
#policy_topic_description ⇒ String
A short summary description of the policy topic.
Corresponds to the JSON property policyTopicDescription
535 536 537 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 535 def policy_topic_description @policy_topic_description end |
#policy_topic_evidences ⇒ Array<Google::Apis::DisplayvideoV3::AdPolicyTopicEvidence>
The evidence used in the policy decision.
Corresponds to the JSON property policyTopicEvidences
540 541 542 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 540 def policy_topic_evidences @policy_topic_evidences end |
#policy_topic_type ⇒ String
How ad serving will be affected due to the relation to the ad policy topic.
Corresponds to the JSON property policyTopicType
545 546 547 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 545 def policy_topic_type @policy_topic_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 552 def update!(**args) @appeal_info = args[:appeal_info] if args.key?(:appeal_info) @help_center_link = args[:help_center_link] if args.key?(:help_center_link) @policy_decision_type = args[:policy_decision_type] if args.key?(:policy_decision_type) @policy_enforcement_means = args[:policy_enforcement_means] if args.key?(:policy_enforcement_means) @policy_label = args[:policy_label] if args.key?(:policy_label) @policy_topic = args[:policy_topic] if args.key?(:policy_topic) @policy_topic_constraints = args[:policy_topic_constraints] if args.key?(:policy_topic_constraints) @policy_topic_description = args[:policy_topic_description] if args.key?(:policy_topic_description) @policy_topic_evidences = args[:policy_topic_evidences] if args.key?(:policy_topic_evidences) @policy_topic_type = args[:policy_topic_type] if args.key?(:policy_topic_type) end |