Class: Google::Apis::DisplayvideoV3::AdPolicyTopicEvidence
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AdPolicyTopicEvidence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Evidence information used in the policy decision.
Instance Attribute Summary collapse
-
#counterfeit ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceCounterfeit
Details on the counterfeit enforcement that caused a policy violation.
-
#destination_mismatch ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationMismatch
Details on a mismatch between destination URL types.
-
#destination_not_working ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationNotWorking
Details for on HTTP or DNS errors related to the ad destination.
-
#destination_text_list ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationTextList
A list of destination text that violated the policy.
-
#http_code ⇒ Fixnum
HTTP code returned when the final URL was crawled.
-
#language_code ⇒ String
The language the ad was detected to be written in.
-
#legal_removal ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceLegalRemoval
Legal related regulation enforcement, either from DMCA or local legal regulation.
-
#regional_requirements ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceRegionalRequirements
Trust & Safety (T&S) proactive enforcement for policies meant to address regional requirements.
-
#text_list ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceTextList
A list of fragments of text that violated the policy.
-
#trademark ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceTrademark
Trademark terms that caused a policy violation.
-
#website_list ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceWebsiteList
A list of websites that violated the policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEvidence
constructor
A new instance of AdPolicyTopicEvidence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEvidence
Returns a new instance of AdPolicyTopicEvidence.
629 630 631 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#counterfeit ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceCounterfeit
Details on the counterfeit enforcement that caused a policy violation.
Corresponds to the JSON property counterfeit
573 574 575 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 573 def counterfeit @counterfeit end |
#destination_mismatch ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationMismatch
Details on a mismatch between destination URL types.
Corresponds to the JSON property destinationMismatch
578 579 580 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 578 def destination_mismatch @destination_mismatch end |
#destination_not_working ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationNotWorking
Details for on HTTP or DNS errors related to the ad destination.
Corresponds to the JSON property destinationNotWorking
583 584 585 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 583 def destination_not_working @destination_not_working end |
#destination_text_list ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceDestinationTextList
A list of destination text that violated the policy.
Corresponds to the JSON property destinationTextList
588 589 590 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 588 def destination_text_list @destination_text_list end |
#http_code ⇒ Fixnum
HTTP code returned when the final URL was crawled.
Corresponds to the JSON property httpCode
593 594 595 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 593 def http_code @http_code end |
#language_code ⇒ String
The language the ad was detected to be written in. This field uses IETF
language tags, such as "en-US".
Corresponds to the JSON property languageCode
599 600 601 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 599 def language_code @language_code end |
#legal_removal ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceLegalRemoval
Legal related regulation enforcement, either from DMCA or local legal
regulation.
Corresponds to the JSON property legalRemoval
605 606 607 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 605 def legal_removal @legal_removal end |
#regional_requirements ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceRegionalRequirements
Trust & Safety (T&S) proactive enforcement for policies meant to address
regional requirements. This is considered a Google-owned investigation instead
of a regulation notice since it's proactive T&S enforcement.
Corresponds to the JSON property regionalRequirements
612 613 614 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 612 def regional_requirements @regional_requirements end |
#text_list ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceTextList
A list of fragments of text that violated the policy.
Corresponds to the JSON property textList
617 618 619 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 617 def text_list @text_list end |
#trademark ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceTrademark
Trademark terms that caused a policy violation.
Corresponds to the JSON property trademark
622 623 624 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 622 def trademark @trademark end |
#website_list ⇒ Google::Apis::DisplayvideoV3::AdPolicyTopicEvidenceWebsiteList
A list of websites that violated the policy.
Corresponds to the JSON property websiteList
627 628 629 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 627 def website_list @website_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 634 def update!(**args) @counterfeit = args[:counterfeit] if args.key?(:counterfeit) @destination_mismatch = args[:destination_mismatch] if args.key?(:destination_mismatch) @destination_not_working = args[:destination_not_working] if args.key?(:destination_not_working) @destination_text_list = args[:destination_text_list] if args.key?(:destination_text_list) @http_code = args[:http_code] if args.key?(:http_code) @language_code = args[:language_code] if args.key?(:language_code) @legal_removal = args[:legal_removal] if args.key?(:legal_removal) @regional_requirements = args[:regional_requirements] if args.key?(:regional_requirements) @text_list = args[:text_list] if args.key?(:text_list) @trademark = args[:trademark] if args.key?(:trademark) @website_list = args[:website_list] if args.key?(:website_list) end |