Class: Google::Apis::DisplayvideoV3::Advertiser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single advertiser in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Advertiser

Returns a new instance of Advertiser.



1255
1256
1257
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV3::AdvertiserAdServerConfig

Ad server related settings of an advertiser. Corresponds to the JSON property adServerConfig



1164
1165
1166
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1164

def ad_server_config
  @ad_server_config
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser. Assigned by the system. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


1169
1170
1171
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1169

def advertiser_id
  @advertiser_id
end

#billing_configGoogle::Apis::DisplayvideoV3::AdvertiserBillingConfig

Billing related settings of an advertiser. Corresponds to the JSON property billingConfig



1174
1175
1176
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1174

def billing_config
  @billing_config
end

#contains_eu_political_adsString

Optional. Whether this advertiser contains line items that serve European Union political ads. If this field is set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING, then the following will happen: * Any new line items created under this advertiser will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. * Any existing line items under this advertiser that do not have a set value be updated to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING within a day. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1185

def contains_eu_political_ads
  @contains_eu_political_ads
end

#creative_configGoogle::Apis::DisplayvideoV3::AdvertiserCreativeConfig

Creatives related settings of an advertiser. Corresponds to the JSON property creativeConfig



1190
1191
1192
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1190

def creative_config
  @creative_config
end

#data_access_configGoogle::Apis::DisplayvideoV3::AdvertiserDataAccessConfig

Settings that control how advertiser related data may be accessed. Corresponds to the JSON property dataAccessConfig



1195
1196
1197
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1195

def data_access_config
  @data_access_config
end

#display_nameString

Required. The display name of the advertiser. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


1201
1202
1203
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1201

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not insertion orders and line items of the advertiser can spend their budgets and bid on inventory. * Accepted values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_PAUSED and ENTITY_STATUS_SCHEDULED_FOR_DELETION. * If set to ENTITY_STATUS_SCHEDULED_FOR_DELETION, the advertiser will be deleted 30 days from when it was first scheduled for deletion. Corresponds to the JSON property entityStatus

Returns:

  • (String)


1211
1212
1213
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1211

def entity_status
  @entity_status
end

#general_configGoogle::Apis::DisplayvideoV3::AdvertiserGeneralConfig

General settings of an advertiser. Corresponds to the JSON property generalConfig



1216
1217
1218
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1216

def general_config
  @general_config
end

#integration_detailsGoogle::Apis::DisplayvideoV3::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



1221
1222
1223
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1221

def integration_details
  @integration_details
end

#nameString

Output only. The resource name of the advertiser. Corresponds to the JSON property name

Returns:

  • (String)


1226
1227
1228
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1226

def name
  @name
end

#partner_idFixnum

Required. Immutable. The unique ID of the partner that the advertiser belongs to. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


1232
1233
1234
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1232

def partner_id
  @partner_id
end

#prisma_enabledBoolean Also known as: prisma_enabled?

Whether integration with Mediaocean (Prisma) is enabled. By enabling this, you agree to the following: On behalf of my company, I authorize Mediaocean ( Prisma) to send budget segment plans to Google, and I authorize Google to send corresponding reporting and invoices from DV360 to Mediaocean for the purposes of budget planning, billing, and reconciliation for this advertiser. Corresponds to the JSON property prismaEnabled

Returns:

  • (Boolean)


1241
1242
1243
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1241

def prisma_enabled
  @prisma_enabled
end

#serving_configGoogle::Apis::DisplayvideoV3::AdvertiserTargetingConfig

Targeting settings related to ad serving of an advertiser. Corresponds to the JSON property servingConfig



1247
1248
1249
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1247

def serving_config
  @serving_config
end

#update_timeString

Output only. The timestamp when the advertiser was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1253

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1260

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @creative_config = args[:creative_config] if args.key?(:creative_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @general_config = args[:general_config] if args.key?(:general_config)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @prisma_enabled = args[:prisma_enabled] if args.key?(:prisma_enabled)
  @serving_config = args[:serving_config] if args.key?(:serving_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end