Class: Google::Apis::DisplayvideoV3::AlgorithmRulesFloodlightActivityConversionSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

The rule to score impressions based on Floodlight conversion events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRulesFloodlightActivityConversionSignal

Returns a new instance of AlgorithmRulesFloodlightActivityConversionSignal.



1640
1641
1642
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_countingString

Required. The type of conversions to be used in impression value computation, for example, post-click conversions. Corresponds to the JSON property conversionCounting

Returns:

  • (String)


1627
1628
1629
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1627

def conversion_counting
  @conversion_counting
end

#counting_methodString

Required. The way to acquire value from the floodlight activity, for example, count of the conversion. Corresponds to the JSON property countingMethod

Returns:

  • (String)


1633
1634
1635
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1633

def counting_method
  @counting_method
end

#floodlight_activity_idFixnum

Required. Id of the floodlight activity. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


1638
1639
1640
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1638

def floodlight_activity_id
  @floodlight_activity_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1645
1646
1647
1648
1649
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 1645

def update!(**args)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @counting_method = args[:counting_method] if args.key?(:counting_method)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
end