Class: Google::Apis::DisplayvideoV3::AssignedLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

An assignment between a location list and a relevant targeting option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssignedLocation

Returns a new instance of AssignedLocation.



2047
2048
2049
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_location_idFixnum

Output only. The unique ID of the assigned location. The ID is only unique within a location list. It may be reused in other contexts. Corresponds to the JSON property assignedLocationId

Returns:

  • (Fixnum)


2035
2036
2037
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2035

def assigned_location_id
  @assigned_location_id
end

#nameString

Output only. The resource name of the assigned location. Corresponds to the JSON property name

Returns:

  • (String)


2040
2041
2042
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2040

def name
  @name
end

#targeting_option_idString

Required. The ID of the targeting option assigned to the location list. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


2045
2046
2047
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2045

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2052
2053
2054
2055
2056
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2052

def update!(**args)
  @assigned_location_id = args[:assigned_location_id] if args.key?(:assigned_location_id)
  @name = args[:name] if args.key?(:name)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end