Class: Google::Apis::DisplayvideoV3::AssignedTargetingOption
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AssignedTargetingOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings.
Instance Attribute Summary collapse
-
#age_range_details ⇒ Google::Apis::DisplayvideoV3::AgeRangeAssignedTargetingOptionDetails
Represents a targetable age range.
-
#app_category_details ⇒ Google::Apis::DisplayvideoV3::AppCategoryAssignedTargetingOptionDetails
Details for assigned app category targeting option.
-
#app_details ⇒ Google::Apis::DisplayvideoV3::AppAssignedTargetingOptionDetails
Details for assigned app targeting option.
-
#assigned_targeting_option_id ⇒ String
Output only.
-
#assigned_targeting_option_id_alias ⇒ String
Output only.
-
#audience_group_details ⇒ Google::Apis::DisplayvideoV3::AudienceGroupAssignedTargetingOptionDetails
Assigned audience group targeting option details.
-
#audio_content_type_details ⇒ Google::Apis::DisplayvideoV3::AudioContentTypeAssignedTargetingOptionDetails
Details for audio content type assigned targeting option.
-
#authorized_seller_status_details ⇒ Google::Apis::DisplayvideoV3::AuthorizedSellerStatusAssignedTargetingOptionDetails
Represents an assigned authorized seller status.
-
#browser_details ⇒ Google::Apis::DisplayvideoV3::BrowserAssignedTargetingOptionDetails
Details for assigned browser targeting option.
-
#business_chain_details ⇒ Google::Apis::DisplayvideoV3::BusinessChainAssignedTargetingOptionDetails
Details for assigned Business chain targeting option.
-
#carrier_and_isp_details ⇒ Google::Apis::DisplayvideoV3::CarrierAndIspAssignedTargetingOptionDetails
Details for assigned carrier and ISP targeting option.
-
#category_details ⇒ Google::Apis::DisplayvideoV3::CategoryAssignedTargetingOptionDetails
Assigned category targeting option details.
-
#channel_details ⇒ Google::Apis::DisplayvideoV3::ChannelAssignedTargetingOptionDetails
Details for assigned channel targeting option.
-
#content_duration_details ⇒ Google::Apis::DisplayvideoV3::ContentDurationAssignedTargetingOptionDetails
Details for content duration assigned targeting option.
-
#content_genre_details ⇒ Google::Apis::DisplayvideoV3::ContentGenreAssignedTargetingOptionDetails
Details for content genre assigned targeting option.
-
#content_instream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentInstreamPositionAssignedTargetingOptionDetails
Assigned content instream position targeting option details.
-
#content_outstream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentOutstreamPositionAssignedTargetingOptionDetails
Assigned content outstream position targeting option details.
-
#content_stream_type_details ⇒ Google::Apis::DisplayvideoV3::ContentStreamTypeAssignedTargetingOptionDetails
Details for content stream type assigned targeting option.
-
#content_theme_exclusion_details ⇒ Google::Apis::DisplayvideoV3::ContentThemeAssignedTargetingOptionDetails
Targeting details for content theme.
-
#day_and_time_details ⇒ Google::Apis::DisplayvideoV3::DayAndTimeAssignedTargetingOptionDetails
Representation of a segment of time defined on a specific day of the week and with a start and end time.
-
#device_make_model_details ⇒ Google::Apis::DisplayvideoV3::DeviceMakeModelAssignedTargetingOptionDetails
Assigned device make and model targeting option details.
-
#device_type_details ⇒ Google::Apis::DisplayvideoV3::DeviceTypeAssignedTargetingOptionDetails
Targeting details for device type.
-
#digital_content_label_exclusion_details ⇒ Google::Apis::DisplayvideoV3::DigitalContentLabelAssignedTargetingOptionDetails
Targeting details for digital content label.
-
#environment_details ⇒ Google::Apis::DisplayvideoV3::EnvironmentAssignedTargetingOptionDetails
Assigned environment targeting option details.
-
#exchange_details ⇒ Google::Apis::DisplayvideoV3::ExchangeAssignedTargetingOptionDetails
Details for assigned exchange targeting option.
-
#gender_details ⇒ Google::Apis::DisplayvideoV3::GenderAssignedTargetingOptionDetails
Details for assigned gender targeting option.
-
#geo_region_details ⇒ Google::Apis::DisplayvideoV3::GeoRegionAssignedTargetingOptionDetails
Details for assigned geographic region targeting option.
-
#household_income_details ⇒ Google::Apis::DisplayvideoV3::HouseholdIncomeAssignedTargetingOptionDetails
Details for assigned household income targeting option.
-
#inheritance ⇒ String
Output only.
-
#inventory_source_details ⇒ Google::Apis::DisplayvideoV3::InventorySourceAssignedTargetingOptionDetails
Targeting details for inventory source.
-
#inventory_source_group_details ⇒ Google::Apis::DisplayvideoV3::InventorySourceGroupAssignedTargetingOptionDetails
Targeting details for inventory source group.
-
#keyword_details ⇒ Google::Apis::DisplayvideoV3::KeywordAssignedTargetingOptionDetails
Details for assigned keyword targeting option.
-
#language_details ⇒ Google::Apis::DisplayvideoV3::LanguageAssignedTargetingOptionDetails
Details for assigned language targeting option.
-
#name ⇒ String
Output only.
-
#native_content_position_details ⇒ Google::Apis::DisplayvideoV3::NativeContentPositionAssignedTargetingOptionDetails
Details for native content position assigned targeting option.
-
#negative_keyword_list_details ⇒ Google::Apis::DisplayvideoV3::NegativeKeywordListAssignedTargetingOptionDetails
Targeting details for negative keyword list.
-
#omid_details ⇒ Google::Apis::DisplayvideoV3::OmidAssignedTargetingOptionDetails
Represents a targetable Open Measurement enabled inventory type.
-
#on_screen_position_details ⇒ Google::Apis::DisplayvideoV3::OnScreenPositionAssignedTargetingOptionDetails
On screen position targeting option details.
-
#operating_system_details ⇒ Google::Apis::DisplayvideoV3::OperatingSystemAssignedTargetingOptionDetails
Assigned operating system targeting option details.
-
#parental_status_details ⇒ Google::Apis::DisplayvideoV3::ParentalStatusAssignedTargetingOptionDetails
Details for assigned parental status targeting option.
-
#poi_details ⇒ Google::Apis::DisplayvideoV3::PoiAssignedTargetingOptionDetails
Details for assigned POI targeting option.
-
#proximity_location_list_details ⇒ Google::Apis::DisplayvideoV3::ProximityLocationListAssignedTargetingOptionDetails
Targeting details for proximity location list.
-
#regional_location_list_details ⇒ Google::Apis::DisplayvideoV3::RegionalLocationListAssignedTargetingOptionDetails
Targeting details for regional location list.
-
#sensitive_category_exclusion_details ⇒ Google::Apis::DisplayvideoV3::SensitiveCategoryAssignedTargetingOptionDetails
Targeting details for sensitive category.
-
#session_position_details ⇒ Google::Apis::DisplayvideoV3::SessionPositionAssignedTargetingOptionDetails
Details for session position assigned targeting option.
-
#sub_exchange_details ⇒ Google::Apis::DisplayvideoV3::SubExchangeAssignedTargetingOptionDetails
Details for assigned sub-exchange targeting option.
-
#targeting_type ⇒ String
Output only.
-
#third_party_verifier_details ⇒ Google::Apis::DisplayvideoV3::ThirdPartyVerifierAssignedTargetingOptionDetails
Assigned third party verifier targeting option details.
-
#url_details ⇒ Google::Apis::DisplayvideoV3::UrlAssignedTargetingOptionDetails
Details for assigned URL targeting option.
-
#user_rewarded_content_details ⇒ Google::Apis::DisplayvideoV3::UserRewardedContentAssignedTargetingOptionDetails
User rewarded content targeting option details.
-
#video_player_size_details ⇒ Google::Apis::DisplayvideoV3::VideoPlayerSizeAssignedTargetingOptionDetails
Video player size targeting option details.
-
#viewability_details ⇒ Google::Apis::DisplayvideoV3::ViewabilityAssignedTargetingOptionDetails
Assigned viewability targeting option details.
-
#youtube_channel_details ⇒ Google::Apis::DisplayvideoV3::YoutubeChannelAssignedTargetingOptionDetails
Details for YouTube channel assigned targeting option.
-
#youtube_channel_pack_details ⇒ Google::Apis::DisplayvideoV3::YoutubeChannelPackAssignedTargetingOptionDetails
Details for YouTube channel pack assigned targeting option.
-
#youtube_video_details ⇒ Google::Apis::DisplayvideoV3::YoutubeVideoAssignedTargetingOptionDetails
Details for YouTube video assigned targeting option.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssignedTargetingOption
constructor
A new instance of AssignedTargetingOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssignedTargetingOption
Returns a new instance of AssignedTargetingOption.
2548 2549 2550 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_range_details ⇒ Google::Apis::DisplayvideoV3::AgeRangeAssignedTargetingOptionDetails
Represents a targetable age range. This will be populated in the details field
of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AGE_RANGE
.
Corresponds to the JSON property ageRangeDetails
2148 2149 2150 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2148 def age_range_details @age_range_details end |
#app_category_details ⇒ Google::Apis::DisplayvideoV3::AppCategoryAssignedTargetingOptionDetails
Details for assigned app category targeting option. This will be populated in
the app_category_details field of an AssignedTargetingOption when
targeting_type is TARGETING_TYPE_APP_CATEGORY.
Corresponds to the JSON property appCategoryDetails
2155 2156 2157 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2155 def app_category_details @app_category_details end |
#app_details ⇒ Google::Apis::DisplayvideoV3::AppAssignedTargetingOptionDetails
Details for assigned app targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_APP.
Corresponds to the JSON property appDetails
2162 2163 2164 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2162 def app_details @app_details end |
#assigned_targeting_option_id ⇒ String
Output only. The unique ID of the assigned targeting option. The ID is only
unique within a given resource and targeting type. It may be reused in other
contexts.
Corresponds to the JSON property assignedTargetingOptionId
2169 2170 2171 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2169 def assigned_targeting_option_id @assigned_targeting_option_id end |
#assigned_targeting_option_id_alias ⇒ String
Output only. An alias for the assigned_targeting_option_id. This value can be
used in place of assignedTargetingOptionId when retrieving or deleting
existing targeting. This field will only be supported for all assigned
targeting options of the following targeting types: *
TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_DEVICE_TYPE *
TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION * TARGETING_TYPE_ENVIRONMENT
TARGETING_TYPE_EXCHANGE*TARGETING_TYPE_GENDER*TARGETING_TYPE_HOUSEHOLD_INCOME*TARGETING_TYPE_NATIVE_CONTENT_POSITION*TARGETING_TYPE_OMID*TARGETING_TYPE_PARENTAL_STATUS*TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION*TARGETING_TYPE_VIDEO_PLAYER_SIZE*TARGETING_TYPE_VIEWABILITYThis field is also supported for line item assigned targeting options of the following targeting types: *TARGETING_TYPE_CONTENT_INSTREAM_POSITION*TARGETING_TYPE_CONTENT_OUTSTREAM_POSITIONCorresponds to the JSON propertyassignedTargetingOptionIdAlias
2187 2188 2189 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2187 def assigned_targeting_option_id_alias @assigned_targeting_option_id_alias end |
#audience_group_details ⇒ Google::Apis::DisplayvideoV3::AudienceGroupAssignedTargetingOptionDetails
Assigned audience group targeting option details. This will be populated in
the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_AUDIENCE_GROUP. The relation between each group is UNION,
except for excluded_first_and_third_party_audience_group and
excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION
with other groups.
Corresponds to the JSON property audienceGroupDetails
2197 2198 2199 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2197 def audience_group_details @audience_group_details end |
#audio_content_type_details ⇒ Google::Apis::DisplayvideoV3::AudioContentTypeAssignedTargetingOptionDetails
Details for audio content type assigned targeting option. This will be
populated in the audio_content_type_details field when targeting_type is
TARGETING_TYPE_AUDIO_CONTENT_TYPE. Explicitly targeting all options is not
supported. Remove all audio content type targeting options to achieve this
effect.
Corresponds to the JSON property audioContentTypeDetails
2206 2207 2208 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2206 def audio_content_type_details @audio_content_type_details end |
#authorized_seller_status_details ⇒ Google::Apis::DisplayvideoV3::AuthorizedSellerStatusAssignedTargetingOptionDetails
Represents an assigned authorized seller status. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. If a resource does not have an
TARGETING_TYPE_AUTHORIZED_SELLER_STATUS assigned targeting option, it is
using the "Authorized Direct Sellers and Resellers" option.
Corresponds to the JSON property authorizedSellerStatusDetails
2215 2216 2217 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2215 def @authorized_seller_status_details end |
#browser_details ⇒ Google::Apis::DisplayvideoV3::BrowserAssignedTargetingOptionDetails
Details for assigned browser targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_BROWSER.
Corresponds to the JSON property browserDetails
2222 2223 2224 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2222 def browser_details @browser_details end |
#business_chain_details ⇒ Google::Apis::DisplayvideoV3::BusinessChainAssignedTargetingOptionDetails
Details for assigned Business chain targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_BUSINESS_CHAIN.
Corresponds to the JSON property businessChainDetails
2229 2230 2231 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2229 def business_chain_details @business_chain_details end |
#carrier_and_isp_details ⇒ Google::Apis::DisplayvideoV3::CarrierAndIspAssignedTargetingOptionDetails
Details for assigned carrier and ISP targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_CARRIER_AND_ISP.
Corresponds to the JSON property carrierAndIspDetails
2236 2237 2238 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2236 def carrier_and_isp_details @carrier_and_isp_details end |
#category_details ⇒ Google::Apis::DisplayvideoV3::CategoryAssignedTargetingOptionDetails
Assigned category targeting option details. This will be populated in the
category_details field when targeting_type is TARGETING_TYPE_CATEGORY.
Corresponds to the JSON property categoryDetails
2242 2243 2244 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2242 def category_details @category_details end |
#channel_details ⇒ Google::Apis::DisplayvideoV3::ChannelAssignedTargetingOptionDetails
Details for assigned channel targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_CHANNEL.
Corresponds to the JSON property channelDetails
2249 2250 2251 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2249 def channel_details @channel_details end |
#content_duration_details ⇒ Google::Apis::DisplayvideoV3::ContentDurationAssignedTargetingOptionDetails
Details for content duration assigned targeting option. This will be populated
in the content_duration_details field when targeting_type is
TARGETING_TYPE_CONTENT_DURATION. Explicitly targeting all options is not
supported. Remove all content duration targeting options to achieve this
effect.
Corresponds to the JSON property contentDurationDetails
2258 2259 2260 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2258 def content_duration_details @content_duration_details end |
#content_genre_details ⇒ Google::Apis::DisplayvideoV3::ContentGenreAssignedTargetingOptionDetails
Details for content genre assigned targeting option. This will be populated in
the content_genre_details field when targeting_type is
TARGETING_TYPE_CONTENT_GENRE. Explicitly targeting all options is not
supported. Remove all content genre targeting options to achieve this effect.
Corresponds to the JSON property contentGenreDetails
2266 2267 2268 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2266 def content_genre_details @content_genre_details end |
#content_instream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentInstreamPositionAssignedTargetingOptionDetails
Assigned content instream position targeting option details. This will be
populated in the content_instream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Corresponds to the JSON property contentInstreamPositionDetails
2273 2274 2275 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2273 def content_instream_position_details @content_instream_position_details end |
#content_outstream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentOutstreamPositionAssignedTargetingOptionDetails
Assigned content outstream position targeting option details. This will be
populated in the content_outstream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.
Corresponds to the JSON property contentOutstreamPositionDetails
2280 2281 2282 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2280 def content_outstream_position_details @content_outstream_position_details end |
#content_stream_type_details ⇒ Google::Apis::DisplayvideoV3::ContentStreamTypeAssignedTargetingOptionDetails
Details for content stream type assigned targeting option. This will be
populated in the content_stream_type_details field when targeting_type is
TARGETING_TYPE_CONTENT_STREAM_TYPE. Explicitly targeting all options is not
supported. Remove all content stream type targeting options to achieve this
effect.
Corresponds to the JSON property contentStreamTypeDetails
2289 2290 2291 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2289 def content_stream_type_details @content_stream_type_details end |
#content_theme_exclusion_details ⇒ Google::Apis::DisplayvideoV3::ContentThemeAssignedTargetingOptionDetails
Targeting details for content theme. This will be populated in the details
field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_CONTENT_THEME_EXCLUSION.
Corresponds to the JSON property contentThemeExclusionDetails
2296 2297 2298 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2296 def content_theme_exclusion_details @content_theme_exclusion_details end |
#day_and_time_details ⇒ Google::Apis::DisplayvideoV3::DayAndTimeAssignedTargetingOptionDetails
Representation of a segment of time defined on a specific day of the week and
with a start and end time. The time represented by start_hour must be before
the time represented by end_hour.
Corresponds to the JSON property dayAndTimeDetails
2303 2304 2305 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2303 def day_and_time_details @day_and_time_details end |
#device_make_model_details ⇒ Google::Apis::DisplayvideoV3::DeviceMakeModelAssignedTargetingOptionDetails
Assigned device make and model targeting option details. This will be
populated in the device_make_model_details field when targeting_type is
TARGETING_TYPE_DEVICE_MAKE_MODEL.
Corresponds to the JSON property deviceMakeModelDetails
2310 2311 2312 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2310 def device_make_model_details @device_make_model_details end |
#device_type_details ⇒ Google::Apis::DisplayvideoV3::DeviceTypeAssignedTargetingOptionDetails
Targeting details for device type. This will be populated in the details field
of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_DEVICE_TYPE.
Corresponds to the JSON property deviceTypeDetails
2317 2318 2319 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2317 def device_type_details @device_type_details end |
#digital_content_label_exclusion_details ⇒ Google::Apis::DisplayvideoV3::DigitalContentLabelAssignedTargetingOptionDetails
Targeting details for digital content label. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION.
Corresponds to the JSON property digitalContentLabelExclusionDetails
2324 2325 2326 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2324 def digital_content_label_exclusion_details @digital_content_label_exclusion_details end |
#environment_details ⇒ Google::Apis::DisplayvideoV3::EnvironmentAssignedTargetingOptionDetails
Assigned environment targeting option details. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_ENVIRONMENT.
Corresponds to the JSON property environmentDetails
2331 2332 2333 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2331 def environment_details @environment_details end |
#exchange_details ⇒ Google::Apis::DisplayvideoV3::ExchangeAssignedTargetingOptionDetails
Details for assigned exchange targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_EXCHANGE.
Corresponds to the JSON property exchangeDetails
2338 2339 2340 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2338 def exchange_details @exchange_details end |
#gender_details ⇒ Google::Apis::DisplayvideoV3::GenderAssignedTargetingOptionDetails
Details for assigned gender targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_GENDER.
Corresponds to the JSON property genderDetails
2345 2346 2347 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2345 def gender_details @gender_details end |
#geo_region_details ⇒ Google::Apis::DisplayvideoV3::GeoRegionAssignedTargetingOptionDetails
Details for assigned geographic region targeting option. This will be
populated in the details field of an AssignedTargetingOption when
targeting_type is TARGETING_TYPE_GEO_REGION.
Corresponds to the JSON property geoRegionDetails
2352 2353 2354 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2352 def geo_region_details @geo_region_details end |
#household_income_details ⇒ Google::Apis::DisplayvideoV3::HouseholdIncomeAssignedTargetingOptionDetails
Details for assigned household income targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_HOUSEHOLD_INCOME.
Corresponds to the JSON property householdIncomeDetails
2359 2360 2361 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2359 def household_income_details @household_income_details end |
#inheritance ⇒ String
Output only. The inheritance status of the assigned targeting option.
Corresponds to the JSON property inheritance
2364 2365 2366 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2364 def inheritance @inheritance end |
#inventory_source_details ⇒ Google::Apis::DisplayvideoV3::InventorySourceAssignedTargetingOptionDetails
Targeting details for inventory source. This will be populated in the details
field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_INVENTORY_SOURCE.
Corresponds to the JSON property inventorySourceDetails
2371 2372 2373 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2371 def inventory_source_details @inventory_source_details end |
#inventory_source_group_details ⇒ Google::Apis::DisplayvideoV3::InventorySourceGroupAssignedTargetingOptionDetails
Targeting details for inventory source group. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_INVENTORY_SOURCE_GROUP.
Corresponds to the JSON property inventorySourceGroupDetails
2378 2379 2380 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2378 def inventory_source_group_details @inventory_source_group_details end |
#keyword_details ⇒ Google::Apis::DisplayvideoV3::KeywordAssignedTargetingOptionDetails
Details for assigned keyword targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_KEYWORD.
Corresponds to the JSON property keywordDetails
2385 2386 2387 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2385 def keyword_details @keyword_details end |
#language_details ⇒ Google::Apis::DisplayvideoV3::LanguageAssignedTargetingOptionDetails
Details for assigned language targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_LANGUAGE.
Corresponds to the JSON property languageDetails
2392 2393 2394 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2392 def language_details @language_details end |
#name ⇒ String
Output only. The resource name for this assigned targeting option.
Corresponds to the JSON property name
2397 2398 2399 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2397 def name @name end |
#native_content_position_details ⇒ Google::Apis::DisplayvideoV3::NativeContentPositionAssignedTargetingOptionDetails
Details for native content position assigned targeting option. This will be
populated in the native_content_position_details field when targeting_type is
TARGETING_TYPE_NATIVE_CONTENT_POSITION. Explicitly targeting all options is
not supported. Remove all native content position targeting options to achieve
this effect.
Corresponds to the JSON property nativeContentPositionDetails
2406 2407 2408 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2406 def native_content_position_details @native_content_position_details end |
#negative_keyword_list_details ⇒ Google::Apis::DisplayvideoV3::NegativeKeywordListAssignedTargetingOptionDetails
Targeting details for negative keyword list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_NEGATIVE_KEYWORD_LIST.
Corresponds to the JSON property negativeKeywordListDetails
2413 2414 2415 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2413 def negative_keyword_list_details @negative_keyword_list_details end |
#omid_details ⇒ Google::Apis::DisplayvideoV3::OmidAssignedTargetingOptionDetails
Represents a targetable Open Measurement enabled inventory type. This will be
populated in the details field of an AssignedTargetingOption when
targeting_type is TARGETING_TYPE_OMID.
Corresponds to the JSON property omidDetails
2420 2421 2422 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2420 def omid_details @omid_details end |
#on_screen_position_details ⇒ Google::Apis::DisplayvideoV3::OnScreenPositionAssignedTargetingOptionDetails
On screen position targeting option details. This will be populated in the
on_screen_position_details field when targeting_type is
TARGETING_TYPE_ON_SCREEN_POSITION.
Corresponds to the JSON property onScreenPositionDetails
2427 2428 2429 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2427 def on_screen_position_details @on_screen_position_details end |
#operating_system_details ⇒ Google::Apis::DisplayvideoV3::OperatingSystemAssignedTargetingOptionDetails
Assigned operating system targeting option details. This will be populated in
the operating_system_details field when targeting_type is
TARGETING_TYPE_OPERATING_SYSTEM.
Corresponds to the JSON property operatingSystemDetails
2434 2435 2436 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2434 def @operating_system_details end |
#parental_status_details ⇒ Google::Apis::DisplayvideoV3::ParentalStatusAssignedTargetingOptionDetails
Details for assigned parental status targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_PARENTAL_STATUS.
Corresponds to the JSON property parentalStatusDetails
2441 2442 2443 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2441 def parental_status_details @parental_status_details end |
#poi_details ⇒ Google::Apis::DisplayvideoV3::PoiAssignedTargetingOptionDetails
Details for assigned POI targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_POI.
Corresponds to the JSON property poiDetails
2448 2449 2450 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2448 def poi_details @poi_details end |
#proximity_location_list_details ⇒ Google::Apis::DisplayvideoV3::ProximityLocationListAssignedTargetingOptionDetails
Targeting details for proximity location list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_PROXIMITY_LOCATION_LIST.
Corresponds to the JSON property proximityLocationListDetails
2455 2456 2457 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2455 def proximity_location_list_details @proximity_location_list_details end |
#regional_location_list_details ⇒ Google::Apis::DisplayvideoV3::RegionalLocationListAssignedTargetingOptionDetails
Targeting details for regional location list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_REGIONAL_LOCATION_LIST.
Corresponds to the JSON property regionalLocationListDetails
2462 2463 2464 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2462 def regional_location_list_details @regional_location_list_details end |
#sensitive_category_exclusion_details ⇒ Google::Apis::DisplayvideoV3::SensitiveCategoryAssignedTargetingOptionDetails
Targeting details for sensitive category. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION.
Corresponds to the JSON property sensitiveCategoryExclusionDetails
2469 2470 2471 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2469 def sensitive_category_exclusion_details @sensitive_category_exclusion_details end |
#session_position_details ⇒ Google::Apis::DisplayvideoV3::SessionPositionAssignedTargetingOptionDetails
Details for session position assigned targeting option. This will be populated
in the session_position_details field when targeting_type is
TARGETING_TYPE_SESSION_POSITION.
Corresponds to the JSON property sessionPositionDetails
2476 2477 2478 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2476 def session_position_details @session_position_details end |
#sub_exchange_details ⇒ Google::Apis::DisplayvideoV3::SubExchangeAssignedTargetingOptionDetails
Details for assigned sub-exchange targeting option. This will be populated in
the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_SUB_EXCHANGE.
Corresponds to the JSON property subExchangeDetails
2483 2484 2485 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2483 def sub_exchange_details @sub_exchange_details end |
#targeting_type ⇒ String
Output only. Identifies the type of this assigned targeting option.
Corresponds to the JSON property targetingType
2488 2489 2490 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2488 def targeting_type @targeting_type end |
#third_party_verifier_details ⇒ Google::Apis::DisplayvideoV3::ThirdPartyVerifierAssignedTargetingOptionDetails
Assigned third party verifier targeting option details. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_THIRD_PARTY_VERIFIER.
Corresponds to the JSON property thirdPartyVerifierDetails
2495 2496 2497 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2495 def third_party_verifier_details @third_party_verifier_details end |
#url_details ⇒ Google::Apis::DisplayvideoV3::UrlAssignedTargetingOptionDetails
Details for assigned URL targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_URL.
Corresponds to the JSON property urlDetails
2502 2503 2504 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2502 def url_details @url_details end |
#user_rewarded_content_details ⇒ Google::Apis::DisplayvideoV3::UserRewardedContentAssignedTargetingOptionDetails
User rewarded content targeting option details. This will be populated in the
user_rewarded_content_details field when targeting_type is
TARGETING_TYPE_USER_REWARDED_CONTENT.
Corresponds to the JSON property userRewardedContentDetails
2509 2510 2511 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2509 def user_rewarded_content_details @user_rewarded_content_details end |
#video_player_size_details ⇒ Google::Apis::DisplayvideoV3::VideoPlayerSizeAssignedTargetingOptionDetails
Video player size targeting option details. This will be populated in the
video_player_size_details field when targeting_type is
TARGETING_TYPE_VIDEO_PLAYER_SIZE. Explicitly targeting all options is not
supported. Remove all video player size targeting options to achieve this
effect.
Corresponds to the JSON property videoPlayerSizeDetails
2518 2519 2520 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2518 def video_player_size_details @video_player_size_details end |
#viewability_details ⇒ Google::Apis::DisplayvideoV3::ViewabilityAssignedTargetingOptionDetails
Assigned viewability targeting option details. This will be populated in the
viewability_details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_VIEWABILITY.
Corresponds to the JSON property viewabilityDetails
2525 2526 2527 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2525 def viewability_details @viewability_details end |
#youtube_channel_details ⇒ Google::Apis::DisplayvideoV3::YoutubeChannelAssignedTargetingOptionDetails
Details for YouTube channel assigned targeting option. This will be populated
in the youtube_channel_details field when targeting_type is
TARGETING_TYPE_YOUTUBE_CHANNEL.
Corresponds to the JSON property youtubeChannelDetails
2532 2533 2534 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2532 def youtube_channel_details @youtube_channel_details end |
#youtube_channel_pack_details ⇒ Google::Apis::DisplayvideoV3::YoutubeChannelPackAssignedTargetingOptionDetails
Details for YouTube channel pack assigned targeting option. This will be
populated in the youtube_channel_pack_details field when targeting_type is
TARGETING_TYPE_YOUTUBE_CHANNEL_PACK.
Corresponds to the JSON property youtubeChannelPackDetails
2539 2540 2541 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2539 def youtube_channel_pack_details @youtube_channel_pack_details end |
#youtube_video_details ⇒ Google::Apis::DisplayvideoV3::YoutubeVideoAssignedTargetingOptionDetails
Details for YouTube video assigned targeting option. This will be populated in
the youtube_video_details field when targeting_type is
TARGETING_TYPE_YOUTUBE_VIDEO.
Corresponds to the JSON property youtubeVideoDetails
2546 2547 2548 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2546 def youtube_video_details @youtube_video_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2553 def update!(**args) @age_range_details = args[:age_range_details] if args.key?(:age_range_details) @app_category_details = args[:app_category_details] if args.key?(:app_category_details) @app_details = args[:app_details] if args.key?(:app_details) @assigned_targeting_option_id = args[:assigned_targeting_option_id] if args.key?(:assigned_targeting_option_id) @assigned_targeting_option_id_alias = args[:assigned_targeting_option_id_alias] if args.key?(:assigned_targeting_option_id_alias) @audience_group_details = args[:audience_group_details] if args.key?(:audience_group_details) @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details) @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details) @browser_details = args[:browser_details] if args.key?(:browser_details) @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details) @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details) @category_details = args[:category_details] if args.key?(:category_details) @channel_details = args[:channel_details] if args.key?(:channel_details) @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details) @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details) @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details) @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details) @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details) @content_theme_exclusion_details = args[:content_theme_exclusion_details] if args.key?(:content_theme_exclusion_details) @day_and_time_details = args[:day_and_time_details] if args.key?(:day_and_time_details) @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details) @device_type_details = args[:device_type_details] if args.key?(:device_type_details) @digital_content_label_exclusion_details = args[:digital_content_label_exclusion_details] if args.key?(:digital_content_label_exclusion_details) @environment_details = args[:environment_details] if args.key?(:environment_details) @exchange_details = args[:exchange_details] if args.key?(:exchange_details) @gender_details = args[:gender_details] if args.key?(:gender_details) @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details) @household_income_details = args[:household_income_details] if args.key?(:household_income_details) @inheritance = args[:inheritance] if args.key?(:inheritance) @inventory_source_details = args[:inventory_source_details] if args.key?(:inventory_source_details) @inventory_source_group_details = args[:inventory_source_group_details] if args.key?(:inventory_source_group_details) @keyword_details = args[:keyword_details] if args.key?(:keyword_details) @language_details = args[:language_details] if args.key?(:language_details) @name = args[:name] if args.key?(:name) @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details) @negative_keyword_list_details = args[:negative_keyword_list_details] if args.key?(:negative_keyword_list_details) @omid_details = args[:omid_details] if args.key?(:omid_details) @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details) @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details) @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details) @poi_details = args[:poi_details] if args.key?(:poi_details) @proximity_location_list_details = args[:proximity_location_list_details] if args.key?(:proximity_location_list_details) @regional_location_list_details = args[:regional_location_list_details] if args.key?(:regional_location_list_details) @sensitive_category_exclusion_details = args[:sensitive_category_exclusion_details] if args.key?(:sensitive_category_exclusion_details) @session_position_details = args[:session_position_details] if args.key?(:session_position_details) @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details) @targeting_type = args[:targeting_type] if args.key?(:targeting_type) @third_party_verifier_details = args[:third_party_verifier_details] if args.key?(:third_party_verifier_details) @url_details = args[:url_details] if args.key?(:url_details) @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details) @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details) @viewability_details = args[:viewability_details] if args.key?(:viewability_details) @youtube_channel_details = args[:youtube_channel_details] if args.key?(:youtube_channel_details) @youtube_channel_pack_details = args[:youtube_channel_pack_details] if args.key?(:youtube_channel_pack_details) @youtube_video_details = args[:youtube_video_details] if args.key?(:youtube_video_details) end |