Class: Google::Apis::DisplayvideoV3::AssignedTargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssignedTargetingOption

Returns a new instance of AssignedTargetingOption.



2531
2532
2533
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_range_detailsGoogle::Apis::DisplayvideoV3::AgeRangeAssignedTargetingOptionDetails

Represents a targetable age range. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AGE_RANGE . Corresponds to the JSON property ageRangeDetails



2131
2132
2133
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2131

def age_range_details
  @age_range_details
end

#app_category_detailsGoogle::Apis::DisplayvideoV3::AppCategoryAssignedTargetingOptionDetails

Details for assigned app category targeting option. This will be populated in the app_category_details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_APP_CATEGORY. Corresponds to the JSON property appCategoryDetails



2138
2139
2140
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2138

def app_category_details
  @app_category_details
end

#app_detailsGoogle::Apis::DisplayvideoV3::AppAssignedTargetingOptionDetails

Details for assigned app targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_APP. Corresponds to the JSON property appDetails



2145
2146
2147
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2145

def app_details
  @app_details
end

#assigned_targeting_option_idString

Output only. The unique ID of the assigned targeting option. The ID is only unique within a given resource and targeting type. It may be reused in other contexts. Corresponds to the JSON property assignedTargetingOptionId

Returns:

  • (String)


2152
2153
2154
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2152

def assigned_targeting_option_id
  @assigned_targeting_option_id
end

#assigned_targeting_option_id_aliasString

Output only. An alias for the assigned_targeting_option_id. This value can be used in place of assignedTargetingOptionId when retrieving or deleting existing targeting. This field will only be supported for all assigned targeting options of the following targeting types: * TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_DEVICE_TYPE * TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION * TARGETING_TYPE_ENVIRONMENT

  • TARGETING_TYPE_EXCHANGE * TARGETING_TYPE_GENDER * TARGETING_TYPE_HOUSEHOLD_INCOME * TARGETING_TYPE_NATIVE_CONTENT_POSITION * TARGETING_TYPE_OMID * TARGETING_TYPE_PARENTAL_STATUS * TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION * TARGETING_TYPE_VIDEO_PLAYER_SIZE * TARGETING_TYPE_VIEWABILITY This field is also supported for line item assigned targeting options of the following targeting types: * TARGETING_TYPE_CONTENT_INSTREAM_POSITION * TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION Corresponds to the JSON property assignedTargetingOptionIdAlias

Returns:

  • (String)


2170
2171
2172
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2170

def assigned_targeting_option_id_alias
  @assigned_targeting_option_id_alias
end

#audience_group_detailsGoogle::Apis::DisplayvideoV3::AudienceGroupAssignedTargetingOptionDetails

Assigned audience group targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AUDIENCE_GROUP. The relation between each group is UNION, except for excluded_first_and_third_party_audience_group and excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION with other groups. Corresponds to the JSON property audienceGroupDetails



2180
2181
2182
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2180

def audience_group_details
  @audience_group_details
end

#audio_content_type_detailsGoogle::Apis::DisplayvideoV3::AudioContentTypeAssignedTargetingOptionDetails

Details for audio content type assigned targeting option. This will be populated in the audio_content_type_details field when targeting_type is TARGETING_TYPE_AUDIO_CONTENT_TYPE. Explicitly targeting all options is not supported. Remove all audio content type targeting options to achieve this effect. Corresponds to the JSON property audioContentTypeDetails



2189
2190
2191
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2189

def audio_content_type_details
  @audio_content_type_details
end

#authorized_seller_status_detailsGoogle::Apis::DisplayvideoV3::AuthorizedSellerStatusAssignedTargetingOptionDetails

Represents an assigned authorized seller status. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. If a resource does not have an TARGETING_TYPE_AUTHORIZED_SELLER_STATUS assigned targeting option, it is using the "Authorized Direct Sellers and Resellers" option. Corresponds to the JSON property authorizedSellerStatusDetails



2198
2199
2200
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2198

def authorized_seller_status_details
  @authorized_seller_status_details
end

#browser_detailsGoogle::Apis::DisplayvideoV3::BrowserAssignedTargetingOptionDetails

Details for assigned browser targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_BROWSER. Corresponds to the JSON property browserDetails



2205
2206
2207
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2205

def browser_details
  @browser_details
end

#business_chain_detailsGoogle::Apis::DisplayvideoV3::BusinessChainAssignedTargetingOptionDetails

Details for assigned Business chain targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_BUSINESS_CHAIN. Corresponds to the JSON property businessChainDetails



2212
2213
2214
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2212

def business_chain_details
  @business_chain_details
end

#carrier_and_isp_detailsGoogle::Apis::DisplayvideoV3::CarrierAndIspAssignedTargetingOptionDetails

Details for assigned carrier and ISP targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property carrierAndIspDetails



2219
2220
2221
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2219

def carrier_and_isp_details
  @carrier_and_isp_details
end

#category_detailsGoogle::Apis::DisplayvideoV3::CategoryAssignedTargetingOptionDetails

Assigned category targeting option details. This will be populated in the category_details field when targeting_type is TARGETING_TYPE_CATEGORY. Corresponds to the JSON property categoryDetails



2225
2226
2227
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2225

def category_details
  @category_details
end

#channel_detailsGoogle::Apis::DisplayvideoV3::ChannelAssignedTargetingOptionDetails

Details for assigned channel targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_CHANNEL. Corresponds to the JSON property channelDetails



2232
2233
2234
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2232

def channel_details
  @channel_details
end

#content_duration_detailsGoogle::Apis::DisplayvideoV3::ContentDurationAssignedTargetingOptionDetails

Details for content duration assigned targeting option. This will be populated in the content_duration_details field when targeting_type is TARGETING_TYPE_CONTENT_DURATION. Explicitly targeting all options is not supported. Remove all content duration targeting options to achieve this effect. Corresponds to the JSON property contentDurationDetails



2241
2242
2243
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2241

def content_duration_details
  @content_duration_details
end

#content_genre_detailsGoogle::Apis::DisplayvideoV3::ContentGenreAssignedTargetingOptionDetails

Details for content genre assigned targeting option. This will be populated in the content_genre_details field when targeting_type is TARGETING_TYPE_CONTENT_GENRE. Explicitly targeting all options is not supported. Remove all content genre targeting options to achieve this effect. Corresponds to the JSON property contentGenreDetails



2249
2250
2251
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2249

def content_genre_details
  @content_genre_details
end

#content_instream_position_detailsGoogle::Apis::DisplayvideoV3::ContentInstreamPositionAssignedTargetingOptionDetails

Assigned content instream position targeting option details. This will be populated in the content_instream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION. Corresponds to the JSON property contentInstreamPositionDetails



2256
2257
2258
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2256

def content_instream_position_details
  @content_instream_position_details
end

#content_outstream_position_detailsGoogle::Apis::DisplayvideoV3::ContentOutstreamPositionAssignedTargetingOptionDetails

Assigned content outstream position targeting option details. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION. Corresponds to the JSON property contentOutstreamPositionDetails



2263
2264
2265
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2263

def content_outstream_position_details
  @content_outstream_position_details
end

#content_stream_type_detailsGoogle::Apis::DisplayvideoV3::ContentStreamTypeAssignedTargetingOptionDetails

Details for content stream type assigned targeting option. This will be populated in the content_stream_type_details field when targeting_type is TARGETING_TYPE_CONTENT_STREAM_TYPE. Explicitly targeting all options is not supported. Remove all content stream type targeting options to achieve this effect. Corresponds to the JSON property contentStreamTypeDetails



2272
2273
2274
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2272

def content_stream_type_details
  @content_stream_type_details
end

#content_theme_exclusion_detailsGoogle::Apis::DisplayvideoV3::ContentThemeAssignedTargetingOptionDetails

Targeting details for content theme. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_CONTENT_THEME_EXCLUSION. Corresponds to the JSON property contentThemeExclusionDetails



2279
2280
2281
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2279

def content_theme_exclusion_details
  @content_theme_exclusion_details
end

#day_and_time_detailsGoogle::Apis::DisplayvideoV3::DayAndTimeAssignedTargetingOptionDetails

Representation of a segment of time defined on a specific day of the week and with a start and end time. The time represented by start_hour must be before the time represented by end_hour. Corresponds to the JSON property dayAndTimeDetails



2286
2287
2288
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2286

def day_and_time_details
  @day_and_time_details
end

#device_make_model_detailsGoogle::Apis::DisplayvideoV3::DeviceMakeModelAssignedTargetingOptionDetails

Assigned device make and model targeting option details. This will be populated in the device_make_model_details field when targeting_type is TARGETING_TYPE_DEVICE_MAKE_MODEL. Corresponds to the JSON property deviceMakeModelDetails



2293
2294
2295
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2293

def device_make_model_details
  @device_make_model_details
end

#device_type_detailsGoogle::Apis::DisplayvideoV3::DeviceTypeAssignedTargetingOptionDetails

Targeting details for device type. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_DEVICE_TYPE. Corresponds to the JSON property deviceTypeDetails



2300
2301
2302
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2300

def device_type_details
  @device_type_details
end

#digital_content_label_exclusion_detailsGoogle::Apis::DisplayvideoV3::DigitalContentLabelAssignedTargetingOptionDetails

Targeting details for digital content label. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION. Corresponds to the JSON property digitalContentLabelExclusionDetails



2307
2308
2309
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2307

def 
  @digital_content_label_exclusion_details
end

#environment_detailsGoogle::Apis::DisplayvideoV3::EnvironmentAssignedTargetingOptionDetails

Assigned environment targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_ENVIRONMENT. Corresponds to the JSON property environmentDetails



2314
2315
2316
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2314

def environment_details
  @environment_details
end

#exchange_detailsGoogle::Apis::DisplayvideoV3::ExchangeAssignedTargetingOptionDetails

Details for assigned exchange targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_EXCHANGE. Corresponds to the JSON property exchangeDetails



2321
2322
2323
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2321

def exchange_details
  @exchange_details
end

#gender_detailsGoogle::Apis::DisplayvideoV3::GenderAssignedTargetingOptionDetails

Details for assigned gender targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_GENDER. Corresponds to the JSON property genderDetails



2328
2329
2330
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2328

def gender_details
  @gender_details
end

#geo_region_detailsGoogle::Apis::DisplayvideoV3::GeoRegionAssignedTargetingOptionDetails

Details for assigned geographic region targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_GEO_REGION. Corresponds to the JSON property geoRegionDetails



2335
2336
2337
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2335

def geo_region_details
  @geo_region_details
end

#household_income_detailsGoogle::Apis::DisplayvideoV3::HouseholdIncomeAssignedTargetingOptionDetails

Details for assigned household income targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_HOUSEHOLD_INCOME. Corresponds to the JSON property householdIncomeDetails



2342
2343
2344
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2342

def household_income_details
  @household_income_details
end

#inheritanceString

Output only. The inheritance status of the assigned targeting option. Corresponds to the JSON property inheritance

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2347

def inheritance
  @inheritance
end

#inventory_source_detailsGoogle::Apis::DisplayvideoV3::InventorySourceAssignedTargetingOptionDetails

Targeting details for inventory source. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_INVENTORY_SOURCE. Corresponds to the JSON property inventorySourceDetails



2354
2355
2356
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2354

def inventory_source_details
  @inventory_source_details
end

#inventory_source_group_detailsGoogle::Apis::DisplayvideoV3::InventorySourceGroupAssignedTargetingOptionDetails

Targeting details for inventory source group. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_INVENTORY_SOURCE_GROUP. Corresponds to the JSON property inventorySourceGroupDetails



2361
2362
2363
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2361

def inventory_source_group_details
  @inventory_source_group_details
end

#keyword_detailsGoogle::Apis::DisplayvideoV3::KeywordAssignedTargetingOptionDetails

Details for assigned keyword targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_KEYWORD. Corresponds to the JSON property keywordDetails



2368
2369
2370
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2368

def keyword_details
  @keyword_details
end

#language_detailsGoogle::Apis::DisplayvideoV3::LanguageAssignedTargetingOptionDetails

Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property languageDetails



2375
2376
2377
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2375

def language_details
  @language_details
end

#nameString

Output only. The resource name for this assigned targeting option. Corresponds to the JSON property name

Returns:

  • (String)


2380
2381
2382
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2380

def name
  @name
end

#native_content_position_detailsGoogle::Apis::DisplayvideoV3::NativeContentPositionAssignedTargetingOptionDetails

Details for native content position assigned targeting option. This will be populated in the native_content_position_details field when targeting_type is TARGETING_TYPE_NATIVE_CONTENT_POSITION. Explicitly targeting all options is not supported. Remove all native content position targeting options to achieve this effect. Corresponds to the JSON property nativeContentPositionDetails



2389
2390
2391
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2389

def native_content_position_details
  @native_content_position_details
end

#negative_keyword_list_detailsGoogle::Apis::DisplayvideoV3::NegativeKeywordListAssignedTargetingOptionDetails

Targeting details for negative keyword list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_NEGATIVE_KEYWORD_LIST. Corresponds to the JSON property negativeKeywordListDetails



2396
2397
2398
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2396

def negative_keyword_list_details
  @negative_keyword_list_details
end

#omid_detailsGoogle::Apis::DisplayvideoV3::OmidAssignedTargetingOptionDetails

Represents a targetable Open Measurement enabled inventory type. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_OMID. Corresponds to the JSON property omidDetails



2403
2404
2405
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2403

def omid_details
  @omid_details
end

#on_screen_position_detailsGoogle::Apis::DisplayvideoV3::OnScreenPositionAssignedTargetingOptionDetails

On screen position targeting option details. This will be populated in the on_screen_position_details field when targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION. Corresponds to the JSON property onScreenPositionDetails



2410
2411
2412
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2410

def on_screen_position_details
  @on_screen_position_details
end

#operating_system_detailsGoogle::Apis::DisplayvideoV3::OperatingSystemAssignedTargetingOptionDetails

Assigned operating system targeting option details. This will be populated in the operating_system_details field when targeting_type is TARGETING_TYPE_OPERATING_SYSTEM. Corresponds to the JSON property operatingSystemDetails



2417
2418
2419
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2417

def operating_system_details
  @operating_system_details
end

#parental_status_detailsGoogle::Apis::DisplayvideoV3::ParentalStatusAssignedTargetingOptionDetails

Details for assigned parental status targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_PARENTAL_STATUS. Corresponds to the JSON property parentalStatusDetails



2424
2425
2426
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2424

def parental_status_details
  @parental_status_details
end

#poi_detailsGoogle::Apis::DisplayvideoV3::PoiAssignedTargetingOptionDetails

Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_POI. Corresponds to the JSON property poiDetails



2431
2432
2433
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2431

def poi_details
  @poi_details
end

#proximity_location_list_detailsGoogle::Apis::DisplayvideoV3::ProximityLocationListAssignedTargetingOptionDetails

Targeting details for proximity location list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_PROXIMITY_LOCATION_LIST. Corresponds to the JSON property proximityLocationListDetails



2438
2439
2440
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2438

def proximity_location_list_details
  @proximity_location_list_details
end

#regional_location_list_detailsGoogle::Apis::DisplayvideoV3::RegionalLocationListAssignedTargetingOptionDetails

Targeting details for regional location list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_REGIONAL_LOCATION_LIST. Corresponds to the JSON property regionalLocationListDetails



2445
2446
2447
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2445

def regional_location_list_details
  @regional_location_list_details
end

#sensitive_category_exclusion_detailsGoogle::Apis::DisplayvideoV3::SensitiveCategoryAssignedTargetingOptionDetails

Targeting details for sensitive category. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION. Corresponds to the JSON property sensitiveCategoryExclusionDetails



2452
2453
2454
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2452

def sensitive_category_exclusion_details
  @sensitive_category_exclusion_details
end

#session_position_detailsGoogle::Apis::DisplayvideoV3::SessionPositionAssignedTargetingOptionDetails

Details for session position assigned targeting option. This will be populated in the session_position_details field when targeting_type is TARGETING_TYPE_SESSION_POSITION. Corresponds to the JSON property sessionPositionDetails



2459
2460
2461
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2459

def session_position_details
  @session_position_details
end

#sub_exchange_detailsGoogle::Apis::DisplayvideoV3::SubExchangeAssignedTargetingOptionDetails

Details for assigned sub-exchange targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_SUB_EXCHANGE. Corresponds to the JSON property subExchangeDetails



2466
2467
2468
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2466

def sub_exchange_details
  @sub_exchange_details
end

#targeting_typeString

Output only. Identifies the type of this assigned targeting option. Corresponds to the JSON property targetingType

Returns:

  • (String)


2471
2472
2473
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2471

def targeting_type
  @targeting_type
end

#third_party_verifier_detailsGoogle::Apis::DisplayvideoV3::ThirdPartyVerifierAssignedTargetingOptionDetails

Assigned third party verifier targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_THIRD_PARTY_VERIFIER. Corresponds to the JSON property thirdPartyVerifierDetails



2478
2479
2480
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2478

def third_party_verifier_details
  @third_party_verifier_details
end

#url_detailsGoogle::Apis::DisplayvideoV3::UrlAssignedTargetingOptionDetails

Details for assigned URL targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_URL. Corresponds to the JSON property urlDetails



2485
2486
2487
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2485

def url_details
  @url_details
end

#user_rewarded_content_detailsGoogle::Apis::DisplayvideoV3::UserRewardedContentAssignedTargetingOptionDetails

User rewarded content targeting option details. This will be populated in the user_rewarded_content_details field when targeting_type is TARGETING_TYPE_USER_REWARDED_CONTENT. Corresponds to the JSON property userRewardedContentDetails



2492
2493
2494
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2492

def user_rewarded_content_details
  @user_rewarded_content_details
end

#video_player_size_detailsGoogle::Apis::DisplayvideoV3::VideoPlayerSizeAssignedTargetingOptionDetails

Video player size targeting option details. This will be populated in the video_player_size_details field when targeting_type is TARGETING_TYPE_VIDEO_PLAYER_SIZE. Explicitly targeting all options is not supported. Remove all video player size targeting options to achieve this effect. Corresponds to the JSON property videoPlayerSizeDetails



2501
2502
2503
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2501

def video_player_size_details
  @video_player_size_details
end

#viewability_detailsGoogle::Apis::DisplayvideoV3::ViewabilityAssignedTargetingOptionDetails

Assigned viewability targeting option details. This will be populated in the viewability_details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_VIEWABILITY. Corresponds to the JSON property viewabilityDetails



2508
2509
2510
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2508

def viewability_details
  @viewability_details
end

#youtube_channel_detailsGoogle::Apis::DisplayvideoV3::YoutubeChannelAssignedTargetingOptionDetails

Details for YouTube channel assigned targeting option. This will be populated in the youtube_channel_details field when targeting_type is TARGETING_TYPE_YOUTUBE_CHANNEL. Corresponds to the JSON property youtubeChannelDetails



2515
2516
2517
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2515

def youtube_channel_details
  @youtube_channel_details
end

#youtube_channel_pack_detailsGoogle::Apis::DisplayvideoV3::YoutubeChannelPackAssignedTargetingOptionDetails

Details for YouTube channel pack assigned targeting option. This will be populated in the youtube_channel_pack_details field when targeting_type is TARGETING_TYPE_YOUTUBE_CHANNEL_PACK. Corresponds to the JSON property youtubeChannelPackDetails



2522
2523
2524
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2522

def youtube_channel_pack_details
  @youtube_channel_pack_details
end

#youtube_video_detailsGoogle::Apis::DisplayvideoV3::YoutubeVideoAssignedTargetingOptionDetails

Details for YouTube video assigned targeting option. This will be populated in the youtube_video_details field when targeting_type is TARGETING_TYPE_YOUTUBE_VIDEO. Corresponds to the JSON property youtubeVideoDetails



2529
2530
2531
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2529

def youtube_video_details
  @youtube_video_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2536

def update!(**args)
  @age_range_details = args[:age_range_details] if args.key?(:age_range_details)
  @app_category_details = args[:app_category_details] if args.key?(:app_category_details)
  @app_details = args[:app_details] if args.key?(:app_details)
  @assigned_targeting_option_id = args[:assigned_targeting_option_id] if args.key?(:assigned_targeting_option_id)
  @assigned_targeting_option_id_alias = args[:assigned_targeting_option_id_alias] if args.key?(:assigned_targeting_option_id_alias)
  @audience_group_details = args[:audience_group_details] if args.key?(:audience_group_details)
  @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details)
  @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details)
  @browser_details = args[:browser_details] if args.key?(:browser_details)
  @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details)
  @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details)
  @category_details = args[:category_details] if args.key?(:category_details)
  @channel_details = args[:channel_details] if args.key?(:channel_details)
  @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details)
  @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details)
  @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details)
  @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details)
  @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details)
  @content_theme_exclusion_details = args[:content_theme_exclusion_details] if args.key?(:content_theme_exclusion_details)
  @day_and_time_details = args[:day_and_time_details] if args.key?(:day_and_time_details)
  @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details)
  @device_type_details = args[:device_type_details] if args.key?(:device_type_details)
  @digital_content_label_exclusion_details = args[:digital_content_label_exclusion_details] if args.key?(:digital_content_label_exclusion_details)
  @environment_details = args[:environment_details] if args.key?(:environment_details)
  @exchange_details = args[:exchange_details] if args.key?(:exchange_details)
  @gender_details = args[:gender_details] if args.key?(:gender_details)
  @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details)
  @household_income_details = args[:household_income_details] if args.key?(:household_income_details)
  @inheritance = args[:inheritance] if args.key?(:inheritance)
  @inventory_source_details = args[:inventory_source_details] if args.key?(:inventory_source_details)
  @inventory_source_group_details = args[:inventory_source_group_details] if args.key?(:inventory_source_group_details)
  @keyword_details = args[:keyword_details] if args.key?(:keyword_details)
  @language_details = args[:language_details] if args.key?(:language_details)
  @name = args[:name] if args.key?(:name)
  @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details)
  @negative_keyword_list_details = args[:negative_keyword_list_details] if args.key?(:negative_keyword_list_details)
  @omid_details = args[:omid_details] if args.key?(:omid_details)
  @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details)
  @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details)
  @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details)
  @poi_details = args[:poi_details] if args.key?(:poi_details)
  @proximity_location_list_details = args[:proximity_location_list_details] if args.key?(:proximity_location_list_details)
  @regional_location_list_details = args[:regional_location_list_details] if args.key?(:regional_location_list_details)
  @sensitive_category_exclusion_details = args[:sensitive_category_exclusion_details] if args.key?(:sensitive_category_exclusion_details)
  @session_position_details = args[:session_position_details] if args.key?(:session_position_details)
  @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
  @third_party_verifier_details = args[:third_party_verifier_details] if args.key?(:third_party_verifier_details)
  @url_details = args[:url_details] if args.key?(:url_details)
  @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details)
  @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details)
  @viewability_details = args[:viewability_details] if args.key?(:viewability_details)
  @youtube_channel_details = args[:youtube_channel_details] if args.key?(:youtube_channel_details)
  @youtube_channel_pack_details = args[:youtube_channel_pack_details] if args.key?(:youtube_channel_pack_details)
  @youtube_video_details = args[:youtube_video_details] if args.key?(:youtube_video_details)
end