Class: Google::Apis::DisplayvideoV3::AssignedUserRole
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AssignedUserRole
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single assigned user role, which defines a user's authorized interaction with a specified partner or advertiser.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
The ID of the advertiser that the assigend user role applies to.
-
#assigned_user_role_id ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
The ID of the partner that the assigned user role applies to.
-
#user_role ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssignedUserRole
constructor
A new instance of AssignedUserRole.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssignedUserRole
Returns a new instance of AssignedUserRole.
2620 2621 2622 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
The ID of the advertiser that the assigend user role applies to.
Corresponds to the JSON property advertiserId
2603 2604 2605 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2603 def advertiser_id @advertiser_id end |
#assigned_user_role_id ⇒ String
Output only. The ID of the assigned user role.
Corresponds to the JSON property assignedUserRoleId
2608 2609 2610 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2608 def assigned_user_role_id @assigned_user_role_id end |
#partner_id ⇒ Fixnum
The ID of the partner that the assigned user role applies to.
Corresponds to the JSON property partnerId
2613 2614 2615 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2613 def partner_id @partner_id end |
#user_role ⇒ String
Required. The user role to assign to a user for the entity.
Corresponds to the JSON property userRole
2618 2619 2620 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2618 def user_role @user_role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2625 2626 2627 2628 2629 2630 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2625 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @assigned_user_role_id = args[:assigned_user_role_id] if args.key?(:assigned_user_role_id) @partner_id = args[:partner_id] if args.key?(:partner_id) @user_role = args[:user_role] if args.key?(:user_role) end |