Class: Google::Apis::DisplayvideoV3::AssignedUserRole

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single assigned user role, which defines a user's authorized interaction with a specified partner or advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssignedUserRole

Returns a new instance of AssignedUserRole.



2550
2551
2552
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that the assigend user role applies to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


2533
2534
2535
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2533

def advertiser_id
  @advertiser_id
end

#assigned_user_role_idString

Output only. The ID of the assigned user role. Corresponds to the JSON property assignedUserRoleId

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2538

def assigned_user_role_id
  @assigned_user_role_id
end

#partner_idFixnum

The ID of the partner that the assigned user role applies to. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


2543
2544
2545
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2543

def partner_id
  @partner_id
end

#user_roleString

Required. The user role to assign to a user for the entity. Corresponds to the JSON property userRole

Returns:

  • (String)


2548
2549
2550
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2548

def user_role
  @user_role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2555
2556
2557
2558
2559
2560
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2555

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @assigned_user_role_id = args[:assigned_user_role_id] if args.key?(:assigned_user_role_id)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @user_role = args[:user_role] if args.key?(:user_role)
end