Class: Google::Apis::DisplayvideoV3::AudienceGroupAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AudienceGroupAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Assigned audience group targeting option details. This will be populated in
the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_AUDIENCE_GROUP. The relation between each group is UNION,
except for excluded_first_and_third_party_audience_group and
excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION
with other groups.
Instance Attribute Summary collapse
-
#excluded_first_and_third_party_audience_group ⇒ Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceGroup
Details of first and third party audience group.
-
#excluded_google_audience_group ⇒ Google::Apis::DisplayvideoV3::GoogleAudienceGroup
Details of Google audience group.
-
#included_combined_audience_group ⇒ Google::Apis::DisplayvideoV3::CombinedAudienceGroup
Details of combined audience group.
-
#included_custom_list_group ⇒ Google::Apis::DisplayvideoV3::CustomListGroup
Details of custom list group.
-
#included_first_and_third_party_audience_groups ⇒ Array<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceGroup>
Optional.
-
#included_google_audience_group ⇒ Google::Apis::DisplayvideoV3::GoogleAudienceGroup
Details of Google audience group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudienceGroupAssignedTargetingOptionDetails
constructor
A new instance of AudienceGroupAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudienceGroupAssignedTargetingOptionDetails
Returns a new instance of AudienceGroupAssignedTargetingOptionDetails.
2682 2683 2684 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_first_and_third_party_audience_group ⇒ Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceGroup
Details of first and third party audience group. All first and third party
audience targeting settings are logically ‘OR’ of each other.
Corresponds to the JSON property excludedFirstAndThirdPartyAudienceGroup
2646 2647 2648 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2646 def excluded_first_and_third_party_audience_group @excluded_first_and_third_party_audience_group end |
#excluded_google_audience_group ⇒ Google::Apis::DisplayvideoV3::GoogleAudienceGroup
Details of Google audience group. All Google audience targeting settings are
logically ‘OR’ of each other.
Corresponds to the JSON property excludedGoogleAudienceGroup
2652 2653 2654 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2652 def excluded_google_audience_group @excluded_google_audience_group end |
#included_combined_audience_group ⇒ Google::Apis::DisplayvideoV3::CombinedAudienceGroup
Details of combined audience group. All combined audience targeting settings
are logically ‘OR’ of each other.
Corresponds to the JSON property includedCombinedAudienceGroup
2658 2659 2660 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2658 def included_combined_audience_group @included_combined_audience_group end |
#included_custom_list_group ⇒ Google::Apis::DisplayvideoV3::CustomListGroup
Details of custom list group. All custom list targeting settings are logically
‘OR’ of each other.
Corresponds to the JSON property includedCustomListGroup
2664 2665 2666 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2664 def included_custom_list_group @included_custom_list_group end |
#included_first_and_third_party_audience_groups ⇒ Array<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceGroup>
Optional. The first and third party audience ids and recencies of included
first and third party audience groups. Each first and third party audience
group contains first and third party audience ids only. The relation between
each first and third party audience group is INTERSECTION, and the result is
UNION'ed with other audience groups. Repeated groups with the same settings
will be ignored.
Corresponds to the JSON property includedFirstAndThirdPartyAudienceGroups
2674 2675 2676 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2674 def included_first_and_third_party_audience_groups @included_first_and_third_party_audience_groups end |
#included_google_audience_group ⇒ Google::Apis::DisplayvideoV3::GoogleAudienceGroup
Details of Google audience group. All Google audience targeting settings are
logically ‘OR’ of each other.
Corresponds to the JSON property includedGoogleAudienceGroup
2680 2681 2682 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2680 def included_google_audience_group @included_google_audience_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2687 2688 2689 2690 2691 2692 2693 2694 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2687 def update!(**args) @excluded_first_and_third_party_audience_group = args[:excluded_first_and_third_party_audience_group] if args.key?(:excluded_first_and_third_party_audience_group) @excluded_google_audience_group = args[:excluded_google_audience_group] if args.key?(:excluded_google_audience_group) @included_combined_audience_group = args[:included_combined_audience_group] if args.key?(:included_combined_audience_group) @included_custom_list_group = args[:included_custom_list_group] if args.key?(:included_custom_list_group) @included_first_and_third_party_audience_groups = args[:included_first_and_third_party_audience_groups] if args.key?(:included_first_and_third_party_audience_groups) @included_google_audience_group = args[:included_google_audience_group] if args.key?(:included_google_audience_group) end |