Class: Google::Apis::DisplayvideoV3::AudioAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::AudioAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for an audio ad.
Instance Attribute Summary collapse
-
#display_url ⇒ String
The webpage address that appears with the ad.
-
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
-
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
-
#video ⇒ Google::Apis::DisplayvideoV3::YoutubeVideoDetails
Details of a YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudioAd
constructor
A new instance of AudioAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudioAd
Returns a new instance of AudioAd.
2651 2652 2653 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_url ⇒ String
The webpage address that appears with the ad.
Corresponds to the JSON property displayUrl
2634 2635 2636 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2634 def display_url @display_url end |
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
Corresponds to the JSON property finalUrl
2639 2640 2641 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2639 def final_url @final_url end |
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
2644 2645 2646 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2644 def tracking_url @tracking_url end |
#video ⇒ Google::Apis::DisplayvideoV3::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
2649 2650 2651 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2649 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2656 2657 2658 2659 2660 2661 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2656 def update!(**args) @display_url = args[:display_url] if args.key?(:display_url) @final_url = args[:final_url] if args.key?(:final_url) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @video = args[:video] if args.key?(:video) end |