Class: Google::Apis::DisplayvideoV3::BiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the bid strategy. Bid strategy determines the bid price.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiddingStrategy

Returns a new instance of BiddingStrategy.



2892
2893
2894
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_bidGoogle::Apis::DisplayvideoV3::FixedBidStrategy

A strategy that uses a fixed bidding price. Corresponds to the JSON property fixedBid



2873
2874
2875
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2873

def fixed_bid
  @fixed_bid
end

#maximize_spend_auto_bidGoogle::Apis::DisplayvideoV3::MaximizeSpendBidStrategy

A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget. Corresponds to the JSON property maximizeSpendAutoBid



2879
2880
2881
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2879

def maximize_spend_auto_bid
  @maximize_spend_auto_bid
end

#performance_goal_auto_bidGoogle::Apis::DisplayvideoV3::PerformanceGoalBidStrategy

A strategy that automatically adjusts the bid to meet or beat a specified performance goal. Corresponds to the JSON property performanceGoalAutoBid



2885
2886
2887
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2885

def performance_goal_auto_bid
  @performance_goal_auto_bid
end

#youtube_and_partners_bidGoogle::Apis::DisplayvideoV3::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property youtubeAndPartnersBid



2890
2891
2892
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2890

def youtube_and_partners_bid
  @youtube_and_partners_bid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2897
2898
2899
2900
2901
2902
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 2897

def update!(**args)
  @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid)
  @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid)
  @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid)
  @youtube_and_partners_bid = args[:youtube_and_partners_bid] if args.key?(:youtube_and_partners_bid)
end