Class: Google::Apis::DisplayvideoV3::BulkListAssignedTargetingOptionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkListAssignedTargetingOptionsResponse

Returns a new instance of BulkListAssignedTargetingOptionsResponse.



3565
3566
3567
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#line_item_assigned_targeting_optionsArray<Google::Apis::DisplayvideoV3::LineItemAssignedTargetingOption>

The list of wrapper objects, each providing an assigned targeting option and the line item it is assigned to. This list will be absent if empty. Corresponds to the JSON property lineItemAssignedTargetingOptions



3555
3556
3557
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3555

def line_item_assigned_targeting_options
  @line_item_assigned_targeting_options
end

#next_page_tokenString

A token identifying the next page of results. This value should be specified as the pageToken in a subsequent call to BulkListAssignedTargetingOptions to fetch the next page of results. This token will be absent if there are no more line_item_assigned_targeting_options to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3563
3564
3565
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3563

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3570
3571
3572
3573
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3570

def update!(**args)
  @line_item_assigned_targeting_options = args[:line_item_assigned_targeting_options] if args.key?(:line_item_assigned_targeting_options)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end