Class: Google::Apis::DisplayvideoV3::Campaign
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::Campaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single campaign.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV3::CampaignBudget>
The list of budgets available to this campaign.
-
#campaign_flight ⇒ Google::Apis::DisplayvideoV3::CampaignFlight
Settings that track the planned spend and duration of a campaign.
-
#campaign_goal ⇒ Google::Apis::DisplayvideoV3::CampaignGoal
Settings that control the goal of a campaign.
-
#campaign_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Campaign
constructor
A new instance of Campaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Campaign
Returns a new instance of Campaign.
3988 3989 3990 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the campaign belongs to.
Corresponds to the JSON property advertiserId
3934 3935 3936 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3934 def advertiser_id @advertiser_id end |
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV3::CampaignBudget>
The list of budgets available to this campaign. If this field is not set, the
campaign uses an unlimited budget.
Corresponds to the JSON property campaignBudgets
3940 3941 3942 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3940 def campaign_budgets @campaign_budgets end |
#campaign_flight ⇒ Google::Apis::DisplayvideoV3::CampaignFlight
Settings that track the planned spend and duration of a campaign.
Corresponds to the JSON property campaignFlight
3945 3946 3947 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3945 def campaign_flight @campaign_flight end |
#campaign_goal ⇒ Google::Apis::DisplayvideoV3::CampaignGoal
Settings that control the goal of a campaign.
Corresponds to the JSON property campaignGoal
3950 3951 3952 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3950 def campaign_goal @campaign_goal end |
#campaign_id ⇒ Fixnum
Output only. The unique ID of the campaign. Assigned by the system.
Corresponds to the JSON property campaignId
3955 3956 3957 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3955 def campaign_id @campaign_id end |
#display_name ⇒ String
Required. The display name of the campaign. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
3961 3962 3963 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3961 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the insertion orders under this campaign can
spend their budgets and bid on inventory. * Accepted values are
ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. *
For CreateCampaign method, ENTITY_STATUS_ARCHIVED is not allowed.
Corresponds to the JSON property entityStatus
3969 3970 3971 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3969 def entity_status @entity_status end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
3975 3976 3977 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3975 def frequency_cap @frequency_cap end |
#name ⇒ String
Output only. The resource name of the campaign.
Corresponds to the JSON property name
3980 3981 3982 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3980 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the campaign was last updated. Assigned by the
system.
Corresponds to the JSON property updateTime
3986 3987 3988 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3986 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3993 3994 3995 3996 3997 3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3993 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @campaign_budgets = args[:campaign_budgets] if args.key?(:campaign_budgets) @campaign_flight = args[:campaign_flight] if args.key?(:campaign_flight) @campaign_goal = args[:campaign_goal] if args.key?(:campaign_goal) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |