Class: Google::Apis::DisplayvideoV3::Campaign
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::Campaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single campaign.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV3::CampaignBudget>
The list of budgets available to this campaign.
-
#campaign_flight ⇒ Google::Apis::DisplayvideoV3::CampaignFlight
Settings that track the planned spend and duration of a campaign.
-
#campaign_goal ⇒ Google::Apis::DisplayvideoV3::CampaignGoal
Settings that control the goal of a campaign.
-
#campaign_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Campaign
constructor
A new instance of Campaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Campaign
Returns a new instance of Campaign.
3833 3834 3835 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the campaign belongs to.
Corresponds to the JSON property advertiserId
3779 3780 3781 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3779 def advertiser_id @advertiser_id end |
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV3::CampaignBudget>
The list of budgets available to this campaign. If this field is not set, the
campaign uses an unlimited budget.
Corresponds to the JSON property campaignBudgets
3785 3786 3787 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3785 def campaign_budgets @campaign_budgets end |
#campaign_flight ⇒ Google::Apis::DisplayvideoV3::CampaignFlight
Settings that track the planned spend and duration of a campaign.
Corresponds to the JSON property campaignFlight
3790 3791 3792 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3790 def campaign_flight @campaign_flight end |
#campaign_goal ⇒ Google::Apis::DisplayvideoV3::CampaignGoal
Settings that control the goal of a campaign.
Corresponds to the JSON property campaignGoal
3795 3796 3797 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3795 def campaign_goal @campaign_goal end |
#campaign_id ⇒ Fixnum
Output only. The unique ID of the campaign. Assigned by the system.
Corresponds to the JSON property campaignId
3800 3801 3802 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3800 def campaign_id @campaign_id end |
#display_name ⇒ String
Required. The display name of the campaign. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
3806 3807 3808 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3806 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the insertion orders under this campaign can
spend their budgets and bid on inventory. * Accepted values are
ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. *
For CreateCampaign method, ENTITY_STATUS_ARCHIVED is not allowed.
Corresponds to the JSON property entityStatus
3814 3815 3816 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3814 def entity_status @entity_status end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
3820 3821 3822 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3820 def frequency_cap @frequency_cap end |
#name ⇒ String
Output only. The resource name of the campaign.
Corresponds to the JSON property name
3825 3826 3827 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3825 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the campaign was last updated. Assigned by the
system.
Corresponds to the JSON property updateTime
3831 3832 3833 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3831 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 3838 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @campaign_budgets = args[:campaign_budgets] if args.key?(:campaign_budgets) @campaign_flight = args[:campaign_flight] if args.key?(:campaign_flight) @campaign_goal = args[:campaign_goal] if args.key?(:campaign_goal) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |