Class: Google::Apis::DisplayvideoV3::CampaignBudget
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::CampaignBudget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings that control how the campaign budget is allocated.
Instance Attribute Summary collapse
-
#budget_amount_micros ⇒ Fixnum
Required.
-
#budget_id ⇒ Fixnum
The unique ID of the campaign budget.
-
#budget_unit ⇒ String
Required.
-
#date_range ⇒ Google::Apis::DisplayvideoV3::DateRange
A date range.
-
#display_name ⇒ String
Required.
-
#external_budget_id ⇒ String
Immutable.
-
#external_budget_source ⇒ String
Required.
-
#invoice_grouping_id ⇒ String
Immutable.
-
#prisma_config ⇒ Google::Apis::DisplayvideoV3::PrismaConfig
Settings specific to the Mediaocean Prisma tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CampaignBudget
constructor
A new instance of CampaignBudget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CampaignBudget
Returns a new instance of CampaignBudget.
4068 4069 4070 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_amount_micros ⇒ Fixnum
Required. The total amount the linked insertion order segments can budget. The
amount is in micros. Must be greater than 0. For example, 500000000 represents
500 standard units of the currency.
Corresponds to the JSON property budgetAmountMicros
4016 4017 4018 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4016 def budget_amount_micros @budget_amount_micros end |
#budget_id ⇒ Fixnum
The unique ID of the campaign budget. Assigned by the system. Do not set for
new budgets. Must be included when updating or adding budgets to
campaign_budgets. Otherwise, a new ID will be generated and assigned.
Corresponds to the JSON property budgetId
4023 4024 4025 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4023 def budget_id @budget_id end |
#budget_unit ⇒ String
Required. Immutable. Specifies whether the budget is measured in currency or
impressions.
Corresponds to the JSON property budgetUnit
4029 4030 4031 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4029 def budget_unit @budget_unit end |
#date_range ⇒ Google::Apis::DisplayvideoV3::DateRange
A date range.
Corresponds to the JSON property dateRange
4034 4035 4036 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4034 def date_range @date_range end |
#display_name ⇒ String
Required. The display name of the budget. Must be UTF-8 encoded with a maximum
size of 240 bytes.
Corresponds to the JSON property displayName
4040 4041 4042 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4040 def display_name @display_name end |
#external_budget_id ⇒ String
Immutable. The ID identifying this budget to the external source. If this
field is set and the invoice detail level of the corresponding billing profile
is set to "Budget level PO", all impressions served against this budget will
include this ID on the invoice. Must be unique under the campaign.
Corresponds to the JSON property externalBudgetId
4048 4049 4050 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4048 def external_budget_id @external_budget_id end |
#external_budget_source ⇒ String
Required. The external source of the budget.
Corresponds to the JSON property externalBudgetSource
4053 4054 4055 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4053 def external_budget_source @external_budget_source end |
#invoice_grouping_id ⇒ String
Immutable. The ID used to group budgets to be included the same invoice. If
this field is set and the invoice level of the corresponding billing profile
is set to "Budget invoice grouping ID", all external_budget_id sharing the
same invoice_grouping_id will be grouped in the same invoice.
Corresponds to the JSON property invoiceGroupingId
4061 4062 4063 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4061 def invoice_grouping_id @invoice_grouping_id end |
#prisma_config ⇒ Google::Apis::DisplayvideoV3::PrismaConfig
Settings specific to the Mediaocean Prisma tool.
Corresponds to the JSON property prismaConfig
4066 4067 4068 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4066 def prisma_config @prisma_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4073 def update!(**args) @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros) @budget_id = args[:budget_id] if args.key?(:budget_id) @budget_unit = args[:budget_unit] if args.key?(:budget_unit) @date_range = args[:date_range] if args.key?(:date_range) @display_name = args[:display_name] if args.key?(:display_name) @external_budget_id = args[:external_budget_id] if args.key?(:external_budget_id) @external_budget_source = args[:external_budget_source] if args.key?(:external_budget_source) @invoice_grouping_id = args[:invoice_grouping_id] if args.key?(:invoice_grouping_id) @prisma_config = args[:prisma_config] if args.key?(:prisma_config) end |