Class: Google::Apis::DisplayvideoV3::CmHybridConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::CmHybridConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings for advertisers that use both Campaign Manager 360 (CM360) and third- party ad servers.
Instance Attribute Summary collapse
-
#cm_account_id ⇒ Fixnum
Required.
-
#cm_advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#cm_floodlight_config_id ⇒ Fixnum
Required.
-
#cm_floodlight_linking_authorized ⇒ Boolean
(also: #cm_floodlight_linking_authorized?)
Required.
-
#cm_syncable_site_ids ⇒ Array<Fixnum>
A list of CM360 sites whose placements will be synced to DV360 as creatives.
-
#dv360_to_cm_cost_reporting_enabled ⇒ Boolean
(also: #dv360_to_cm_cost_reporting_enabled?)
Whether or not to report DV360 cost to CM360.
-
#dv360_to_cm_data_sharing_enabled ⇒ Boolean
(also: #dv360_to_cm_data_sharing_enabled?)
Whether or not to include DV360 data in CM360 data transfer reports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CmHybridConfig
constructor
A new instance of CmHybridConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CmHybridConfig
Returns a new instance of CmHybridConfig.
4457 4458 4459 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cm_account_id ⇒ Fixnum
Required. Immutable. Account ID of the CM360 Floodlight configuration linked
with the DV360 advertiser.
Corresponds to the JSON property cmAccountId
4415 4416 4417 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4415 def cm_account_id @cm_account_id end |
#cm_advertiser_ids ⇒ Array<Fixnum>
Output only. The set of CM360 Advertiser IDs sharing the CM360 Floodlight
configuration.
Corresponds to the JSON property cmAdvertiserIds
4421 4422 4423 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4421 def cm_advertiser_ids @cm_advertiser_ids end |
#cm_floodlight_config_id ⇒ Fixnum
Required. Immutable. ID of the CM360 Floodlight configuration linked with the
DV360 advertiser.
Corresponds to the JSON property cmFloodlightConfigId
4427 4428 4429 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4427 def cm_floodlight_config_id @cm_floodlight_config_id end |
#cm_floodlight_linking_authorized ⇒ Boolean Also known as:
Required. Immutable. By setting this field to true, you, on behalf of your
company, authorize the sharing of information from the given Floodlight
configuration to this Display & Video 360 advertiser.
Corresponds to the JSON property cmFloodlightLinkingAuthorized
4434 4435 4436 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4434 def @cm_floodlight_linking_authorized end |
#cm_syncable_site_ids ⇒ Array<Fixnum>
A list of CM360 sites whose placements will be synced to DV360 as creatives.
If absent or empty in CreateAdvertiser method, the system will automatically
create a CM360 site. Removing sites from this list may cause DV360 creatives
synced from CM360 to be deleted. At least one site must be specified.
Corresponds to the JSON property cmSyncableSiteIds
4443 4444 4445 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4443 def cm_syncable_site_ids @cm_syncable_site_ids end |
#dv360_to_cm_cost_reporting_enabled ⇒ Boolean Also known as: dv360_to_cm_cost_reporting_enabled?
Whether or not to report DV360 cost to CM360.
Corresponds to the JSON property dv360ToCmCostReportingEnabled
4448 4449 4450 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4448 def dv360_to_cm_cost_reporting_enabled @dv360_to_cm_cost_reporting_enabled end |
#dv360_to_cm_data_sharing_enabled ⇒ Boolean Also known as: dv360_to_cm_data_sharing_enabled?
Whether or not to include DV360 data in CM360 data transfer reports.
Corresponds to the JSON property dv360ToCmDataSharingEnabled
4454 4455 4456 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4454 def dv360_to_cm_data_sharing_enabled @dv360_to_cm_data_sharing_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4462 4463 4464 4465 4466 4467 4468 4469 4470 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4462 def update!(**args) @cm_account_id = args[:cm_account_id] if args.key?(:cm_account_id) @cm_advertiser_ids = args[:cm_advertiser_ids] if args.key?(:cm_advertiser_ids) @cm_floodlight_config_id = args[:cm_floodlight_config_id] if args.key?(:cm_floodlight_config_id) @cm_floodlight_linking_authorized = args[:cm_floodlight_linking_authorized] if args.key?(:cm_floodlight_linking_authorized) @cm_syncable_site_ids = args[:cm_syncable_site_ids] if args.key?(:cm_syncable_site_ids) @dv360_to_cm_cost_reporting_enabled = args[:dv360_to_cm_cost_reporting_enabled] if args.key?(:dv360_to_cm_cost_reporting_enabled) @dv360_to_cm_data_sharing_enabled = args[:dv360_to_cm_data_sharing_enabled] if args.key?(:dv360_to_cm_data_sharing_enabled) end |