Class: Google::Apis::DisplayvideoV3::CombinedAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::CombinedAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ CombinedAudienceGroup
constructor
A new instance of CombinedAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CombinedAudienceGroup
Returns a new instance of CombinedAudienceGroup.
4334 4335 4336 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV3::CombinedAudienceTargetingSetting>
Required. All combined audience targeting settings in combined audience group.
Repeated settings with the same id will be ignored. The number of combined
audience settings should be no more than five, error will be thrown otherwise.
Corresponds to the JSON property settings
4332 4333 4334 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4332 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4339 4340 4341 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4339 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |