Class: Google::Apis::DisplayvideoV3::CommonInStreamAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Common attributes for in-stream, non-skippable and bumper ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonInStreamAttribute

Returns a new instance of CommonInStreamAttribute.



4616
4617
4618
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelString

The text on the call-to-action button. Corresponds to the JSON property actionButtonLabel

Returns:

  • (String)


4584
4585
4586
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4584

def action_button_label
  @action_button_label
end

#action_headlineString

The headline of the call-to-action banner. Corresponds to the JSON property actionHeadline

Returns:

  • (String)


4589
4590
4591
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4589

def action_headline
  @action_headline
end

#companion_bannerGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property companionBanner



4594
4595
4596
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4594

def companion_banner
  @companion_banner
end

#display_urlString

The webpage address that appears with the ad. Corresponds to the JSON property displayUrl

Returns:

  • (String)


4599
4600
4601
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4599

def display_url
  @display_url
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4604
4605
4606
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4604

def final_url
  @final_url
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


4609
4610
4611
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4609

def tracking_url
  @tracking_url
end

#videoGoogle::Apis::DisplayvideoV3::YoutubeVideoDetails

Details of a YouTube video. Corresponds to the JSON property video



4614
4615
4616
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4614

def video
  @video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4621
4622
4623
4624
4625
4626
4627
4628
4629
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4621

def update!(**args)
  @action_button_label = args[:action_button_label] if args.key?(:action_button_label)
  @action_headline = args[:action_headline] if args.key?(:action_headline)
  @companion_banner = args[:companion_banner] if args.key?(:companion_banner)
  @display_url = args[:display_url] if args.key?(:display_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @video = args[:video] if args.key?(:video)
end