Class: Google::Apis::DisplayvideoV3::ConversionCountingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ConversionCountingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting.
Instance Attribute Summary collapse
-
#floodlight_activity_configs ⇒ Array<Google::Apis::DisplayvideoV3::TrackingFloodlightActivityConfig>
The Floodlight activity configs used to track conversions.
-
#post_view_count_percentage_millis ⇒ Fixnum
The percentage of post-view conversions to count, in millis (1/1000 of a percent).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversionCountingConfig
constructor
A new instance of ConversionCountingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversionCountingConfig
Returns a new instance of ConversionCountingConfig.
4876 4877 4878 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#floodlight_activity_configs ⇒ Array<Google::Apis::DisplayvideoV3::TrackingFloodlightActivityConfig>
The Floodlight activity configs used to track conversions. The number of
conversions counted is the sum of all of the conversions counted by all of the
Floodlight activity IDs specified in this field. This field can't be updated
if a custom bidding algorithm is assigned to the line item. If you set this
field and assign a custom bidding algorithm in the same request, the
floodlight activities must match the ones used by the custom bidding algorithm.
Corresponds to the JSON property floodlightActivityConfigs
4867 4868 4869 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4867 def floodlight_activity_configs @floodlight_activity_configs end |
#post_view_count_percentage_millis ⇒ Fixnum
The percentage of post-view conversions to count, in millis (1/1000 of a
percent). Must be between 0 and 100000 inclusive. For example, to track 50% of
the post-click conversions, set a value of 50000.
Corresponds to the JSON property postViewCountPercentageMillis
4874 4875 4876 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4874 def post_view_count_percentage_millis @post_view_count_percentage_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4881 4882 4883 4884 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 4881 def update!(**args) @floodlight_activity_configs = args[:floodlight_activity_configs] if args.key?(:floodlight_activity_configs) @post_view_count_percentage_millis = args[:post_view_count_percentage_millis] if args.key?(:post_view_count_percentage_millis) end |