Class: Google::Apis::DisplayvideoV3::CustomBiddingAlgorithm
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::CustomBiddingAlgorithm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single custom bidding algorithm.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Immutable.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_type ⇒ String
Required.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Controls whether or not the custom bidding algorithm can be used as a bidding strategy.
-
#model_details ⇒ Array<Google::Apis::DisplayvideoV3::CustomBiddingModelDetails>
Output only.
-
#name ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
Immutable.
-
#shared_advertiser_ids ⇒ Array<Fixnum>
The IDs of the advertisers who have access to this algorithm.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithm
constructor
A new instance of CustomBiddingAlgorithm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithm
Returns a new instance of CustomBiddingAlgorithm.
5544 5545 5546 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Immutable. The unique ID of the advertiser that owns the custom bidding
algorithm.
Corresponds to the JSON property advertiserId
5486 5487 5488 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5486 def advertiser_id @advertiser_id end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm. Assigned by the
system.
Corresponds to the JSON property customBiddingAlgorithmId
5492 5493 5494 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5492 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_type ⇒ String
Required. Immutable. The type of custom bidding algorithm.
Corresponds to the JSON property customBiddingAlgorithmType
5497 5498 5499 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5497 def custom_bidding_algorithm_type @custom_bidding_algorithm_type end |
#display_name ⇒ String
Required. The display name of the custom bidding algorithm. Must be UTF-8
encoded with a maximum size of 240 bytes.
Corresponds to the JSON property displayName
5503 5504 5505 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5503 def display_name @display_name end |
#entity_status ⇒ String
Controls whether or not the custom bidding algorithm can be used as a bidding
strategy. Accepted values are: * ENTITY_STATUS_ACTIVE *
ENTITY_STATUS_ARCHIVED
Corresponds to the JSON property entityStatus
5510 5511 5512 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5510 def entity_status @entity_status end |
#model_details ⇒ Array<Google::Apis::DisplayvideoV3::CustomBiddingModelDetails>
5521 5522 5523 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5521 def model_details @model_details end |
#name ⇒ String
Output only. The resource name of the custom bidding algorithm.
Corresponds to the JSON property name
5526 5527 5528 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5526 def name @name end |
#partner_id ⇒ Fixnum
Immutable. The unique ID of the partner that owns the custom bidding algorithm.
Corresponds to the JSON property partnerId
5531 5532 5533 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5531 def partner_id @partner_id end |
#shared_advertiser_ids ⇒ Array<Fixnum>
5542 5543 5544 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5542 def shared_advertiser_ids @shared_advertiser_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5549 5550 5551 5552 5553 5554 5555 5556 5557 5558 5559 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5549 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_type = args[:custom_bidding_algorithm_type] if args.key?(:custom_bidding_algorithm_type) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @model_details = args[:model_details] if args.key?(:model_details) @name = args[:name] if args.key?(:name) @partner_id = args[:partner_id] if args.key?(:partner_id) @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids) end |