Class: Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single custom bidding algorithm rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingAlgorithmRules

Returns a new instance of CustomBiddingAlgorithmRules.



5802
5803
5804
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the rules resource is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


5762
5763
5764
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5762

def active
  @active
end

#create_timeString

Output only. The time when the rules resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5768
5769
5770
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5768

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm that the rules resource belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


5774
5775
5776
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5774

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_algorithm_rules_idFixnum

Output only. The unique ID of the rules resource. Corresponds to the JSON property customBiddingAlgorithmRulesId

Returns:

  • (Fixnum)


5779
5780
5781
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5779

def custom_bidding_algorithm_rules_id
  @custom_bidding_algorithm_rules_id
end

#errorGoogle::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesError

An error message for a CustomBiddingAlgorithmRules resource. Corresponds to the JSON property error



5784
5785
5786
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5784

def error
  @error
end

#nameString

Output only. The resource name of the rules resource. Corresponds to the JSON property name

Returns:

  • (String)


5789
5790
5791
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5789

def name
  @name
end

#rulesGoogle::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesRef

The reference to the uploaded AlgorithmRules file. Retrieve the location to upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules. Corresponds to the JSON property rules



5795
5796
5797
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5795

def rules
  @rules
end

#stateString

Output only. The state of the rules resource. Corresponds to the JSON property state

Returns:

  • (String)


5800
5801
5802
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5800

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5807
5808
5809
5810
5811
5812
5813
5814
5815
5816
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5807

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @state = args[:state] if args.key?(:state)
end