Class: Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single custom bidding algorithm rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingAlgorithmRules

Returns a new instance of CustomBiddingAlgorithmRules.



5610
5611
5612
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the rules resource is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


5570
5571
5572
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5570

def active
  @active
end

#create_timeString

Output only. The time when the rules resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5576
5577
5578
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5576

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm that the rules resource belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


5582
5583
5584
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5582

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_algorithm_rules_idFixnum

Output only. The unique ID of the rules resource. Corresponds to the JSON property customBiddingAlgorithmRulesId

Returns:

  • (Fixnum)


5587
5588
5589
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5587

def custom_bidding_algorithm_rules_id
  @custom_bidding_algorithm_rules_id
end

#errorGoogle::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesError

An error message for a CustomBiddingAlgorithmRules resource. Corresponds to the JSON property error



5592
5593
5594
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5592

def error
  @error
end

#nameString

Output only. The resource name of the rules resource. Corresponds to the JSON property name

Returns:

  • (String)


5597
5598
5599
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5597

def name
  @name
end

#rulesGoogle::Apis::DisplayvideoV3::CustomBiddingAlgorithmRulesRef

The reference to the uploaded AlgorithmRules file. Retrieve the location to upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules. Corresponds to the JSON property rules



5603
5604
5605
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5603

def rules
  @rules
end

#stateString

Output only. The state of the rules resource. Corresponds to the JSON property state

Returns:

  • (String)


5608
5609
5610
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5608

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5615

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @state = args[:state] if args.key?(:state)
end