Class: Google::Apis::DisplayvideoV3::CustomBiddingScript
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::CustomBiddingScript
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single custom bidding script.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_script_id ⇒ Fixnum
Output only.
-
#errors ⇒ Array<Google::Apis::DisplayvideoV3::ScriptError>
Output only.
-
#name ⇒ String
Output only.
-
#script ⇒ Google::Apis::DisplayvideoV3::CustomBiddingScriptRef
The reference to the uploaded custom bidding script file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingScript
constructor
A new instance of CustomBiddingScript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingScript
Returns a new instance of CustomBiddingScript.
5850 5851 5852 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the script is currently being used for scoring by the
parent algorithm.
Corresponds to the JSON property active
5810 5811 5812 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5810 def active @active end |
#create_time ⇒ String
Output only. The time when the script was created.
Corresponds to the JSON property createTime
5816 5817 5818 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5816 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm the script belongs
to.
Corresponds to the JSON property customBiddingAlgorithmId
5822 5823 5824 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5822 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_script_id ⇒ Fixnum
Output only. The unique ID of the custom bidding script.
Corresponds to the JSON property customBiddingScriptId
5827 5828 5829 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5827 def custom_bidding_script_id @custom_bidding_script_id end |
#errors ⇒ Array<Google::Apis::DisplayvideoV3::ScriptError>
Output only. Error details of a rejected custom bidding script. This field
will only be populated when state is REJECTED.
Corresponds to the JSON property errors
5833 5834 5835 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5833 def errors @errors end |
#name ⇒ String
Output only. The resource name of the custom bidding script.
Corresponds to the JSON property name
5838 5839 5840 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5838 def name @name end |
#script ⇒ Google::Apis::DisplayvideoV3::CustomBiddingScriptRef
The reference to the uploaded custom bidding script file.
Corresponds to the JSON property script
5843 5844 5845 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5843 def script @script end |
#state ⇒ String
Output only. The state of the custom bidding script.
Corresponds to the JSON property state
5848 5849 5850 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5848 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5855 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @script = args[:script] if args.key?(:script) @state = args[:state] if args.key?(:state) end |