Class: Google::Apis::DisplayvideoV3::CustomBiddingScript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingScript

Returns a new instance of CustomBiddingScript.



5747
5748
5749
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the script is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


5707
5708
5709
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5707

def active
  @active
end

#create_timeString

Output only. The time when the script was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5713
5714
5715
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5713

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm the script belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


5719
5720
5721
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5719

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_script_idFixnum

Output only. The unique ID of the custom bidding script. Corresponds to the JSON property customBiddingScriptId

Returns:

  • (Fixnum)


5724
5725
5726
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5724

def custom_bidding_script_id
  @custom_bidding_script_id
end

#errorsArray<Google::Apis::DisplayvideoV3::ScriptError>

Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED. Corresponds to the JSON property errors



5730
5731
5732
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5730

def errors
  @errors
end

#nameString

Output only. The resource name of the custom bidding script. Corresponds to the JSON property name

Returns:

  • (String)


5735
5736
5737
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5735

def name
  @name
end

#scriptGoogle::Apis::DisplayvideoV3::CustomBiddingScriptRef

The reference to the uploaded custom bidding script file. Corresponds to the JSON property script



5740
5741
5742
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5740

def script
  @script
end

#stateString

Output only. The state of the custom bidding script. Corresponds to the JSON property state

Returns:

  • (String)


5745
5746
5747
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5745

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5752
5753
5754
5755
5756
5757
5758
5759
5760
5761
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 5752

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @script = args[:script] if args.key?(:script)
  @state = args[:state] if args.key?(:state)
end