Class: Google::Apis::DisplayvideoV3::DemandGenBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the bid strategy for Demand Gen resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenBiddingStrategy

Returns a new instance of DemandGenBiddingStrategy.



6322
6323
6324
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_bidding_valueFixnum

Output only. The value effectively used by the bidding strategy. This field will be the same as value if set. If value is not set and the strategy is assigned to an ad group, this field will be inherited from the line item's bidding strategy. If type is not DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA or DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS, this field will be 0. Corresponds to the JSON property effectiveBiddingValue

Returns:

  • (Fixnum)


6297
6298
6299
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6297

def effective_bidding_value
  @effective_bidding_value
end

#effective_bidding_value_sourceString

Output only. Source of the effective bidding value. Corresponds to the JSON property effectiveBiddingValueSource

Returns:

  • (String)


6302
6303
6304
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6302

def effective_bidding_value_source
  @effective_bidding_value_source
end

#typeString

Optional. The type of the bidding strategy. This can only be set when assigned to a line item. Ad groups will inherit this value from their line item. Corresponds to the JSON property type

Returns:

  • (String)


6308
6309
6310
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6308

def type
  @type
end

#valueFixnum

Optional. The value used by the bidding strategy. This can be set when assigned to line items or ad groups. This field is only applicable for the following strategy types: * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPC * DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS Value of this field is in micros of the advertiser's currency or ROAS value. For example, 1000000 represents 1. 0 standard units of the currency or 100% ROAS value. If not using an applicable strategy, the value of this field will be 0. Corresponds to the JSON property value

Returns:

  • (Fixnum)


6320
6321
6322
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6320

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6327
6328
6329
6330
6331
6332
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6327

def update!(**args)
  @effective_bidding_value = args[:effective_bidding_value] if args.key?(:effective_bidding_value)
  @effective_bidding_value_source = args[:effective_bidding_value_source] if args.key?(:effective_bidding_value_source)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end