Class: Google::Apis::DisplayvideoV3::DemandGenCarouselAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a Demand Gen carousel ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenCarouselAd

Returns a new instance of DemandGenCarouselAd.



6391
6392
6393
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6342
6343
6344
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6342

def business_name
  @business_name
end

#cardsArray<Google::Apis::DisplayvideoV3::CarouselCard>

Required. The list of cards shown on the ad. Corresponds to the JSON property cards



6347
6348
6349
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6347

def cards
  @cards
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6353
6354
6355
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6353

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6358
6359
6360
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6358

def description
  @description
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6364
6365
6366
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6364

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6369
6370
6371
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6369

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6374
6375
6376
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6374

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6379
6380
6381
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6379

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6384
6385
6386
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6384

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6389
6390
6391
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6389

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6396

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @cards = args[:cards] if args.key?(:cards)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end