Class: Google::Apis::DisplayvideoV3::DemandGenImageAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a Demand Gen image ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenImageAd

Returns a new instance of DemandGenImageAd.



6397
6398
6399
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Optional. The business name shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6325
6326
6327
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6325

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. Corresponds to the JSON property callToAction

Returns:

  • (String)


6330
6331
6332
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6330

def call_to_action
  @call_to_action
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6336
6337
6338
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6336

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

Required. The list of descriptions shown on the ad. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


6341
6342
6343
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6341

def descriptions
  @descriptions
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the ad on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


6347
6348
6349
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6347

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6353
6354
6355
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6353

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6358
6359
6360
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6358

def final_url_suffix
  @final_url_suffix
end

#headlinesArray<String>

Required. The list of headlines shown on the ad. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


6363
6364
6365
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6363

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of logo images shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property logoImages



6370
6371
6372
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6370

def logo_images
  @logo_images
end

#marketing_imagesArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of marketing images shown on the ad. Corresponds to the JSON property marketingImages



6375
6376
6377
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6375

def marketing_images
  @marketing_images
end

#portrait_marketing_imagesArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of portrait marketing images shown on the ad. Corresponds to the JSON property portraitMarketingImages



6380
6381
6382
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6380

def portrait_marketing_images
  @portrait_marketing_images
end

#square_marketing_imagesArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of square marketing images shown on the ad. Corresponds to the JSON property squareMarketingImages



6385
6386
6387
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6385

def square_marketing_images
  @square_marketing_images
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6390
6391
6392
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6390

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6395
6396
6397
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6395

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6402
6403
6404
6405
6406
6407
6408
6409
6410
6411
6412
6413
6414
6415
6416
6417
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6402

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @marketing_images = args[:marketing_images] if args.key?(:marketing_images)
  @portrait_marketing_images = args[:portrait_marketing_images] if args.key?(:portrait_marketing_images)
  @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end