Class: Google::Apis::DisplayvideoV3::DemandGenImageAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::DemandGenImageAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for a Demand Gen image ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Required.
-
#call_to_action ⇒ String
Required.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#descriptions ⇒ Array<String>
Required.
-
#final_mobile_url ⇒ String
Optional.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headlines ⇒ Array<String>
Required.
-
#logo_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of logo images shown on the ad.
-
#marketing_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of marketing images shown on the ad.
-
#portrait_marketing_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of portrait marketing images shown on the ad.
-
#square_marketing_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of square marketing images shown on the ad.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenImageAd
constructor
A new instance of DemandGenImageAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenImageAd
Returns a new instance of DemandGenImageAd.
6487 6488 6489 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Required. The business name shown on the ad.
Corresponds to the JSON property businessName
6417 6418 6419 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6417 def business_name @business_name end |
#call_to_action ⇒ String
Required. The call-to-action button shown on the ad.
Corresponds to the JSON property callToAction
6422 6423 6424 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6422 def call_to_action @call_to_action end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6428 6429 6430 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6428 def custom_parameters @custom_parameters end |
#descriptions ⇒ Array<String>
Required. The list of descriptions shown on the ad.
Corresponds to the JSON property descriptions
6433 6434 6435 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6433 def descriptions @descriptions end |
#final_mobile_url ⇒ String
Optional. The URL address of the webpage that people reach after they click
the ad on a mobile device.
Corresponds to the JSON property finalMobileUrl
6439 6440 6441 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6439 def final_mobile_url @final_mobile_url end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6445 6446 6447 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6445 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6450 6451 6452 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6450 def final_url_suffix @final_url_suffix end |
#headlines ⇒ Array<String>
Required. The list of headlines shown on the ad.
Corresponds to the JSON property headlines
6455 6456 6457 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6455 def headlines @headlines end |
#logo_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of logo images shown on the ad.
Corresponds to the JSON property logoImages
6460 6461 6462 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6460 def logo_images @logo_images end |
#marketing_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of marketing images shown on the ad.
Corresponds to the JSON property marketingImages
6465 6466 6467 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6465 def marketing_images @marketing_images end |
#portrait_marketing_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of portrait marketing images shown on the ad.
Corresponds to the JSON property portraitMarketingImages
6470 6471 6472 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6470 def portrait_marketing_images @portrait_marketing_images end |
#square_marketing_images ⇒ Array<Google::Apis::DisplayvideoV3::ImageAsset>
The list of square marketing images shown on the ad.
Corresponds to the JSON property squareMarketingImages
6475 6476 6477 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6475 def square_marketing_images @square_marketing_images end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6480 6481 6482 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6480 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6485 6486 6487 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6485 def user_specified_tracking_url @user_specified_tracking_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 6505 6506 6507 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6492 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @descriptions = args[:descriptions] if args.key?(:descriptions) @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headlines = args[:headlines] if args.key?(:headlines) @logo_images = args[:logo_images] if args.key?(:logo_images) @marketing_images = args[:marketing_images] if args.key?(:marketing_images) @portrait_marketing_images = args[:portrait_marketing_images] if args.key?(:portrait_marketing_images) @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) end |