Class: Google::Apis::DisplayvideoV3::DemandGenVideoAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a Demand Gen video ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenVideoAd

Returns a new instance of DemandGenVideoAd.



6726
6727
6728
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6642
6643
6644
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6642

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. The supported values are:

  • AUTOMATED * LEARN_MORE * GET_QUOTE * APPLY_NOW * SIGN_UP * CONTACT_US * SUBSCRIBE * DOWNLOAD * BOOK_NOW * SHOP_NOW * BUY_NOW * DONATE_NOW * ORDER_NOW * PLAY_NOW * SEE_MORE * START_NOW * VISIT_SITE * WATCH_NOW Corresponds to the JSON property callToAction

Returns:

  • (String)


6651
6652
6653
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6651

def call_to_action
  @call_to_action
end

#companion_bannerGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property companionBanner



6656
6657
6658
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6656

def companion_banner
  @companion_banner
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6662
6663
6664
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6662

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

Required. The list of descriptions shown on the ad. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


6667
6668
6669
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6667

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

Optional. The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


6672
6673
6674
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6672

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

Optional. The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


6677
6678
6679
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6677

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the ad on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


6683
6684
6685
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6683

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6689
6690
6691
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6689

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6694
6695
6696
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6694

def final_url_suffix
  @final_url_suffix
end

#headlinesArray<String>

Required. The list of headlines shown on the ad. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


6699
6700
6701
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6699

def headlines
  @headlines
end

#logoGoogle::Apis::DisplayvideoV3::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6704
6705
6706
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6704

def 
  @logo
end

#long_headlinesArray<String>

Required. The list of long headlines shown on the ad. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


6709
6710
6711
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6709

def long_headlines
  @long_headlines
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6714
6715
6716
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6714

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6719
6720
6721
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6719

def user_specified_tracking_url
  @user_specified_tracking_url
end

#videosArray<Google::Apis::DisplayvideoV3::YoutubeVideoDetails>

Required. The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



6724
6725
6726
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6724

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6731

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @companion_banner = args[:companion_banner] if args.key?(:companion_banner)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo = args[:logo] if args.key?(:logo)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end