Class: Google::Apis::DisplayvideoV3::EditCustomerMatchMembersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Request message for FirstAndThirdPartyAudienceService.EditCustomerMatchMembers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EditCustomerMatchMembersRequest

Returns a new instance of EditCustomerMatchMembersRequest.



6542
6543
6544
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#added_contact_info_listGoogle::Apis::DisplayvideoV3::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property addedContactInfoList



6516
6517
6518
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6516

def added_contact_info_list
  @added_contact_info_list
end

#added_mobile_device_id_listGoogle::Apis::DisplayvideoV3::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property addedMobileDeviceIdList



6522
6523
6524
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6522

def added_mobile_device_id_list
  @added_mobile_device_id_list
end

#advertiser_idFixnum

Required. The ID of the owner advertiser of the updated Customer Match FirstAndThirdPartyAudience. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


6528
6529
6530
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6528

def advertiser_id
  @advertiser_id
end

#removed_contact_info_listGoogle::Apis::DisplayvideoV3::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property removedContactInfoList



6534
6535
6536
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6534

def removed_contact_info_list
  @removed_contact_info_list
end

#removed_mobile_device_id_listGoogle::Apis::DisplayvideoV3::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property removedMobileDeviceIdList



6540
6541
6542
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6540

def removed_mobile_device_id_list
  @removed_mobile_device_id_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6547
6548
6549
6550
6551
6552
6553
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6547

def update!(**args)
  @added_contact_info_list = args[:added_contact_info_list] if args.key?(:added_contact_info_list)
  @added_mobile_device_id_list = args[:added_mobile_device_id_list] if args.key?(:added_mobile_device_id_list)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @removed_contact_info_list = args[:removed_contact_info_list] if args.key?(:removed_contact_info_list)
  @removed_mobile_device_id_list = args[:removed_mobile_device_id_list] if args.key?(:removed_mobile_device_id_list)
end