Class: Google::Apis::DisplayvideoV3::ExchangeConfigEnabledExchange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

An enabled exchange in the partner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangeConfigEnabledExchange

Returns a new instance of ExchangeConfigEnabledExchange.



6828
6829
6830
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exchangeString

The enabled exchange. Corresponds to the JSON property exchange

Returns:

  • (String)


6809
6810
6811
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6809

def exchange
  @exchange
end

Output only. Agency ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerAgencyId

Returns:

  • (String)


6815
6816
6817
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6815

def google_ad_manager_agency_id
  @google_ad_manager_agency_id
end

Output only. Network ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerBuyerNetworkId

Returns:

  • (String)


6821
6822
6823
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6821

def google_ad_manager_buyer_network_id
  @google_ad_manager_buyer_network_id
end

#seat_idString

Output only. Seat ID of the enabled exchange. Corresponds to the JSON property seatId

Returns:

  • (String)


6826
6827
6828
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6826

def seat_id
  @seat_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6833
6834
6835
6836
6837
6838
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6833

def update!(**args)
  @exchange = args[:exchange] if args.key?(:exchange)
  @google_ad_manager_agency_id = args[:google_ad_manager_agency_id] if args.key?(:google_ad_manager_agency_id)
  @google_ad_manager_buyer_network_id = args[:google_ad_manager_buyer_network_id] if args.key?(:google_ad_manager_buyer_network_id)
  @seat_id = args[:seat_id] if args.key?(:seat_id)
end