Class: Google::Apis::DisplayvideoV3::ExitEvent
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ExitEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Exit event of the creative.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#reporting_name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExitEvent
constructor
A new instance of ExitEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExitEvent
Returns a new instance of ExitEvent.
7543 7544 7545 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. The name of the click tag of the exit event. The name must be unique
within one creative. Leave it empty or unset for creatives containing image
assets only.
Corresponds to the JSON property name
7524 7525 7526 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7524 def name @name end |
#reporting_name ⇒ String
Optional. The name used to identify this event in reports. Leave it empty or
unset for creatives containing image assets only.
Corresponds to the JSON property reportingName
7530 7531 7532 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7530 def reporting_name @reporting_name end |
#type ⇒ String
Required. The type of the exit event.
Corresponds to the JSON property type
7535 7536 7537 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7535 def type @type end |
#url ⇒ String
Required. The click through URL of the exit event. This is required when type
is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP
Corresponds to the JSON property url
7541 7542 7543 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7541 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7548 7549 7550 7551 7552 7553 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7548 def update!(**args) @name = args[:name] if args.key?(:name) @reporting_name = args[:reporting_name] if args.key?(:reporting_name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |