Class: Google::Apis::DisplayvideoV3::ExitEvent
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ExitEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Exit event of the creative.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#reporting_name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExitEvent
constructor
A new instance of ExitEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExitEvent
Returns a new instance of ExitEvent.
6915 6916 6917 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. The name of the click tag of the exit event. The name must be unique
within one creative. Leave it empty or unset for creatives containing image
assets only.
Corresponds to the JSON property name
6896 6897 6898 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6896 def name @name end |
#reporting_name ⇒ String
Optional. The name used to identify this event in reports. Leave it empty or
unset for creatives containing image assets only.
Corresponds to the JSON property reportingName
6902 6903 6904 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6902 def reporting_name @reporting_name end |
#type ⇒ String
Required. The type of the exit event.
Corresponds to the JSON property type
6907 6908 6909 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6907 def type @type end |
#url ⇒ String
Required. The click through URL of the exit event. This is required when type
is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP
Corresponds to the JSON property url
6913 6914 6915 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6913 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6920 6921 6922 6923 6924 6925 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6920 def update!(**args) @name = args[:name] if args.key?(:name) @reporting_name = args[:reporting_name] if args.key?(:reporting_name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |