Class: Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Describes a first or third party audience list used for targeting. First party audiences are created via usage of client data. Third party audiences are provided by Third Party data providers and can only be licensed to customers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstAndThirdPartyAudience

Returns a new instance of FirstAndThirdPartyAudience.



7057
7058
7059
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_display_audience_sizeFixnum

Output only. The estimated audience size for the Display network in the past month. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property activeDisplayAudienceSize

Returns:

  • (Fixnum)


6940
6941
6942
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6940

def active_display_audience_size
  @active_display_audience_size
end

#app_idString

The app_id matches with the type of the mobile_device_ids being uploaded. Only applicable to audience_type CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property appId

Returns:

  • (String)


6946
6947
6948
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6946

def app_id
  @app_id
end

#audience_sourceString

Output only. The source of the audience. Corresponds to the JSON property audienceSource

Returns:

  • (String)


6951
6952
6953
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6951

def audience_source
  @audience_source
end

#audience_typeString

The type of the audience. Corresponds to the JSON property audienceType

Returns:

  • (String)


6956
6957
6958
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6956

def audience_type
  @audience_type
end

#contact_info_listGoogle::Apis::DisplayvideoV3::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property contactInfoList



6962
6963
6964
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6962

def contact_info_list
  @contact_info_list
end

#descriptionString

The user-provided description of the audience. Only applicable to first party audiences. Corresponds to the JSON property description

Returns:

  • (String)


6968
6969
6970
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6968

def description
  @description
end

#display_audience_sizeFixnum

Output only. The estimated audience size for the Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property displayAudienceSize

Returns:

  • (Fixnum)


6976
6977
6978
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6976

def display_audience_size
  @display_audience_size
end

#display_desktop_audience_sizeFixnum

Output only. The estimated desktop audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayDesktopAudienceSize

Returns:

  • (Fixnum)


6985
6986
6987
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6985

def display_desktop_audience_size
  @display_desktop_audience_size
end

#display_mobile_app_audience_sizeFixnum

Output only. The estimated mobile app audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileAppAudienceSize

Returns:

  • (Fixnum)


6994
6995
6996
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 6994

def display_mobile_app_audience_size
  @display_mobile_app_audience_size
end

#display_mobile_web_audience_sizeFixnum

Output only. The estimated mobile web audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileWebAudienceSize

Returns:

  • (Fixnum)


7003
7004
7005
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7003

def display_mobile_web_audience_size
  @display_mobile_web_audience_size
end

#display_nameString

The display name of the first and third party audience. Corresponds to the JSON property displayName

Returns:

  • (String)


7008
7009
7010
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7008

def display_name
  @display_name
end

#first_and_third_party_audience_idFixnum

Output only. The unique ID of the first and third party audience. Assigned by the system. Corresponds to the JSON property firstAndThirdPartyAudienceId

Returns:

  • (Fixnum)


7014
7015
7016
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7014

def first_and_third_party_audience_id
  @first_and_third_party_audience_id
end

#first_and_third_party_audience_typeString

Whether the audience is a first or third party audience. Corresponds to the JSON property firstAndThirdPartyAudienceType

Returns:

  • (String)


7019
7020
7021
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7019

def first_and_third_party_audience_type
  @first_and_third_party_audience_type
end

#gmail_audience_sizeFixnum

Output only. The estimated audience size for Gmail network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property gmailAudienceSize

Returns:

  • (Fixnum)


7027
7028
7029
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7027

def gmail_audience_size
  @gmail_audience_size
end

#membership_duration_daysFixnum

The duration in days that an entry remains in the audience after the qualifying event. The set value must be greater than 0 and less than or equal to 540. Only applicable to first party audiences. This field is required if one of the following audience_type is used: * CUSTOMER_MATCH_CONTACT_INFO * CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property membershipDurationDays

Returns:

  • (Fixnum)


7036
7037
7038
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7036

def membership_duration_days
  @membership_duration_days
end

#mobile_device_id_listGoogle::Apis::DisplayvideoV3::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property mobileDeviceIdList



7042
7043
7044
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7042

def mobile_device_id_list
  @mobile_device_id_list
end

#nameString

Output only. The resource name of the first and third party audience. Corresponds to the JSON property name

Returns:

  • (String)


7047
7048
7049
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7047

def name
  @name
end

#youtube_audience_sizeFixnum

Output only. The estimated audience size for YouTube network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property youtubeAudienceSize

Returns:

  • (Fixnum)


7055
7056
7057
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7055

def youtube_audience_size
  @youtube_audience_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7062

def update!(**args)
  @active_display_audience_size = args[:active_display_audience_size] if args.key?(:active_display_audience_size)
  @app_id = args[:app_id] if args.key?(:app_id)
  @audience_source = args[:audience_source] if args.key?(:audience_source)
  @audience_type = args[:audience_type] if args.key?(:audience_type)
  @contact_info_list = args[:contact_info_list] if args.key?(:contact_info_list)
  @description = args[:description] if args.key?(:description)
  @display_audience_size = args[:display_audience_size] if args.key?(:display_audience_size)
  @display_desktop_audience_size = args[:display_desktop_audience_size] if args.key?(:display_desktop_audience_size)
  @display_mobile_app_audience_size = args[:display_mobile_app_audience_size] if args.key?(:display_mobile_app_audience_size)
  @display_mobile_web_audience_size = args[:display_mobile_web_audience_size] if args.key?(:display_mobile_web_audience_size)
  @display_name = args[:display_name] if args.key?(:display_name)
  @first_and_third_party_audience_id = args[:first_and_third_party_audience_id] if args.key?(:first_and_third_party_audience_id)
  @first_and_third_party_audience_type = args[:first_and_third_party_audience_type] if args.key?(:first_and_third_party_audience_type)
  @gmail_audience_size = args[:gmail_audience_size] if args.key?(:gmail_audience_size)
  @membership_duration_days = args[:membership_duration_days] if args.key?(:membership_duration_days)
  @mobile_device_id_list = args[:mobile_device_id_list] if args.key?(:mobile_device_id_list)
  @name = args[:name] if args.key?(:name)
  @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size)
end