Class: Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details of first and third party audience group. All first and third party audience targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstAndThirdPartyAudienceGroup

Returns a new instance of FirstAndThirdPartyAudienceGroup.



7414
7415
7416
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceTargetingSetting>

Required. All first and third party audience targeting settings in first and third party audience group. Repeated settings with the same id are not allowed. Corresponds to the JSON property settings



7412
7413
7414
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7412

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7419
7420
7421
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7419

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end