Class: Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details of first and third party audience group. All first and third party audience targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstAndThirdPartyAudienceGroup

Returns a new instance of FirstAndThirdPartyAudienceGroup.



7723
7724
7725
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudienceTargetingSetting>

Required. All first and third party audience targeting settings in first and third party audience group. Repeated settings with the same id are not allowed. Corresponds to the JSON property settings



7721
7722
7723
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7721

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7728
7729
7730
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7728

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end