Class: Google::Apis::DisplayvideoV3::FloodlightActivity
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::FloodlightActivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single Floodlight activity.
Instance Attribute Summary collapse
-
#advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#display_name ⇒ String
Required.
-
#floodlight_activity_id ⇒ Fixnum
Output only.
-
#floodlight_group_id ⇒ Fixnum
Required.
-
#name ⇒ String
Output only.
-
#remarketing_configs ⇒ Array<Google::Apis::DisplayvideoV3::RemarketingConfig>
Output only.
-
#serving_status ⇒ String
Optional.
-
#ssl_required ⇒ Boolean
(also: #ssl_required?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightActivity
constructor
A new instance of FloodlightActivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightActivity
Returns a new instance of FloodlightActivity.
7526 7527 7528 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_ids ⇒ Array<Fixnum>
Output only. IDs of the advertisers that have access to the parent Floodlight
group. Only advertisers under the provided partner ID will be listed in this
field.
Corresponds to the JSON property advertiserIds
7485 7486 7487 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7485 def advertiser_ids @advertiser_ids end |
#display_name ⇒ String
Required. The display name of the Floodlight activity.
Corresponds to the JSON property displayName
7490 7491 7492 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7490 def display_name @display_name end |
#floodlight_activity_id ⇒ Fixnum
Output only. The unique ID of the Floodlight activity. Assigned by the system.
Corresponds to the JSON property floodlightActivityId
7495 7496 7497 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7495 def floodlight_activity_id @floodlight_activity_id end |
#floodlight_group_id ⇒ Fixnum
Required. Immutable. The ID of the parent Floodlight group.
Corresponds to the JSON property floodlightGroupId
7500 7501 7502 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7500 def floodlight_group_id @floodlight_group_id end |
#name ⇒ String
Output only. The resource name of the Floodlight activity.
Corresponds to the JSON property name
7505 7506 7507 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7505 def name @name end |
#remarketing_configs ⇒ Array<Google::Apis::DisplayvideoV3::RemarketingConfig>
Output only. A list of configuration objects designating whether remarketing
for this Floodlight Activity is enabled and available for a specifc advertiser.
If enabled, this Floodlight Activity generates a remarketing user list that
is able to be used in targeting under the advertiser.
Corresponds to the JSON property remarketingConfigs
7513 7514 7515 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7513 def remarketing_configs @remarketing_configs end |
#serving_status ⇒ String
Optional. Whether the Floodlight activity is served.
Corresponds to the JSON property servingStatus
7518 7519 7520 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7518 def serving_status @serving_status end |
#ssl_required ⇒ Boolean Also known as: ssl_required?
Output only. Whether tags are required to be compliant.
Corresponds to the JSON property sslRequired
7523 7524 7525 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7523 def ssl_required @ssl_required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7531 def update!(**args) @advertiser_ids = args[:advertiser_ids] if args.key?(:advertiser_ids) @display_name = args[:display_name] if args.key?(:display_name) @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id) @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id) @name = args[:name] if args.key?(:name) @remarketing_configs = args[:remarketing_configs] if args.key?(:remarketing_configs) @serving_status = args[:serving_status] if args.key?(:serving_status) @ssl_required = args[:ssl_required] if args.key?(:ssl_required) end |