Class: Google::Apis::DisplayvideoV3::FloodlightActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single Floodlight activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivity

Returns a new instance of FloodlightActivity.



7207
7208
7209
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idsArray<Fixnum>

Output only. IDs of the advertisers that have access to the parent Floodlight group. Only advertisers under the provided partner ID will be listed in this field. Corresponds to the JSON property advertiserIds

Returns:

  • (Array<Fixnum>)


7166
7167
7168
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7166

def advertiser_ids
  @advertiser_ids
end

#display_nameString

Required. The display name of the Floodlight activity. Corresponds to the JSON property displayName

Returns:

  • (String)


7171
7172
7173
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7171

def display_name
  @display_name
end

#floodlight_activity_idFixnum

Output only. The unique ID of the Floodlight activity. Assigned by the system. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


7176
7177
7178
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7176

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_group_idFixnum

Required. Immutable. The ID of the parent Floodlight group. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


7181
7182
7183
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7181

def floodlight_group_id
  @floodlight_group_id
end

#nameString

Output only. The resource name of the Floodlight activity. Corresponds to the JSON property name

Returns:

  • (String)


7186
7187
7188
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7186

def name
  @name
end

#remarketing_configsArray<Google::Apis::DisplayvideoV3::RemarketingConfig>

Output only. A list of configuration objects designating whether remarketing for this Floodlight Activity is enabled and available for a specifc advertiser. If enabled, this Floodlight Activity generates a remarketing user list that is able to be used in targeting under the advertiser. Corresponds to the JSON property remarketingConfigs



7194
7195
7196
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7194

def remarketing_configs
  @remarketing_configs
end

#serving_statusString

Optional. Whether the Floodlight activity is served. Corresponds to the JSON property servingStatus

Returns:

  • (String)


7199
7200
7201
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7199

def serving_status
  @serving_status
end

#ssl_requiredBoolean Also known as: ssl_required?

Output only. Whether tags are required to be compliant. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


7204
7205
7206
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7204

def ssl_required
  @ssl_required
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7212
7213
7214
7215
7216
7217
7218
7219
7220
7221
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7212

def update!(**args)
  @advertiser_ids = args[:advertiser_ids] if args.key?(:advertiser_ids)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @name = args[:name] if args.key?(:name)
  @remarketing_configs = args[:remarketing_configs] if args.key?(:remarketing_configs)
  @serving_status = args[:serving_status] if args.key?(:serving_status)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
end