Class: Google::Apis::DisplayvideoV3::FloodlightGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single Floodlight group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightGroup

Returns a new instance of FloodlightGroup.



7276
7277
7278
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_view_configGoogle::Apis::DisplayvideoV3::ActiveViewVideoViewabilityMetricConfig

Configuration for custom Active View video viewability metrics. Corresponds to the JSON property activeViewConfig



7231
7232
7233
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7231

def active_view_config
  @active_view_config
end

#custom_variablesHash<String,Object>

User-defined custom variables owned by the Floodlight group. Use custom Floodlight variables to create reporting data that is tailored to your unique business needs. Custom Floodlight variables use the keys U1=, U2=, and so on, and can take any values that you choose to pass to them. You can use them to track virtually any type of data that you collect about your customers, such as the genre of movie that a customer purchases, the country to which the item is shipped, and so on. Custom Floodlight variables may not be used to pass any data that could be used or recognized as personally identifiable information (PII). Example: custom_variables fields "U1": value number_value: 123.4 , "U2": value string_value: "MyVariable2" , "U3": value string_value: "MyVariable3" `Acceptable values for keys are "U1" through "U100", inclusive. String values must be less than 64 characters long, and cannot contain the following characters:"<>. Corresponds to the JSON propertycustomVariables`

Returns:

  • (Hash<String,Object>)


7248
7249
7250
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7248

def custom_variables
  @custom_variables
end

#display_nameString

Required. The display name of the Floodlight group. Corresponds to the JSON property displayName

Returns:

  • (String)


7253
7254
7255
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7253

def display_name
  @display_name
end

#floodlight_group_idFixnum

Output only. The unique ID of the Floodlight group. Assigned by the system. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


7258
7259
7260
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7258

def floodlight_group_id
  @floodlight_group_id
end

#lookback_windowGoogle::Apis::DisplayvideoV3::LookbackWindow

Specifies how many days into the past to look when determining whether to record a conversion. Corresponds to the JSON property lookbackWindow



7264
7265
7266
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7264

def lookback_window
  @lookback_window
end

#nameString

Output only. The resource name of the Floodlight group. Corresponds to the JSON property name

Returns:

  • (String)


7269
7270
7271
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7269

def name
  @name
end

#web_tag_typeString

Required. The web tag type enabled for the Floodlight group. Corresponds to the JSON property webTagType

Returns:

  • (String)


7274
7275
7276
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7274

def web_tag_type
  @web_tag_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7281
7282
7283
7284
7285
7286
7287
7288
7289
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7281

def update!(**args)
  @active_view_config = args[:active_view_config] if args.key?(:active_view_config)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @lookback_window = args[:lookback_window] if args.key?(:lookback_window)
  @name = args[:name] if args.key?(:name)
  @web_tag_type = args[:web_tag_type] if args.key?(:web_tag_type)
end