Class: Google::Apis::DisplayvideoV3::FrequencyCap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the number of times a user may be shown with the same ad during a given time period.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrequencyCap

Returns a new instance of FrequencyCap.



7962
7963
7964
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_impressionsFixnum

The maximum number of times a user may be shown the same ad during this period. Must be greater than 0. Required when unlimited is false and max_views is not set. Corresponds to the JSON property maxImpressions

Returns:

  • (Fixnum)


7930
7931
7932
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7930

def max_impressions
  @max_impressions
end

#max_viewsFixnum

Optional. The maximum number of times a user may click-through or fully view an ad during this period until it is no longer served to them. Must be greater than 0. Only applicable to YouTube and Partners resources. Required when unlimited is false and max_impressions is not set. Corresponds to the JSON property maxViews

Returns:

  • (Fixnum)


7938
7939
7940
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7938

def max_views
  @max_views
end

#time_unitString

The time unit in which the frequency cap will be applied. Required when unlimited is false. Corresponds to the JSON property timeUnit

Returns:

  • (String)


7944
7945
7946
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7944

def time_unit
  @time_unit
end

#time_unit_countFixnum

The number of time_unit the frequency cap will last. Required when unlimited is false. The following restrictions apply based on the value of time_unit: * TIME_UNIT_MONTHS - must be 1 * TIME_UNIT_WEEKS - must be between 1 and 4 * TIME_UNIT_DAYS - must be between 1 and 6 * TIME_UNIT_HOURS - must be between 1 and 23 * TIME_UNIT_MINUTES - must be between 1 and 59 Corresponds to the JSON property timeUnitCount

Returns:

  • (Fixnum)


7953
7954
7955
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7953

def time_unit_count
  @time_unit_count
end

#unlimitedBoolean Also known as: unlimited?

Whether unlimited frequency capping is applied. When this field is set to true, the remaining frequency cap fields are not applicable. Corresponds to the JSON property unlimited

Returns:

  • (Boolean)


7959
7960
7961
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7959

def unlimited
  @unlimited
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7967
7968
7969
7970
7971
7972
7973
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7967

def update!(**args)
  @max_impressions = args[:max_impressions] if args.key?(:max_impressions)
  @max_views = args[:max_views] if args.key?(:max_views)
  @time_unit = args[:time_unit] if args.key?(:time_unit)
  @time_unit_count = args[:time_unit_count] if args.key?(:time_unit_count)
  @unlimited = args[:unlimited] if args.key?(:unlimited)
end