Class: Google::Apis::DisplayvideoV3::GuaranteedOrder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A guaranteed order. Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuaranteedOrder

Returns a new instance of GuaranteedOrder.



7987
7988
7989
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_advertiser_idFixnum

Output only. The ID of default advertiser of the guaranteed order. The default advertiser is either the read_write_advertiser_id or, if that is not set, the first advertiser listed in read_advertiser_ids. Otherwise, there is no default advertiser. Corresponds to the JSON property defaultAdvertiserId

Returns:

  • (Fixnum)


7906
7907
7908
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7906

def default_advertiser_id
  @default_advertiser_id
end

#default_campaign_idFixnum

The ID of the default campaign that is assigned to the guaranteed order. The default campaign must belong to the default advertiser. Corresponds to the JSON property defaultCampaignId

Returns:

  • (Fixnum)


7912
7913
7914
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7912

def default_campaign_id
  @default_campaign_id
end

#display_nameString

Required. The display name of the guaranteed order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


7918
7919
7920
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7918

def display_name
  @display_name
end

#exchangeString

Required. Immutable. The exchange where the guaranteed order originated. Corresponds to the JSON property exchange

Returns:

  • (String)


7923
7924
7925
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7923

def exchange
  @exchange
end

#guaranteed_order_idString

Output only. The unique identifier of the guaranteed order. The guaranteed order IDs have the format exchange`-`legacy_guaranteed_order_id. Corresponds to the JSON property guaranteedOrderId

Returns:

  • (String)


7929
7930
7931
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7929

def guaranteed_order_id
  @guaranteed_order_id
end

#legacy_guaranteed_order_idString

Output only. The legacy ID of the guaranteed order. Assigned by the original exchange. The legacy ID is unique within one exchange, but is not guaranteed to be unique across all guaranteed orders. This ID is used in SDF and UI. Corresponds to the JSON property legacyGuaranteedOrderId

Returns:

  • (String)


7936
7937
7938
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7936

def legacy_guaranteed_order_id
  @legacy_guaranteed_order_id
end

#nameString

Output only. The resource name of the guaranteed order. Corresponds to the JSON property name

Returns:

  • (String)


7941
7942
7943
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7941

def name
  @name
end

#publisher_nameString

Required. The publisher name of the guaranteed order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property publisherName

Returns:

  • (String)


7947
7948
7949
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7947

def publisher_name
  @publisher_name
end

#read_access_inheritedBoolean Also known as: read_access_inherited?

Whether all advertisers of read_write_partner_id have read access to the guaranteed order. Only applicable if read_write_partner_id is set. If True, overrides read_advertiser_ids. Corresponds to the JSON property readAccessInherited

Returns:

  • (Boolean)


7954
7955
7956
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7954

def read_access_inherited
  @read_access_inherited
end

#read_advertiser_idsArray<Fixnum>

The IDs of advertisers with read access to the guaranteed order. This field must not include the advertiser assigned to read_write_advertiser_id if it is set. All advertisers in this field must belong to read_write_partner_id or the same partner as read_write_advertiser_id. Corresponds to the JSON property readAdvertiserIds

Returns:

  • (Array<Fixnum>)


7963
7964
7965
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7963

def read_advertiser_ids
  @read_advertiser_ids
end

#read_write_advertiser_idFixnum

The advertiser with read/write access to the guaranteed order. This is also the default advertiser of the guaranteed order. Corresponds to the JSON property readWriteAdvertiserId

Returns:

  • (Fixnum)


7969
7970
7971
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7969

def read_write_advertiser_id
  @read_write_advertiser_id
end

#read_write_partner_idFixnum

The partner with read/write access to the guaranteed order. Corresponds to the JSON property readWritePartnerId

Returns:

  • (Fixnum)


7974
7975
7976
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7974

def read_write_partner_id
  @read_write_partner_id
end

#statusGoogle::Apis::DisplayvideoV3::GuaranteedOrderStatus

The status settings of the guaranteed order. Corresponds to the JSON property status



7979
7980
7981
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7979

def status
  @status
end

#update_timeString

Output only. The timestamp when the guaranteed order was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


7985
7986
7987
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7985

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7992

def update!(**args)
  @default_advertiser_id = args[:default_advertiser_id] if args.key?(:default_advertiser_id)
  @default_campaign_id = args[:default_campaign_id] if args.key?(:default_campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exchange = args[:exchange] if args.key?(:exchange)
  @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id)
  @legacy_guaranteed_order_id = args[:legacy_guaranteed_order_id] if args.key?(:legacy_guaranteed_order_id)
  @name = args[:name] if args.key?(:name)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
  @read_access_inherited = args[:read_access_inherited] if args.key?(:read_access_inherited)
  @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids)
  @read_write_advertiser_id = args[:read_write_advertiser_id] if args.key?(:read_write_advertiser_id)
  @read_write_partner_id = args[:read_write_partner_id] if args.key?(:read_write_partner_id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
end