Class: Google::Apis::DisplayvideoV3::InsertionOrder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single insertion order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrder

Returns a new instance of InsertionOrder.



8001
8002
8003
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the insertion order belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7905
7906
7907
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7905

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV3::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



7910
7911
7912
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7910

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV3::InsertionOrderBudget

Settings that control how insertion order budget is allocated. Corresponds to the JSON property budget



7915
7916
7917
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7915

def budget
  @budget
end

#campaign_idFixnum

Required. Immutable. The unique ID of the campaign that the insertion order belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


7921
7922
7923
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7921

def campaign_id
  @campaign_id
end

#display_nameString

Required. The display name of the insertion order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


7927
7928
7929
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7927

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the insertion order can spend its budget and bid on inventory. * For CreateInsertionOrder method, only ENTITY_STATUS_DRAFT is allowed. To activate an insertion order, use UpdateInsertionOrder method and update the status to ENTITY_STATUS_ACTIVE after creation. * An insertion order cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * An insertion order cannot be set to ENTITY_STATUS_ACTIVE if its parent campaign is not active. Corresponds to the JSON property entityStatus

Returns:

  • (String)


7938
7939
7940
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7938

def entity_status
  @entity_status
end

#frequency_capGoogle::Apis::DisplayvideoV3::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



7944
7945
7946
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7944

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Output only. The unique ID of the insertion order. Assigned by the system. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


7949
7950
7951
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7949

def insertion_order_id
  @insertion_order_id
end

#insertion_order_typeString

Optional. The type of insertion order. If this field is unspecified in creation, the value defaults to RTB. Corresponds to the JSON property insertionOrderType

Returns:

  • (String)


7955
7956
7957
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7955

def insertion_order_type
  @insertion_order_type
end

#integration_detailsGoogle::Apis::DisplayvideoV3::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



7960
7961
7962
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7960

def integration_details
  @integration_details
end

#kpiGoogle::Apis::DisplayvideoV3::Kpi

Settings that control the key performance indicator, or KPI, of an insertion order. Corresponds to the JSON property kpi



7966
7967
7968
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7966

def kpi
  @kpi
end

#nameString

Output only. The resource name of the insertion order. Corresponds to the JSON property name

Returns:

  • (String)


7971
7972
7973
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7971

def name
  @name
end

#optimization_objectiveString

Optional. Required. The optimization objective of the insertion order. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


7976
7977
7978
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7976

def optimization_objective
  @optimization_objective
end

#pacingGoogle::Apis::DisplayvideoV3::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



7981
7982
7983
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7981

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV3::PartnerCost>

Optional. The partner costs associated with the insertion order. If absent or empty in CreateInsertionOrder method, the newly created insertion order will inherit partner costs from the partner settings. Corresponds to the JSON property partnerCosts



7988
7989
7990
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7988

def partner_costs
  @partner_costs
end

#reservation_typeString

Output only. The reservation type of the insertion order. Corresponds to the JSON property reservationType

Returns:

  • (String)


7993
7994
7995
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7993

def reservation_type
  @reservation_type
end

#update_timeString

Output only. The timestamp when the insertion order was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


7999
8000
8001
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 7999

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8006
8007
8008
8009
8010
8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8006

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @insertion_order_type = args[:insertion_order_type] if args.key?(:insertion_order_type)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @kpi = args[:kpi] if args.key?(:kpi)
  @name = args[:name] if args.key?(:name)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end