Class: Google::Apis::DisplayvideoV3::InsertionOrderBudgetSegment
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::InsertionOrderBudgetSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings that control the budget of a single budget segment.
Instance Attribute Summary collapse
-
#budget_amount_micros ⇒ Fixnum
Required.
-
#campaign_budget_id ⇒ Fixnum
Optional.
-
#date_range ⇒ Google::Apis::DisplayvideoV3::DateRange
A date range.
-
#description ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertionOrderBudgetSegment
constructor
A new instance of InsertionOrderBudgetSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertionOrderBudgetSegment
Returns a new instance of InsertionOrderBudgetSegment.
8725 8726 8727 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_amount_micros ⇒ Fixnum
Required. The budget amount the insertion order will spend for the given
date_range. The amount is in micros. Must be greater than 0. For example,
500000000 represents 500 standard units of the currency.
Corresponds to the JSON property budgetAmountMicros
8705 8706 8707 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8705 def budget_amount_micros @budget_amount_micros end |
#campaign_budget_id ⇒ Fixnum
Optional. The budget_id of the campaign budget that this insertion order
budget segment is a part of.
Corresponds to the JSON property campaignBudgetId
8711 8712 8713 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8711 def campaign_budget_id @campaign_budget_id end |
#date_range ⇒ Google::Apis::DisplayvideoV3::DateRange
A date range.
Corresponds to the JSON property dateRange
8716 8717 8718 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8716 def date_range @date_range end |
#description ⇒ String
Optional. The budget segment description. It can be used to enter Purchase
Order information for each budget segment and have that information printed on
the invoices. Must be UTF-8 encoded.
Corresponds to the JSON property description
8723 8724 8725 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8723 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8730 8731 8732 8733 8734 8735 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8730 def update!(**args) @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros) @campaign_budget_id = args[:campaign_budget_id] if args.key?(:campaign_budget_id) @date_range = args[:date_range] if args.key?(:date_range) @description = args[:description] if args.key?(:description) end |