Class: Google::Apis::DisplayvideoV3::InsertionOrderBudgetSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the budget of a single budget segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrderBudgetSegment

Returns a new instance of InsertionOrderBudgetSegment.



8091
8092
8093
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_amount_microsFixnum

Required. The budget amount the insertion order will spend for the given date_range. The amount is in micros. Must be greater than 0. For example, 500000000 represents 500 standard units of the currency. Corresponds to the JSON property budgetAmountMicros

Returns:

  • (Fixnum)


8071
8072
8073
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8071

def budget_amount_micros
  @budget_amount_micros
end

#campaign_budget_idFixnum

Optional. The budget_id of the campaign budget that this insertion order budget segment is a part of. Corresponds to the JSON property campaignBudgetId

Returns:

  • (Fixnum)


8077
8078
8079
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8077

def campaign_budget_id
  @campaign_budget_id
end

#date_rangeGoogle::Apis::DisplayvideoV3::DateRange

A date range. Corresponds to the JSON property dateRange



8082
8083
8084
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8082

def date_range
  @date_range
end

#descriptionString

Optional. The budget segment description. It can be used to enter Purchase Order information for each budget segment and have that information printed on the invoices. Must be UTF-8 encoded. Corresponds to the JSON property description

Returns:

  • (String)


8089
8090
8091
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8089

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8096
8097
8098
8099
8100
8101
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8096

def update!(**args)
  @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros)
  @campaign_budget_id = args[:campaign_budget_id] if args.key?(:campaign_budget_id)
  @date_range = args[:date_range] if args.key?(:date_range)
  @description = args[:description] if args.key?(:description)
end