Class: Google::Apis::DisplayvideoV3::IntegrationDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::IntegrationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Integration details of an entry.
Instance Attribute Summary collapse
-
#details ⇒ String
Additional details of the entry in string format.
-
#integration_code ⇒ String
An external identifier to be associated with the entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntegrationDetails
constructor
A new instance of IntegrationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntegrationDetails
Returns a new instance of IntegrationDetails.
8227 8228 8229 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Additional details of the entry in string format. Must be UTF-8 encoded with a
length of no more than 1000 characters.
Corresponds to the JSON property details
8218 8219 8220 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8218 def details @details end |
#integration_code ⇒ String
An external identifier to be associated with the entry. The integration code
will show up together with the entry in many places in the system, for example,
reporting. Must be UTF-8 encoded with a length of no more than 500 characters.
Corresponds to the JSON property integrationCode
8225 8226 8227 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8225 def integration_code @integration_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8232 8233 8234 8235 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8232 def update!(**args) @details = args[:details] if args.key?(:details) @integration_code = args[:integration_code] if args.key?(:integration_code) end |