Class: Google::Apis::DisplayvideoV3::InventorySource
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::InventorySource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
An inventory source. Next ID: 22
Instance Attribute Summary collapse
-
#commitment ⇒ String
Whether the inventory source has a guaranteed or non-guaranteed delivery.
-
#creative_configs ⇒ Array<Google::Apis::DisplayvideoV3::CreativeConfig>
The creative requirements of the inventory source.
-
#deal_id ⇒ String
The ID in the exchange space that uniquely identifies the inventory source.
-
#delivery_method ⇒ String
The delivery method of the inventory source.
-
#display_name ⇒ String
The display name of the inventory source.
-
#exchange ⇒ String
The exchange to which the inventory source belongs.
-
#guaranteed_order_id ⇒ String
Immutable.
-
#inventory_source_id ⇒ Fixnum
Output only.
-
#inventory_source_product_type ⇒ String
Output only.
-
#inventory_source_type ⇒ String
Denotes the type of the inventory source.
-
#name ⇒ String
Output only.
-
#publisher_name ⇒ String
The publisher/seller name of the inventory source.
-
#rate_details ⇒ Google::Apis::DisplayvideoV3::RateDetails
The rate related settings of the inventory source.
-
#read_advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#read_partner_ids ⇒ Array<Fixnum>
Output only.
-
#read_write_accessors ⇒ Google::Apis::DisplayvideoV3::InventorySourceAccessors
The partner or advertisers with access to the inventory source.
-
#status ⇒ Google::Apis::DisplayvideoV3::InventorySourceStatus
The status related settings of the inventory source.
-
#time_range ⇒ Google::Apis::DisplayvideoV3::TimeRange
A time range.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InventorySource
constructor
A new instance of InventorySource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InventorySource
Returns a new instance of InventorySource.
8352 8353 8354 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8352 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commitment ⇒ String
Whether the inventory source has a guaranteed or non-guaranteed delivery.
Corresponds to the JSON property commitment
8245 8246 8247 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8245 def commitment @commitment end |
#creative_configs ⇒ Array<Google::Apis::DisplayvideoV3::CreativeConfig>
The creative requirements of the inventory source. Not applicable for auction
packages.
Corresponds to the JSON property creativeConfigs
8251 8252 8253 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8251 def creative_configs @creative_configs end |
#deal_id ⇒ String
The ID in the exchange space that uniquely identifies the inventory source.
Must be unique across buyers within each exchange but not necessarily unique
across exchanges.
Corresponds to the JSON property dealId
8258 8259 8260 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8258 def deal_id @deal_id end |
#delivery_method ⇒ String
The delivery method of the inventory source. * For non-guaranteed inventory
sources, the only acceptable value is
INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. * For guaranteed inventory
sources, acceptable values are INVENTORY_SOURCE_DELIVERY_METHOD_TAG and
INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC.
Corresponds to the JSON property deliveryMethod
8267 8268 8269 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8267 def delivery_method @delivery_method end |
#display_name ⇒ String
The display name of the inventory source. Must be UTF-8 encoded with a maximum
size of 240 bytes.
Corresponds to the JSON property displayName
8273 8274 8275 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8273 def display_name @display_name end |
#exchange ⇒ String
The exchange to which the inventory source belongs.
Corresponds to the JSON property exchange
8278 8279 8280 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8278 def exchange @exchange end |
#guaranteed_order_id ⇒ String
Immutable. The ID of the guaranteed order that this inventory source belongs
to. Only applicable when commitment is INVENTORY_SOURCE_COMMITMENT_GUARANTEED
.
Corresponds to the JSON property guaranteedOrderId
8285 8286 8287 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8285 def guaranteed_order_id @guaranteed_order_id end |
#inventory_source_id ⇒ Fixnum
Output only. The unique ID of the inventory source. Assigned by the system.
Corresponds to the JSON property inventorySourceId
8290 8291 8292 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8290 def inventory_source_id @inventory_source_id end |
#inventory_source_product_type ⇒ String
Output only. The product type of the inventory source, denoting the way
through which it sells inventory.
Corresponds to the JSON property inventorySourceProductType
8296 8297 8298 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8296 def inventory_source_product_type @inventory_source_product_type end |
#inventory_source_type ⇒ String
Denotes the type of the inventory source.
Corresponds to the JSON property inventorySourceType
8301 8302 8303 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8301 def inventory_source_type @inventory_source_type end |
#name ⇒ String
Output only. The resource name of the inventory source.
Corresponds to the JSON property name
8306 8307 8308 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8306 def name @name end |
#publisher_name ⇒ String
The publisher/seller name of the inventory source.
Corresponds to the JSON property publisherName
8311 8312 8313 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8311 def publisher_name @publisher_name end |
#rate_details ⇒ Google::Apis::DisplayvideoV3::RateDetails
The rate related settings of the inventory source.
Corresponds to the JSON property rateDetails
8316 8317 8318 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8316 def rate_details @rate_details end |
#read_advertiser_ids ⇒ Array<Fixnum>
Output only. The IDs of advertisers with read-only access to the inventory
source.
Corresponds to the JSON property readAdvertiserIds
8322 8323 8324 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8322 def read_advertiser_ids @read_advertiser_ids end |
#read_partner_ids ⇒ Array<Fixnum>
Output only. The IDs of partners with read-only access to the inventory source.
All advertisers of partners in this field inherit read-only access to the
inventory source.
Corresponds to the JSON property readPartnerIds
8329 8330 8331 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8329 def read_partner_ids @read_partner_ids end |
#read_write_accessors ⇒ Google::Apis::DisplayvideoV3::InventorySourceAccessors
The partner or advertisers with access to the inventory source.
Corresponds to the JSON property readWriteAccessors
8334 8335 8336 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8334 def read_write_accessors @read_write_accessors end |
#status ⇒ Google::Apis::DisplayvideoV3::InventorySourceStatus
The status related settings of the inventory source.
Corresponds to the JSON property status
8339 8340 8341 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8339 def status @status end |
#time_range ⇒ Google::Apis::DisplayvideoV3::TimeRange
A time range.
Corresponds to the JSON property timeRange
8344 8345 8346 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8344 def time_range @time_range end |
#update_time ⇒ String
Output only. The timestamp when the inventory source was last updated.
Assigned by the system.
Corresponds to the JSON property updateTime
8350 8351 8352 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8350 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8357 8358 8359 8360 8361 8362 8363 8364 8365 8366 8367 8368 8369 8370 8371 8372 8373 8374 8375 8376 8377 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8357 def update!(**args) @commitment = args[:commitment] if args.key?(:commitment) @creative_configs = args[:creative_configs] if args.key?(:creative_configs) @deal_id = args[:deal_id] if args.key?(:deal_id) @delivery_method = args[:delivery_method] if args.key?(:delivery_method) @display_name = args[:display_name] if args.key?(:display_name) @exchange = args[:exchange] if args.key?(:exchange) @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id) @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id) @inventory_source_product_type = args[:inventory_source_product_type] if args.key?(:inventory_source_product_type) @inventory_source_type = args[:inventory_source_type] if args.key?(:inventory_source_type) @name = args[:name] if args.key?(:name) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) @rate_details = args[:rate_details] if args.key?(:rate_details) @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids) @read_partner_ids = args[:read_partner_ids] if args.key?(:read_partner_ids) @read_write_accessors = args[:read_write_accessors] if args.key?(:read_write_accessors) @status = args[:status] if args.key?(:status) @time_range = args[:time_range] if args.key?(:time_range) @update_time = args[:update_time] if args.key?(:update_time) end |