Class: Google::Apis::DisplayvideoV3::KeywordAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for assigned keyword targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_KEYWORD.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeywordAssignedTargetingOptionDetails

Returns a new instance of KeywordAssignedTargetingOptionDetails.



9170
9171
9172
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempted_policy_namesArray<String>

Optional. The policy names to exempt the keyword from. When attempting to target a keyword that violates a policy, the error returned will include the name of the relevant policy. Use that name in this field to exempt the targeted keyword from the policy. This field is only applicable for positively- targeted keywords assigned to Demand Gen resources. Retrieval and management of Demand Gen resources is currently in beta. This field is only available to allowlisted users. Corresponds to the JSON property exemptedPolicyNames

Returns:

  • (Array<String>)


9155
9156
9157
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9155

def exempted_policy_names
  @exempted_policy_names
end

#keywordString

Required. The keyword, for example car insurance. Positive keyword cannot be offensive word. Must be UTF-8 encoded with a maximum size of 255 bytes. Maximum number of characters is 80. Maximum number of words is 10. Corresponds to the JSON property keyword

Returns:

  • (String)


9162
9163
9164
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9162

def keyword
  @keyword
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. Corresponds to the JSON property negative

Returns:

  • (Boolean)


9167
9168
9169
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9167

def negative
  @negative
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9175
9176
9177
9178
9179
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9175

def update!(**args)
  @exempted_policy_names = args[:exempted_policy_names] if args.key?(:exempted_policy_names)
  @keyword = args[:keyword] if args.key?(:keyword)
  @negative = args[:negative] if args.key?(:negative)
end