Class: Google::Apis::DisplayvideoV3::LanguageAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_LANGUAGE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageAssignedTargetingOptionDetails

Returns a new instance of LanguageAssignedTargetingOptionDetails.



8914
8915
8916
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the language (e.g., "French"). Corresponds to the JSON property displayName

Returns:

  • (String)


8899
8900
8901
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8899

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned language targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


8905
8906
8907
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8905

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


8912
8913
8914
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8912

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8919
8920
8921
8922
8923
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8919

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end