Class: Google::Apis::DisplayvideoV3::LineItem
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::LineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A single line item.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#bid_strategy ⇒ Google::Apis::DisplayvideoV3::BiddingStrategy
Settings that control the bid strategy.
-
#budget ⇒ Google::Apis::DisplayvideoV3::LineItemBudget
Settings that control how budget is allocated.
-
#campaign_id ⇒ Fixnum
Output only.
-
#contains_eu_political_ads ⇒ String
Whether this line item will serve European Union political ads.
-
#conversion_counting ⇒ Google::Apis::DisplayvideoV3::ConversionCountingConfig
Settings that control how conversions are counted.
-
#creative_ids ⇒ Array<Fixnum>
The IDs of the creatives associated with the line item.
-
#demand_gen_settings ⇒ Google::Apis::DisplayvideoV3::DemandGenSettings
Settings for Demand Gen line items.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#exclude_new_exchanges ⇒ Boolean
(also: #exclude_new_exchanges?)
Whether to exclude new exchanges from automatically being targeted by the line item.
-
#flight ⇒ Google::Apis::DisplayvideoV3::LineItemFlight
Settings that control the active duration of a line item.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#insertion_order_id ⇒ Fixnum
Required.
-
#integration_details ⇒ Google::Apis::DisplayvideoV3::IntegrationDetails
Integration details of an entry.
-
#line_item_id ⇒ Fixnum
Output only.
-
#line_item_type ⇒ String
Required.
-
#mobile_app ⇒ Google::Apis::DisplayvideoV3::MobileApp
A mobile app promoted by a mobile app install line item.
-
#name ⇒ String
Output only.
-
#optimize_fixed_bidding ⇒ Boolean
(also: #optimize_fixed_bidding?)
Optional.
-
#pacing ⇒ Google::Apis::DisplayvideoV3::Pacing
Settings that control the rate at which a budget is spent.
-
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV3::PartnerCost>
The partner costs associated with the line item.
-
#partner_revenue_model ⇒ Google::Apis::DisplayvideoV3::PartnerRevenueModel
Settings that control how partner revenue is calculated.
-
#reservation_type ⇒ String
Output only.
-
#targeting_expansion ⇒ Google::Apis::DisplayvideoV3::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
-
#update_time ⇒ String
Output only.
-
#warning_messages ⇒ Array<String>
Output only.
-
#youtube_and_partners_settings ⇒ Google::Apis::DisplayvideoV3::YoutubeAndPartnersSettings
Settings for YouTube and Partners line items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LineItem
constructor
A new instance of LineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LineItem
Returns a new instance of LineItem.
9159 9160 9161 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the line item belongs to.
Corresponds to the JSON property advertiserId
8990 8991 8992 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8990 def advertiser_id @advertiser_id end |
#bid_strategy ⇒ Google::Apis::DisplayvideoV3::BiddingStrategy
Settings that control the bid strategy. Bid strategy determines the bid price.
Corresponds to the JSON property bidStrategy
8995 8996 8997 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8995 def bid_strategy @bid_strategy end |
#budget ⇒ Google::Apis::DisplayvideoV3::LineItemBudget
Settings that control how budget is allocated.
Corresponds to the JSON property budget
9000 9001 9002 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9000 def budget @budget end |
#campaign_id ⇒ Fixnum
Output only. The unique ID of the campaign that the line item belongs to.
Corresponds to the JSON property campaignId
9005 9006 9007 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9005 def campaign_id @campaign_id end |
#contains_eu_political_ads ⇒ String
Whether this line item will serve European Union political ads. If
contains_eu_political_ads has been set to
DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this
field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not
otherwise specified. This field can then be updated using the UI, API, or
Structured Data Files. This field must be assigned when creating a new line
item. Otherwise, the advertisers.lineItems.create request will fail.
Corresponds to the JSON property containsEuPoliticalAds
9016 9017 9018 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9016 def contains_eu_political_ads @contains_eu_political_ads end |
#conversion_counting ⇒ Google::Apis::DisplayvideoV3::ConversionCountingConfig
Settings that control how conversions are counted. All post-click conversions
will be counted. A percentage value can be set for post-view conversions
counting.
Corresponds to the JSON property conversionCounting
9023 9024 9025 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9023 def conversion_counting @conversion_counting end |
#creative_ids ⇒ Array<Fixnum>
The IDs of the creatives associated with the line item.
Corresponds to the JSON property creativeIds
9028 9029 9030 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9028 def creative_ids @creative_ids end |
#demand_gen_settings ⇒ Google::Apis::DisplayvideoV3::DemandGenSettings
Settings for Demand Gen line items.
Corresponds to the JSON property demandGenSettings
9033 9034 9035 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9033 def demand_gen_settings @demand_gen_settings end |
#display_name ⇒ String
Required. The display name of the line item. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
9039 9040 9041 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9039 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the line item can spend its budget and bid
on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is
allowed. To activate a line item, use UpdateLineItem method and update the
status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be
changed back to ENTITY_STATUS_DRAFT status from any other status. * If the
line item's parent insertion order is not active, the line item can't spend
its budget even if its own status is ENTITY_STATUS_ACTIVE.
Corresponds to the JSON property entityStatus
9050 9051 9052 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9050 def entity_status @entity_status end |
#exclude_new_exchanges ⇒ Boolean Also known as: exclude_new_exchanges?
Whether to exclude new exchanges from automatically being targeted by the line
item. This field is false by default.
Corresponds to the JSON property excludeNewExchanges
9056 9057 9058 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9056 def exclude_new_exchanges @exclude_new_exchanges end |
#flight ⇒ Google::Apis::DisplayvideoV3::LineItemFlight
Settings that control the active duration of a line item.
Corresponds to the JSON property flight
9062 9063 9064 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9062 def flight @flight end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
9068 9069 9070 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9068 def frequency_cap @frequency_cap end |
#insertion_order_id ⇒ Fixnum
Required. Immutable. The unique ID of the insertion order that the line item
belongs to.
Corresponds to the JSON property insertionOrderId
9074 9075 9076 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9074 def insertion_order_id @insertion_order_id end |
#integration_details ⇒ Google::Apis::DisplayvideoV3::IntegrationDetails
Integration details of an entry.
Corresponds to the JSON property integrationDetails
9079 9080 9081 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9079 def integration_details @integration_details end |
#line_item_id ⇒ Fixnum
Output only. The unique ID of the line item. Assigned by the system.
Corresponds to the JSON property lineItemId
9084 9085 9086 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9084 def line_item_id @line_item_id end |
#line_item_type ⇒ String
Required. Immutable. The type of the line item.
Corresponds to the JSON property lineItemType
9089 9090 9091 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9089 def line_item_type @line_item_type end |
#mobile_app ⇒ Google::Apis::DisplayvideoV3::MobileApp
A mobile app promoted by a mobile app install line item.
Corresponds to the JSON property mobileApp
9094 9095 9096 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9094 def mobile_app @mobile_app end |
#name ⇒ String
Output only. The resource name of the line item.
Corresponds to the JSON property name
9099 9100 9101 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9099 def name @name end |
#optimize_fixed_bidding ⇒ Boolean Also known as: optimize_fixed_bidding?
Optional. Whether to enable DV360's bid optimization for fixed bid line items.
By default, DV360 optimizes your fixed bid by automatically lowering bids for
impressions that are less likely to perform well. This optimization is enabled
by default (value is true). When this field is set to false, this
optimization is disabled, and the bid will not be lowered for any reason. This
setting only applies to line items with a bidding_strategy of type
FIXED_BID.
Corresponds to the JSON property optimizeFixedBidding
9110 9111 9112 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9110 def optimize_fixed_bidding @optimize_fixed_bidding end |
#pacing ⇒ Google::Apis::DisplayvideoV3::Pacing
Settings that control the rate at which a budget is spent.
Corresponds to the JSON property pacing
9116 9117 9118 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9116 def pacing @pacing end |
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV3::PartnerCost>
The partner costs associated with the line item. If absent or empty in
CreateLineItem method, the newly created line item will inherit partner costs
from its parent insertion order.
Corresponds to the JSON property partnerCosts
9123 9124 9125 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9123 def partner_costs @partner_costs end |
#partner_revenue_model ⇒ Google::Apis::DisplayvideoV3::PartnerRevenueModel
Settings that control how partner revenue is calculated.
Corresponds to the JSON property partnerRevenueModel
9128 9129 9130 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9128 def partner_revenue_model @partner_revenue_model end |
#reservation_type ⇒ String
Output only. The reservation type of the line item.
Corresponds to the JSON property reservationType
9133 9134 9135 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9133 def reservation_type @reservation_type end |
#targeting_expansion ⇒ Google::Apis::DisplayvideoV3::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
Corresponds to the JSON property targetingExpansion
9139 9140 9141 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9139 def targeting_expansion @targeting_expansion end |
#update_time ⇒ String
Output only. The timestamp when the line item was last updated. Assigned by
the system.
Corresponds to the JSON property updateTime
9145 9146 9147 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9145 def update_time @update_time end |
#warning_messages ⇒ Array<String>
Output only. The warning messages generated by the line item. These warnings
do not block saving the line item, but some may block the line item from
running.
Corresponds to the JSON property warningMessages
9152 9153 9154 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9152 def @warning_messages end |
#youtube_and_partners_settings ⇒ Google::Apis::DisplayvideoV3::YoutubeAndPartnersSettings
Settings for YouTube and Partners line items.
Corresponds to the JSON property youtubeAndPartnersSettings
9157 9158 9159 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9157 def youtube_and_partners_settings @youtube_and_partners_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9164 9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9164 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy) @budget = args[:budget] if args.key?(:budget) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads) @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting) @creative_ids = args[:creative_ids] if args.key?(:creative_ids) @demand_gen_settings = args[:demand_gen_settings] if args.key?(:demand_gen_settings) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges) @flight = args[:flight] if args.key?(:flight) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id) @integration_details = args[:integration_details] if args.key?(:integration_details) @line_item_id = args[:line_item_id] if args.key?(:line_item_id) @line_item_type = args[:line_item_type] if args.key?(:line_item_type) @mobile_app = args[:mobile_app] if args.key?(:mobile_app) @name = args[:name] if args.key?(:name) @optimize_fixed_bidding = args[:optimize_fixed_bidding] if args.key?(:optimize_fixed_bidding) @pacing = args[:pacing] if args.key?(:pacing) @partner_costs = args[:partner_costs] if args.key?(:partner_costs) @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model) @reservation_type = args[:reservation_type] if args.key?(:reservation_type) @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion) @update_time = args[:update_time] if args.key?(:update_time) @warning_messages = args[:warning_messages] if args.key?(:warning_messages) @youtube_and_partners_settings = args[:youtube_and_partners_settings] if args.key?(:youtube_and_partners_settings) end |