Class: Google::Apis::DisplayvideoV3::LineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItem

Returns a new instance of LineItem.



9105
9106
9107
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the line item belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8953
8954
8955
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8953

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV3::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



8958
8959
8960
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8958

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV3::LineItemBudget

Settings that control how budget is allocated. Corresponds to the JSON property budget



8963
8964
8965
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8963

def budget
  @budget
end

#campaign_idFixnum

Output only. The unique ID of the campaign that the line item belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


8968
8969
8970
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8968

def campaign_id
  @campaign_id
end

#contains_eu_political_adsString

Whether this line item will serve European Union political ads. If contains_eu_political_ads has been set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. This field can then be updated using the UI, API, or Structured Data Files. This field must be assigned when creating a new line item. Otherwise, the advertisers.lineItems.create request will fail. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


8979
8980
8981
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8979

def contains_eu_political_ads
  @contains_eu_political_ads
end

#conversion_countingGoogle::Apis::DisplayvideoV3::ConversionCountingConfig

Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting. Corresponds to the JSON property conversionCounting



8986
8987
8988
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8986

def conversion_counting
  @conversion_counting
end

#creative_idsArray<Fixnum>

The IDs of the creatives associated with the line item. Corresponds to the JSON property creativeIds

Returns:

  • (Array<Fixnum>)


8991
8992
8993
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8991

def creative_ids
  @creative_ids
end

#display_nameString

Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


8997
8998
8999
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 8997

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the line item can spend its budget and bid on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is allowed. To activate a line item, use UpdateLineItem method and update the status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * If the line item's parent insertion order is not active, the line item can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


9008
9009
9010
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9008

def entity_status
  @entity_status
end

#exclude_new_exchangesBoolean Also known as: exclude_new_exchanges?

Whether to exclude new exchanges from automatically being targeted by the line item. This field is false by default. Corresponds to the JSON property excludeNewExchanges

Returns:

  • (Boolean)


9014
9015
9016
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9014

def exclude_new_exchanges
  @exclude_new_exchanges
end

#flightGoogle::Apis::DisplayvideoV3::LineItemFlight

Settings that control the active duration of a line item. Corresponds to the JSON property flight



9020
9021
9022
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9020

def flight
  @flight
end

#frequency_capGoogle::Apis::DisplayvideoV3::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



9026
9027
9028
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9026

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Required. Immutable. The unique ID of the insertion order that the line item belongs to. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


9032
9033
9034
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9032

def insertion_order_id
  @insertion_order_id
end

#integration_detailsGoogle::Apis::DisplayvideoV3::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



9037
9038
9039
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9037

def integration_details
  @integration_details
end

#line_item_idFixnum

Output only. The unique ID of the line item. Assigned by the system. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


9042
9043
9044
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9042

def line_item_id
  @line_item_id
end

#line_item_typeString

Required. Immutable. The type of the line item. Corresponds to the JSON property lineItemType

Returns:

  • (String)


9047
9048
9049
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9047

def line_item_type
  @line_item_type
end

#mobile_appGoogle::Apis::DisplayvideoV3::MobileApp

A mobile app promoted by a mobile app install line item. Corresponds to the JSON property mobileApp



9052
9053
9054
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9052

def mobile_app
  @mobile_app
end

#nameString

Output only. The resource name of the line item. Corresponds to the JSON property name

Returns:

  • (String)


9057
9058
9059
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9057

def name
  @name
end

#pacingGoogle::Apis::DisplayvideoV3::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



9062
9063
9064
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9062

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV3::PartnerCost>

The partner costs associated with the line item. If absent or empty in CreateLineItem method, the newly created line item will inherit partner costs from its parent insertion order. Corresponds to the JSON property partnerCosts



9069
9070
9071
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9069

def partner_costs
  @partner_costs
end

#partner_revenue_modelGoogle::Apis::DisplayvideoV3::PartnerRevenueModel

Settings that control how partner revenue is calculated. Corresponds to the JSON property partnerRevenueModel



9074
9075
9076
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9074

def partner_revenue_model
  @partner_revenue_model
end

#reservation_typeString

Output only. The reservation type of the line item. Corresponds to the JSON property reservationType

Returns:

  • (String)


9079
9080
9081
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9079

def reservation_type
  @reservation_type
end

#targeting_expansionGoogle::Apis::DisplayvideoV3::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



9085
9086
9087
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9085

def targeting_expansion
  @targeting_expansion
end

#update_timeString

Output only. The timestamp when the line item was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9091
9092
9093
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9091

def update_time
  @update_time
end

#warning_messagesArray<String>

Output only. The warning messages generated by the line item. These warnings do not block saving the line item, but some may block the line item from running. Corresponds to the JSON property warningMessages

Returns:

  • (Array<String>)


9098
9099
9100
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9098

def warning_messages
  @warning_messages
end

#youtube_and_partners_settingsGoogle::Apis::DisplayvideoV3::YoutubeAndPartnersSettings

Settings for YouTube and Partners line items. Corresponds to the JSON property youtubeAndPartnersSettings



9103
9104
9105
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9103

def youtube_and_partners_settings
  @youtube_and_partners_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9110
9111
9112
9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9110

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @creative_ids = args[:creative_ids] if args.key?(:creative_ids)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges)
  @flight = args[:flight] if args.key?(:flight)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @line_item_type = args[:line_item_type] if args.key?(:line_item_type)
  @mobile_app = args[:mobile_app] if args.key?(:mobile_app)
  @name = args[:name] if args.key?(:name)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @update_time = args[:update_time] if args.key?(:update_time)
  @warning_messages = args[:warning_messages] if args.key?(:warning_messages)
  @youtube_and_partners_settings = args[:youtube_and_partners_settings] if args.key?(:youtube_and_partners_settings)
end