Class: Google::Apis::DisplayvideoV3::ListChannelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListChannelsResponse

Returns a new instance of ListChannelsResponse.



9470
9471
9472
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channelsArray<Google::Apis::DisplayvideoV3::Channel>

The list of channels. This list will be absent if empty. Corresponds to the JSON property channels



9461
9462
9463
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9461

def channels
  @channels
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListChannels method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9468
9469
9470
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9468

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9475
9476
9477
9478
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9475

def update!(**args)
  @channels = args[:channels] if args.key?(:channels)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end