Class: Google::Apis::DisplayvideoV3::ListCreativesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListCreativesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#creatives ⇒ Array<Google::Apis::DisplayvideoV3::Creative>
The list of creatives.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCreativesResponse
constructor
A new instance of ListCreativesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCreativesResponse
Returns a new instance of ListCreativesResponse.
9582 9583 9584 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creatives ⇒ Array<Google::Apis::DisplayvideoV3::Creative>
The list of creatives. This list will be absent if empty.
Corresponds to the JSON property creatives
9572 9573 9574 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9572 def creatives @creatives end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCreativesRequest method to
retrieve the next page of results. If this field is null, it means this is the
last page.
Corresponds to the JSON property nextPageToken
9580 9581 9582 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9580 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9587 9588 9589 9590 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9587 def update!(**args) @creatives = args[:creatives] if args.key?(:creatives) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |