Class: Google::Apis::DisplayvideoV3::ListCreativesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListCreativesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#creatives ⇒ Array<Google::Apis::DisplayvideoV3::Creative>
The list of creatives.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCreativesResponse
constructor
A new instance of ListCreativesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCreativesResponse
Returns a new instance of ListCreativesResponse.
9891 9892 9893 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creatives ⇒ Array<Google::Apis::DisplayvideoV3::Creative>
The list of creatives. This list will be absent if empty.
Corresponds to the JSON property creatives
9881 9882 9883 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9881 def creatives @creatives end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCreativesRequest method to
retrieve the next page of results. If this field is null, it means this is the
last page.
Corresponds to the JSON property nextPageToken
9889 9890 9891 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9889 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9896 9897 9898 9899 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9896 def update!(**args) @creatives = args[:creatives] if args.key?(:creatives) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |