Class: Google::Apis::DisplayvideoV3::ListCreativesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCreativesResponse

Returns a new instance of ListCreativesResponse.



9525
9526
9527
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creativesArray<Google::Apis::DisplayvideoV3::Creative>

The list of creatives. This list will be absent if empty. Corresponds to the JSON property creatives



9515
9516
9517
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9515

def creatives
  @creatives
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCreativesRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9523
9524
9525
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9523

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9530
9531
9532
9533
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9530

def update!(**args)
  @creatives = args[:creatives] if args.key?(:creatives)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end