Class: Google::Apis::DisplayvideoV3::ListCustomBiddingAlgorithmRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListCustomBiddingAlgorithmRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#custom_bidding_rules ⇒ Array<Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRules>
The list of CustomBiddingAlgorithmRules resources.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomBiddingAlgorithmRulesResponse
constructor
A new instance of ListCustomBiddingAlgorithmRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomBiddingAlgorithmRulesResponse
Returns a new instance of ListCustomBiddingAlgorithmRulesResponse.
9618 9619 9620 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_bidding_rules ⇒ Array<Google::Apis::DisplayvideoV3::CustomBiddingAlgorithmRules>
The list of CustomBiddingAlgorithmRules resources. This list will be absent if
empty.
Corresponds to the JSON property customBiddingRules
9608 9609 9610 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9608 def custom_bidding_rules @custom_bidding_rules end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to
ListCustomBiddingAlgorithmRulesRequest method to retrieve the next page of
results. If this field is null, it means this is the last page.
Corresponds to the JSON property nextPageToken
9616 9617 9618 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9616 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9623 9624 9625 9626 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9623 def update!(**args) @custom_bidding_rules = args[:custom_bidding_rules] if args.key?(:custom_bidding_rules) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |