Class: Google::Apis::DisplayvideoV3::ListFirstAndThirdPartyAudiencesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListFirstAndThirdPartyAudiencesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#first_and_third_party_audiences ⇒ Array<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudience>
The list of first and third party audiences.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFirstAndThirdPartyAudiencesResponse
constructor
A new instance of ListFirstAndThirdPartyAudiencesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFirstAndThirdPartyAudiencesResponse
Returns a new instance of ListFirstAndThirdPartyAudiencesResponse.
10031 10032 10033 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#first_and_third_party_audiences ⇒ Array<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudience>
The list of first and third party audiences. Audience size properties will not
be included. This list will be absent if empty.
Corresponds to the JSON property firstAndThirdPartyAudiences
10022 10023 10024 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10022 def first_and_third_party_audiences @first_and_third_party_audiences end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListFirstAndThirdPartyAudiences
method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
10029 10030 10031 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10029 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10036 10037 10038 10039 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10036 def update!(**args) @first_and_third_party_audiences = args[:first_and_third_party_audiences] if args.key?(:first_and_third_party_audiences) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |