Class: Google::Apis::DisplayvideoV3::ListFirstAndThirdPartyAudiencesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFirstAndThirdPartyAudiencesResponse

Returns a new instance of ListFirstAndThirdPartyAudiencesResponse.



9665
9666
9667
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#first_and_third_party_audiencesArray<Google::Apis::DisplayvideoV3::FirstAndThirdPartyAudience>

The list of first and third party audiences. Audience size properties will not be included. This list will be absent if empty. Corresponds to the JSON property firstAndThirdPartyAudiences



9656
9657
9658
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9656

def first_and_third_party_audiences
  @first_and_third_party_audiences
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListFirstAndThirdPartyAudiences method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9663
9664
9665
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9663

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9670
9671
9672
9673
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9670

def update!(**args)
  @first_and_third_party_audiences = args[:first_and_third_party_audiences] if args.key?(:first_and_third_party_audiences)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end