Class: Google::Apis::DisplayvideoV3::ListInvoicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInvoicesResponse

Returns a new instance of ListInvoicesResponse.



9857
9858
9859
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#invoicesArray<Google::Apis::DisplayvideoV3::Invoice>

The list of invoices. This list will be absent if empty. Corresponds to the JSON property invoices



9847
9848
9849
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9847

def invoices
  @invoices
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListInvoices method to retrieve the next page of results. This token will be absent if there are no more invoices to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9855
9856
9857
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9855

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9862
9863
9864
9865
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9862

def update!(**args)
  @invoices = args[:invoices] if args.key?(:invoices)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end