Class: Google::Apis::DisplayvideoV3::ListInvoicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListInvoicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#invoices ⇒ Array<Google::Apis::DisplayvideoV3::Invoice>
The list of invoices.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInvoicesResponse
constructor
A new instance of ListInvoicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInvoicesResponse
Returns a new instance of ListInvoicesResponse.
9855 9856 9857 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invoices ⇒ Array<Google::Apis::DisplayvideoV3::Invoice>
The list of invoices. This list will be absent if empty.
Corresponds to the JSON property invoices
9845 9846 9847 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9845 def invoices @invoices end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListInvoices method to retrieve
the next page of results. This token will be absent if there are no more
invoices to return.
Corresponds to the JSON property nextPageToken
9853 9854 9855 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9853 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9860 9861 9862 9863 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 9860 def update!(**args) @invoices = args[:invoices] if args.key?(:invoices) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |