Class: Google::Apis::DisplayvideoV3::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#users ⇒ Array<Google::Apis::DisplayvideoV3::User>
The list of users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
10137 10138 10139 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListUsers method to retrieve the
next page of results. This token will be absent if there are no more results
to return.
Corresponds to the JSON property nextPageToken
10130 10131 10132 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10130 def next_page_token @next_page_token end |
#users ⇒ Array<Google::Apis::DisplayvideoV3::User>
The list of users. This list will be absent if empty.
Corresponds to the JSON property users
10135 10136 10137 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10135 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10142 10143 10144 10145 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10142 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @users = args[:users] if args.key?(:users) end |