Class: Google::Apis::DisplayvideoV3::ListUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUsersResponse

Returns a new instance of ListUsersResponse.



10128
10129
10130
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListUsers method to retrieve the next page of results. This token will be absent if there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10121
10122
10123
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10121

def next_page_token
  @next_page_token
end

#usersArray<Google::Apis::DisplayvideoV3::User>

The list of users. This list will be absent if empty. Corresponds to the JSON property users



10126
10127
10128
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10126

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10133
10134
10135
10136
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10133

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @users = args[:users] if args.key?(:users)
end