Class: Google::Apis::DisplayvideoV3::MobileApp
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::MobileApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
A mobile app promoted by a mobile app install line item.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#display_name ⇒ String
Output only.
-
#platform ⇒ String
Output only.
-
#publisher ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileApp
constructor
A new instance of MobileApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileApp
Returns a new instance of MobileApp.
10755 10756 10757 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. The ID of the app provided by the platform store. Android apps are
identified by the bundle ID used by Android's Play store, such as com.google.
android.gm. iOS apps are identified by a nine-digit app ID used by Apple's
App store, such as 422689480.
Corresponds to the JSON property appId
10738 10739 10740 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10738 def app_id @app_id end |
#display_name ⇒ String
Output only. The app name.
Corresponds to the JSON property displayName
10743 10744 10745 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10743 def display_name @display_name end |
#platform ⇒ String
Output only. The app platform.
Corresponds to the JSON property platform
10748 10749 10750 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10748 def platform @platform end |
#publisher ⇒ String
Output only. The app publisher.
Corresponds to the JSON property publisher
10753 10754 10755 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10753 def publisher @publisher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10760 10761 10762 10763 10764 10765 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10760 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @display_name = args[:display_name] if args.key?(:display_name) @platform = args[:platform] if args.key?(:platform) @publisher = args[:publisher] if args.key?(:publisher) end |