Class: Google::Apis::DisplayvideoV3::MobileApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A mobile app promoted by a mobile app install line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileApp

Returns a new instance of MobileApp.



10416
10417
10418
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. The ID of the app provided by the platform store. Android apps are identified by the bundle ID used by Android's Play store, such as com.google. android.gm. iOS apps are identified by a nine-digit app ID used by Apple's App store, such as 422689480. Corresponds to the JSON property appId

Returns:

  • (String)


10399
10400
10401
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10399

def app_id
  @app_id
end

#display_nameString

Output only. The app name. Corresponds to the JSON property displayName

Returns:

  • (String)


10404
10405
10406
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10404

def display_name
  @display_name
end

#platformString

Output only. The app platform. Corresponds to the JSON property platform

Returns:

  • (String)


10409
10410
10411
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10409

def platform
  @platform
end

#publisherString

Output only. The app publisher. Corresponds to the JSON property publisher

Returns:

  • (String)


10414
10415
10416
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10414

def publisher
  @publisher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10421
10422
10423
10424
10425
10426
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10421

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @platform = args[:platform] if args.key?(:platform)
  @publisher = args[:publisher] if args.key?(:publisher)
end