Class: Google::Apis::DisplayvideoV3::NegativeKeywordList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A list of negative keywords used for targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NegativeKeywordList

Returns a new instance of NegativeKeywordList.



10599
10600
10601
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the negative keyword list belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


10574
10575
10576
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10574

def advertiser_id
  @advertiser_id
end

#display_nameString

Required. The display name of the negative keyword list. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


10580
10581
10582
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10580

def display_name
  @display_name
end

#nameString

Output only. The resource name of the negative keyword list. Corresponds to the JSON property name

Returns:

  • (String)


10585
10586
10587
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10585

def name
  @name
end

#negative_keyword_list_idFixnum

Output only. The unique ID of the negative keyword list. Assigned by the system. Corresponds to the JSON property negativeKeywordListId

Returns:

  • (Fixnum)


10591
10592
10593
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10591

def negative_keyword_list_id
  @negative_keyword_list_id
end

#targeted_line_item_countFixnum

Output only. Number of line items that are directly targeting this negative keyword list. Corresponds to the JSON property targetedLineItemCount

Returns:

  • (Fixnum)


10597
10598
10599
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10597

def targeted_line_item_count
  @targeted_line_item_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10604
10605
10606
10607
10608
10609
10610
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 10604

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @negative_keyword_list_id = args[:negative_keyword_list_id] if args.key?(:negative_keyword_list_id)
  @targeted_line_item_count = args[:targeted_line_item_count] if args.key?(:targeted_line_item_count)
end