Class: Google::Apis::DisplayvideoV3::OnScreenPositionAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::OnScreenPositionAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
On screen position targeting option details. This will be populated in the
on_screen_position_details field when targeting_type is
TARGETING_TYPE_ON_SCREEN_POSITION.
Instance Attribute Summary collapse
-
#ad_type ⇒ String
Output only.
-
#on_screen_position ⇒ String
Output only.
-
#targeting_option_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OnScreenPositionAssignedTargetingOptionDetails
constructor
A new instance of OnScreenPositionAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OnScreenPositionAssignedTargetingOptionDetails
Returns a new instance of OnScreenPositionAssignedTargetingOptionDetails.
11097 11098 11099 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_type ⇒ String
Output only. The ad type to target. Only applicable to insertion order
targeting and new line items supporting the specified ad type will inherit
this targeting option by default. Possible values are: * AD_TYPE_DISPLAY,
the setting will be inherited by new line item when line_item_type is
LINE_ITEM_TYPE_DISPLAY_DEFAULT. * AD_TYPE_VIDEO, the setting will be
inherited by new line item when line_item_type is
LINE_ITEM_TYPE_VIDEO_DEFAULT.
Corresponds to the JSON property adType
11084 11085 11086 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11084 def ad_type @ad_type end |
#on_screen_position ⇒ String
Output only. The on screen position.
Corresponds to the JSON property onScreenPosition
11089 11090 11091 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11089 def on_screen_position @on_screen_position end |
#targeting_option_id ⇒ String
Required. The targeting_option_id field when targeting_type is
TARGETING_TYPE_ON_SCREEN_POSITION.
Corresponds to the JSON property targetingOptionId
11095 11096 11097 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11095 def targeting_option_id @targeting_option_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11102 11103 11104 11105 11106 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11102 def update!(**args) @ad_type = args[:ad_type] if args.key?(:ad_type) @on_screen_position = args[:on_screen_position] if args.key?(:on_screen_position) @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id) end |