Class: Google::Apis::DisplayvideoV3::Partner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

A single partner in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Partner

Returns a new instance of Partner.



11128
11129
11130
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV3::PartnerAdServerConfig

Ad server related settings of a partner. Corresponds to the JSON property adServerConfig



11079
11080
11081
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11079

def ad_server_config
  @ad_server_config
end

#billing_configGoogle::Apis::DisplayvideoV3::PartnerBillingConfig

Billing related settings of a partner. Corresponds to the JSON property billingConfig



11084
11085
11086
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11084

def billing_config
  @billing_config
end

#data_access_configGoogle::Apis::DisplayvideoV3::PartnerDataAccessConfig

Settings that control how partner related data may be accessed. Corresponds to the JSON property dataAccessConfig



11089
11090
11091
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11089

def data_access_config
  @data_access_config
end

#display_nameString

The display name of the partner. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


11095
11096
11097
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11095

def display_name
  @display_name
end

#entity_statusString

Output only. The status of the partner. Corresponds to the JSON property entityStatus

Returns:

  • (String)


11100
11101
11102
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11100

def entity_status
  @entity_status
end

#exchange_configGoogle::Apis::DisplayvideoV3::ExchangeConfig

Settings that control which exchanges are enabled for a partner. Corresponds to the JSON property exchangeConfig



11105
11106
11107
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11105

def exchange_config
  @exchange_config
end

#general_configGoogle::Apis::DisplayvideoV3::PartnerGeneralConfig

General settings of a partner. Corresponds to the JSON property generalConfig



11110
11111
11112
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11110

def general_config
  @general_config
end

#nameString

Output only. The resource name of the partner. Corresponds to the JSON property name

Returns:

  • (String)


11115
11116
11117
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11115

def name
  @name
end

#partner_idFixnum

Output only. The unique ID of the partner. Assigned by the system. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


11120
11121
11122
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11120

def partner_id
  @partner_id
end

#update_timeString

Output only. The timestamp when the partner was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


11126
11127
11128
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11126

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11133
11134
11135
11136
11137
11138
11139
11140
11141
11142
11143
11144
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11133

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exchange_config = args[:exchange_config] if args.key?(:exchange_config)
  @general_config = args[:general_config] if args.key?(:general_config)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end