Class: Google::Apis::DisplayvideoV3::PoiAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::PoiAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Details for assigned POI targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_POI.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#latitude ⇒ Float
Output only.
-
#longitude ⇒ Float
Output only.
-
#proximity_radius_amount ⇒ Float
Required.
-
#proximity_radius_unit ⇒ String
Required.
-
#targeting_option_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PoiAssignedTargetingOptionDetails
constructor
A new instance of PoiAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PoiAssignedTargetingOptionDetails
Returns a new instance of PoiAssignedTargetingOptionDetails.
11428 11429 11430 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name of a POI, e.g. "Times Square", "Space Needle",
followed by its full address if available.
Corresponds to the JSON property displayName
11388 11389 11390 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11388 def display_name @display_name end |
#latitude ⇒ Float
Output only. Latitude of the POI rounding to 6th decimal place.
Corresponds to the JSON property latitude
11393 11394 11395 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11393 def latitude @latitude end |
#longitude ⇒ Float
Output only. Longitude of the POI rounding to 6th decimal place.
Corresponds to the JSON property longitude
11398 11399 11400 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11398 def longitude @longitude end |
#proximity_radius_amount ⇒ Float
Required. The radius of the area around the POI that will be targeted. The
units of the radius are specified by proximity_radius_unit. Must be 1 to 800
if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is
DISTANCE_UNIT_MILES.
Corresponds to the JSON property proximityRadiusAmount
11406 11407 11408 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11406 def proximity_radius_amount @proximity_radius_amount end |
#proximity_radius_unit ⇒ String
Required. The unit of distance by which the targeting radius is measured.
Corresponds to the JSON property proximityRadiusUnit
11411 11412 11413 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11411 def proximity_radius_unit @proximity_radius_unit end |
#targeting_option_id ⇒ String
Required. The targeting_option_id of a TargetingOption of type
TARGETING_TYPE_POI. Accepted POI targeting option IDs can be retrieved using
targetingTypes.targetingOptions.search. If targeting a specific latitude/
longitude coordinate removed from an address or POI name, you can generate the
necessary targeting option ID by rounding the desired coordinate values to the
6th decimal place, removing the decimals, and concatenating the string values
separated by a semicolon. For example, you can target the latitude/longitude
pair of 40.7414691, -74.003387 using the targeting option ID "40741469;-
74003387". Upon creation, this field value will be updated to append a
semicolon and alphanumerical hash value if only latitude/longitude
coordinates are provided.
Corresponds to the JSON property targetingOptionId
11426 11427 11428 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11426 def targeting_option_id @targeting_option_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11433 11434 11435 11436 11437 11438 11439 11440 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11433 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount) @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit) @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id) end |