Class: Google::Apis::DisplayvideoV3::PoiAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_POI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoiAssignedTargetingOptionDetails

Returns a new instance of PoiAssignedTargetingOptionDetails.



11792
11793
11794
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of a POI, e.g. "Times Square", "Space Needle", followed by its full address if available. Corresponds to the JSON property displayName

Returns:

  • (String)


11752
11753
11754
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11752

def display_name
  @display_name
end

#latitudeFloat

Output only. Latitude of the POI rounding to 6th decimal place. Corresponds to the JSON property latitude

Returns:

  • (Float)


11757
11758
11759
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11757

def latitude
  @latitude
end

#longitudeFloat

Output only. Longitude of the POI rounding to 6th decimal place. Corresponds to the JSON property longitude

Returns:

  • (Float)


11762
11763
11764
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11762

def longitude
  @longitude
end

#proximity_radius_amountFloat

Required. The radius of the area around the POI that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is DISTANCE_UNIT_MILES. Corresponds to the JSON property proximityRadiusAmount

Returns:

  • (Float)


11770
11771
11772
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11770

def proximity_radius_amount
  @proximity_radius_amount
end

#proximity_radius_unitString

Required. The unit of distance by which the targeting radius is measured. Corresponds to the JSON property proximityRadiusUnit

Returns:

  • (String)


11775
11776
11777
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11775

def proximity_radius_unit
  @proximity_radius_unit
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_POI. Accepted POI targeting option IDs can be retrieved using targetingTypes.targetingOptions.search. If targeting a specific latitude/ longitude coordinate removed from an address or POI name, you can generate the necessary targeting option ID by rounding the desired coordinate values to the 6th decimal place, removing the decimals, and concatenating the string values separated by a semicolon. For example, you can target the latitude/longitude pair of 40.7414691, -74.003387 using the targeting option ID "40741469;- 74003387". Upon creation, this field value will be updated to append a semicolon and alphanumerical hash value if only latitude/longitude coordinates are provided. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


11790
11791
11792
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11790

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11797
11798
11799
11800
11801
11802
11803
11804
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 11797

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount)
  @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end