Class: Google::Apis::DisplayvideoV3::ScriptError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

An error message for a custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScriptError

Returns a new instance of ScriptError.



12261
12262
12263
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnFixnum

The column number in the script where the error was thrown. Corresponds to the JSON property column

Returns:

  • (Fixnum)


12244
12245
12246
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12244

def column
  @column
end

#error_codeString

The type of error. Corresponds to the JSON property errorCode

Returns:

  • (String)


12249
12250
12251
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12249

def error_code
  @error_code
end

#error_messageString

The detailed error message. Corresponds to the JSON property errorMessage

Returns:

  • (String)


12254
12255
12256
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12254

def error_message
  @error_message
end

#lineFixnum

The line number in the script where the error was thrown. Corresponds to the JSON property line

Returns:

  • (Fixnum)


12259
12260
12261
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12259

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12266
12267
12268
12269
12270
12271
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12266

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @line = args[:line] if args.key?(:line)
end