Class: Google::Apis::DisplayvideoV3::ScriptError
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ScriptError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
An error message for a custom bidding script.
Instance Attribute Summary collapse
-
#column ⇒ Fixnum
The column number in the script where the error was thrown.
-
#error_code ⇒ String
The type of error.
-
#error_message ⇒ String
The detailed error message.
-
#line ⇒ Fixnum
The line number in the script where the error was thrown.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScriptError
constructor
A new instance of ScriptError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScriptError
Returns a new instance of ScriptError.
12261 12262 12263 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ Fixnum
The column number in the script where the error was thrown.
Corresponds to the JSON property column
12244 12245 12246 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12244 def column @column end |
#error_code ⇒ String
The type of error.
Corresponds to the JSON property errorCode
12249 12250 12251 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12249 def error_code @error_code end |
#error_message ⇒ String
The detailed error message.
Corresponds to the JSON property errorMessage
12254 12255 12256 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12254 def @error_message end |
#line ⇒ Fixnum
The line number in the script where the error was thrown.
Corresponds to the JSON property line
12259 12260 12261 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12259 def line @line end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12266 12267 12268 12269 12270 12271 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12266 def update!(**args) @column = args[:column] if args.key?(:column) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @line = args[:line] if args.key?(:line) end |