Class: Google::Apis::DisplayvideoV3::TargetingExpansionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control the optimized targeting settings of the line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingExpansionConfig

Returns a new instance of TargetingExpansionConfig.



12411
12412
12413
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_expansion_levelString

Output only. Magnitude of expansion for eligible first-party user lists under this ad group. This field only applies to YouTube and Partners line item and ad group resources. Corresponds to the JSON property audienceExpansionLevel

Returns:

  • (String)


12388
12389
12390
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12388

def audience_expansion_level
  @audience_expansion_level
end

#audience_expansion_seed_list_excludedBoolean Also known as: audience_expansion_seed_list_excluded?

Output only. Whether to exclude seed list for audience expansion. This field only applies to YouTube and Partners line item and ad group resources. Corresponds to the JSON property audienceExpansionSeedListExcluded

Returns:

  • (Boolean)


12394
12395
12396
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12394

def audience_expansion_seed_list_excluded
  @audience_expansion_seed_list_excluded
end

#enable_optimized_targetingBoolean Also known as: enable_optimized_targeting?

Required. Whether to enable Optimized Targeting for the line item. Optimized targeting is not compatible with all bid strategies. Attempting to set this field to true for a line item using the BiddingStrategy field fixed_bid or one of the following combinations of BiddingStrategy fields and BiddingStrategyPerformanceGoalType will result in an error: maximize_auto_spend_bid: * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CIVA * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_IVO_TEN * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_AV_VIEWED performance_goal_auto_bid: * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM Corresponds to the JSON property enableOptimizedTargeting

Returns:

  • (Boolean)


12408
12409
12410
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12408

def enable_optimized_targeting
  @enable_optimized_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12416
12417
12418
12419
12420
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12416

def update!(**args)
  @audience_expansion_level = args[:audience_expansion_level] if args.key?(:audience_expansion_level)
  @audience_expansion_seed_list_excluded = args[:audience_expansion_seed_list_excluded] if args.key?(:audience_expansion_seed_list_excluded)
  @enable_optimized_targeting = args[:enable_optimized_targeting] if args.key?(:enable_optimized_targeting)
end