Class: Google::Apis::DisplayvideoV3::TargetingOption
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::TargetingOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Represents a single targeting option, which is a targetable concept in DV360.
Instance Attribute Summary collapse
-
#age_range_details ⇒ Google::Apis::DisplayvideoV3::AgeRangeTargetingOptionDetails
Represents a targetable age range.
-
#app_category_details ⇒ Google::Apis::DisplayvideoV3::AppCategoryTargetingOptionDetails
Represents a targetable collection of apps.
-
#audio_content_type_details ⇒ Google::Apis::DisplayvideoV3::AudioContentTypeTargetingOptionDetails
Represents a targetable audio content type.
-
#authorized_seller_status_details ⇒ Google::Apis::DisplayvideoV3::AuthorizedSellerStatusTargetingOptionDetails
Represents a targetable authorized seller status.
-
#browser_details ⇒ Google::Apis::DisplayvideoV3::BrowserTargetingOptionDetails
Represents a targetable browser.
-
#business_chain_details ⇒ Google::Apis::DisplayvideoV3::BusinessChainTargetingOptionDetails
Represents a targetable business chain within a geo region.
-
#carrier_and_isp_details ⇒ Google::Apis::DisplayvideoV3::CarrierAndIspTargetingOptionDetails
Represents a targetable carrier or ISP.
-
#category_details ⇒ Google::Apis::DisplayvideoV3::CategoryTargetingOptionDetails
Represents a targetable category.
-
#content_duration_details ⇒ Google::Apis::DisplayvideoV3::ContentDurationTargetingOptionDetails
Represents a targetable content duration.
-
#content_genre_details ⇒ Google::Apis::DisplayvideoV3::ContentGenreTargetingOptionDetails
Represents a targetable content genre.
-
#content_instream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentInstreamPositionTargetingOptionDetails
Represents a targetable content instream position, which could be used by video and audio ads.
-
#content_outstream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentOutstreamPositionTargetingOptionDetails
Represents a targetable content outstream position, which could be used by display and video ads.
-
#content_stream_type_details ⇒ Google::Apis::DisplayvideoV3::ContentStreamTypeTargetingOptionDetails
Represents a targetable content stream type.
-
#content_theme_details ⇒ Google::Apis::DisplayvideoV3::ContentThemeTargetingOptionDetails
Represents a targetable content theme.
-
#device_make_model_details ⇒ Google::Apis::DisplayvideoV3::DeviceMakeModelTargetingOptionDetails
Represents a targetable device make and model.
-
#device_type_details ⇒ Google::Apis::DisplayvideoV3::DeviceTypeTargetingOptionDetails
Represents a targetable device type.
-
#digital_content_label_details ⇒ Google::Apis::DisplayvideoV3::DigitalContentLabelTargetingOptionDetails
Represents a targetable digital content label rating tier.
-
#environment_details ⇒ Google::Apis::DisplayvideoV3::EnvironmentTargetingOptionDetails
Represents a targetable environment.
-
#exchange_details ⇒ Google::Apis::DisplayvideoV3::ExchangeTargetingOptionDetails
Represents a targetable exchange.
-
#gender_details ⇒ Google::Apis::DisplayvideoV3::GenderTargetingOptionDetails
Represents a targetable gender.
-
#geo_region_details ⇒ Google::Apis::DisplayvideoV3::GeoRegionTargetingOptionDetails
Represents a targetable geographic region.
-
#household_income_details ⇒ Google::Apis::DisplayvideoV3::HouseholdIncomeTargetingOptionDetails
Represents a targetable household income.
-
#language_details ⇒ Google::Apis::DisplayvideoV3::LanguageTargetingOptionDetails
Represents a targetable language.
-
#name ⇒ String
Output only.
-
#native_content_position_details ⇒ Google::Apis::DisplayvideoV3::NativeContentPositionTargetingOptionDetails
Represents a targetable native content position.
-
#omid_details ⇒ Google::Apis::DisplayvideoV3::OmidTargetingOptionDetails
Represents a targetable Open Measurement enabled inventory type.
-
#on_screen_position_details ⇒ Google::Apis::DisplayvideoV3::OnScreenPositionTargetingOptionDetails
Represents a targetable on screen position, which could be used by display and video ads.
-
#operating_system_details ⇒ Google::Apis::DisplayvideoV3::OperatingSystemTargetingOptionDetails
Represents a targetable operating system.
-
#parental_status_details ⇒ Google::Apis::DisplayvideoV3::ParentalStatusTargetingOptionDetails
Represents a targetable parental status.
-
#poi_details ⇒ Google::Apis::DisplayvideoV3::PoiTargetingOptionDetails
Represents a targetable point of interest(POI).
-
#sensitive_category_details ⇒ Google::Apis::DisplayvideoV3::SensitiveCategoryTargetingOptionDetails
Represents a targetable sensitive category.
-
#sub_exchange_details ⇒ Google::Apis::DisplayvideoV3::SubExchangeTargetingOptionDetails
Represents a targetable sub-exchange.
-
#targeting_option_id ⇒ String
Output only.
-
#targeting_type ⇒ String
Output only.
-
#user_rewarded_content_details ⇒ Google::Apis::DisplayvideoV3::UserRewardedContentTargetingOptionDetails
Represents a targetable user rewarded content status for video ads only.
-
#video_player_size_details ⇒ Google::Apis::DisplayvideoV3::VideoPlayerSizeTargetingOptionDetails
Represents a targetable video player size.
-
#viewability_details ⇒ Google::Apis::DisplayvideoV3::ViewabilityTargetingOptionDetails
Represents a targetable viewability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetingOption
constructor
A new instance of TargetingOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetingOption
Returns a new instance of TargetingOption.
13016 13017 13018 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_range_details ⇒ Google::Apis::DisplayvideoV3::AgeRangeTargetingOptionDetails
Represents a targetable age range. This will be populated in the
age_range_details field when targeting_type is TARGETING_TYPE_AGE_RANGE.
Corresponds to the JSON property ageRangeDetails
12768 12769 12770 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12768 def age_range_details @age_range_details end |
#app_category_details ⇒ Google::Apis::DisplayvideoV3::AppCategoryTargetingOptionDetails
Represents a targetable collection of apps. A collection lets you target
dynamic groups of related apps that are maintained by the platform, for
example All Apps/Google Play/Games. This will be populated in the
app_category_details field when targeting_type is TARGETING_TYPE_APP_CATEGORY
.
Corresponds to the JSON property appCategoryDetails
12777 12778 12779 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12777 def app_category_details @app_category_details end |
#audio_content_type_details ⇒ Google::Apis::DisplayvideoV3::AudioContentTypeTargetingOptionDetails
Represents a targetable audio content type. This will be populated in the
audio_content_type_details field when targeting_type is
TARGETING_TYPE_AUDIO_CONTENT_TYPE.
Corresponds to the JSON property audioContentTypeDetails
12784 12785 12786 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12784 def audio_content_type_details @audio_content_type_details end |
#authorized_seller_status_details ⇒ Google::Apis::DisplayvideoV3::AuthorizedSellerStatusTargetingOptionDetails
Represents a targetable authorized seller status. This will be populated in
the authorized_seller_status_details field when targeting_type is
TARGETING_TYPE_AUTHORIZED_SELLER_STATUS.
Corresponds to the JSON property authorizedSellerStatusDetails
12791 12792 12793 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12791 def @authorized_seller_status_details end |
#browser_details ⇒ Google::Apis::DisplayvideoV3::BrowserTargetingOptionDetails
Represents a targetable browser. This will be populated in the browser_details
field when targeting_type is TARGETING_TYPE_BROWSER.
Corresponds to the JSON property browserDetails
12797 12798 12799 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12797 def browser_details @browser_details end |
#business_chain_details ⇒ Google::Apis::DisplayvideoV3::BusinessChainTargetingOptionDetails
Represents a targetable business chain within a geo region. This will be
populated in the business_chain_details field when targeting_type is
TARGETING_TYPE_BUSINESS_CHAIN.
Corresponds to the JSON property businessChainDetails
12804 12805 12806 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12804 def business_chain_details @business_chain_details end |
#carrier_and_isp_details ⇒ Google::Apis::DisplayvideoV3::CarrierAndIspTargetingOptionDetails
Represents a targetable carrier or ISP. This will be populated in the
carrier_and_isp_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_CARRIER_AND_ISP.
Corresponds to the JSON property carrierAndIspDetails
12811 12812 12813 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12811 def carrier_and_isp_details @carrier_and_isp_details end |
#category_details ⇒ Google::Apis::DisplayvideoV3::CategoryTargetingOptionDetails
Represents a targetable category. This will be populated in the
category_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_CATEGORY.
Corresponds to the JSON property categoryDetails
12818 12819 12820 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12818 def category_details @category_details end |
#content_duration_details ⇒ Google::Apis::DisplayvideoV3::ContentDurationTargetingOptionDetails
Represents a targetable content duration. This will be populated in the
content_duration_details field when targeting_type is
TARGETING_TYPE_CONTENT_DURATION.
Corresponds to the JSON property contentDurationDetails
12825 12826 12827 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12825 def content_duration_details @content_duration_details end |
#content_genre_details ⇒ Google::Apis::DisplayvideoV3::ContentGenreTargetingOptionDetails
Represents a targetable content genre. This will be populated in the
content_genre_details field when targeting_type is
TARGETING_TYPE_CONTENT_GENRE.
Corresponds to the JSON property contentGenreDetails
12832 12833 12834 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12832 def content_genre_details @content_genre_details end |
#content_instream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentInstreamPositionTargetingOptionDetails
Represents a targetable content instream position, which could be used by
video and audio ads. This will be populated in the
content_instream_position_details field when targeting_type is
TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Corresponds to the JSON property contentInstreamPositionDetails
12840 12841 12842 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12840 def content_instream_position_details @content_instream_position_details end |
#content_outstream_position_details ⇒ Google::Apis::DisplayvideoV3::ContentOutstreamPositionTargetingOptionDetails
Represents a targetable content outstream position, which could be used by
display and video ads. This will be populated in the
content_outstream_position_details field when targeting_type is
TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.
Corresponds to the JSON property contentOutstreamPositionDetails
12848 12849 12850 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12848 def content_outstream_position_details @content_outstream_position_details end |
#content_stream_type_details ⇒ Google::Apis::DisplayvideoV3::ContentStreamTypeTargetingOptionDetails
Represents a targetable content stream type. This will be populated in the
content_stream_type_details field when targeting_type is
TARGETING_TYPE_CONTENT_STREAM_TYPE.
Corresponds to the JSON property contentStreamTypeDetails
12855 12856 12857 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12855 def content_stream_type_details @content_stream_type_details end |
#content_theme_details ⇒ Google::Apis::DisplayvideoV3::ContentThemeTargetingOptionDetails
Represents a targetable content theme. This will be populated in the
content_theme_details field of the TargetingOption when targeting_type is
TARGETING_TYPE_CONTENT_THEME_EXCLUSION.
Corresponds to the JSON property contentThemeDetails
12862 12863 12864 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12862 def content_theme_details @content_theme_details end |
#device_make_model_details ⇒ Google::Apis::DisplayvideoV3::DeviceMakeModelTargetingOptionDetails
Represents a targetable device make and model. This will be populated in the
device_make_model_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_DEVICE_MAKE_MODEL.
Corresponds to the JSON property deviceMakeModelDetails
12869 12870 12871 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12869 def device_make_model_details @device_make_model_details end |
#device_type_details ⇒ Google::Apis::DisplayvideoV3::DeviceTypeTargetingOptionDetails
Represents a targetable device type. This will be populated in the
device_type_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_DEVICE_TYPE.
Corresponds to the JSON property deviceTypeDetails
12876 12877 12878 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12876 def device_type_details @device_type_details end |
#digital_content_label_details ⇒ Google::Apis::DisplayvideoV3::DigitalContentLabelTargetingOptionDetails
Represents a targetable digital content label rating tier. This will be
populated in the digital_content_label_details field of the TargetingOption
when targeting_type is TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION.
Corresponds to the JSON property digitalContentLabelDetails
12883 12884 12885 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12883 def digital_content_label_details @digital_content_label_details end |
#environment_details ⇒ Google::Apis::DisplayvideoV3::EnvironmentTargetingOptionDetails
Represents a targetable environment. This will be populated in the
environment_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_ENVIRONMENT.
Corresponds to the JSON property environmentDetails
12890 12891 12892 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12890 def environment_details @environment_details end |
#exchange_details ⇒ Google::Apis::DisplayvideoV3::ExchangeTargetingOptionDetails
Represents a targetable exchange. This will be populated in the
exchange_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_EXCHANGE.
Corresponds to the JSON property exchangeDetails
12897 12898 12899 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12897 def exchange_details @exchange_details end |
#gender_details ⇒ Google::Apis::DisplayvideoV3::GenderTargetingOptionDetails
Represents a targetable gender. This will be populated in the gender_details
field of a TargetingOption when targeting_type is TARGETING_TYPE_GENDER.
Corresponds to the JSON property genderDetails
12903 12904 12905 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12903 def gender_details @gender_details end |
#geo_region_details ⇒ Google::Apis::DisplayvideoV3::GeoRegionTargetingOptionDetails
Represents a targetable geographic region. This will be populated in the
geo_region_details field when targeting_type is TARGETING_TYPE_GEO_REGION.
Corresponds to the JSON property geoRegionDetails
12909 12910 12911 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12909 def geo_region_details @geo_region_details end |
#household_income_details ⇒ Google::Apis::DisplayvideoV3::HouseholdIncomeTargetingOptionDetails
Represents a targetable household income. This will be populated in the
household_income_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_HOUSEHOLD_INCOME.
Corresponds to the JSON property householdIncomeDetails
12916 12917 12918 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12916 def household_income_details @household_income_details end |
#language_details ⇒ Google::Apis::DisplayvideoV3::LanguageTargetingOptionDetails
Represents a targetable language. This will be populated in the
language_details field when targeting_type is TARGETING_TYPE_LANGUAGE.
Corresponds to the JSON property languageDetails
12922 12923 12924 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12922 def language_details @language_details end |
#name ⇒ String
Output only. The resource name for this targeting option.
Corresponds to the JSON property name
12927 12928 12929 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12927 def name @name end |
#native_content_position_details ⇒ Google::Apis::DisplayvideoV3::NativeContentPositionTargetingOptionDetails
Represents a targetable native content position. This will be populated in the
native_content_position_details field when targeting_type is
TARGETING_TYPE_NATIVE_CONTENT_POSITION.
Corresponds to the JSON property nativeContentPositionDetails
12934 12935 12936 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12934 def native_content_position_details @native_content_position_details end |
#omid_details ⇒ Google::Apis::DisplayvideoV3::OmidTargetingOptionDetails
Represents a targetable Open Measurement enabled inventory type. This will be
populated in the omid_details field when targeting_type is
TARGETING_TYPE_OMID.
Corresponds to the JSON property omidDetails
12941 12942 12943 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12941 def omid_details @omid_details end |
#on_screen_position_details ⇒ Google::Apis::DisplayvideoV3::OnScreenPositionTargetingOptionDetails
Represents a targetable on screen position, which could be used by display and
video ads. This will be populated in the on_screen_position_details field when
targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION.
Corresponds to the JSON property onScreenPositionDetails
12948 12949 12950 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12948 def on_screen_position_details @on_screen_position_details end |
#operating_system_details ⇒ Google::Apis::DisplayvideoV3::OperatingSystemTargetingOptionDetails
Represents a targetable operating system. This will be populated in the
operating_system_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_OPERATING_SYSTEM.
Corresponds to the JSON property operatingSystemDetails
12955 12956 12957 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12955 def @operating_system_details end |
#parental_status_details ⇒ Google::Apis::DisplayvideoV3::ParentalStatusTargetingOptionDetails
Represents a targetable parental status. This will be populated in the
parental_status_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_PARENTAL_STATUS.
Corresponds to the JSON property parentalStatusDetails
12962 12963 12964 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12962 def parental_status_details @parental_status_details end |
#poi_details ⇒ Google::Apis::DisplayvideoV3::PoiTargetingOptionDetails
Represents a targetable point of interest(POI). This will be populated in the
poi_details field when targeting_type is TARGETING_TYPE_POI.
Corresponds to the JSON property poiDetails
12968 12969 12970 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12968 def poi_details @poi_details end |
#sensitive_category_details ⇒ Google::Apis::DisplayvideoV3::SensitiveCategoryTargetingOptionDetails
Represents a targetable sensitive category. This will be populated in the
sensitive_category_details field of the TargetingOption when targeting_type is
TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION.
Corresponds to the JSON property sensitiveCategoryDetails
12975 12976 12977 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12975 def sensitive_category_details @sensitive_category_details end |
#sub_exchange_details ⇒ Google::Apis::DisplayvideoV3::SubExchangeTargetingOptionDetails
Represents a targetable sub-exchange. This will be populated in the
sub_exchange_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_SUB_EXCHANGE.
Corresponds to the JSON property subExchangeDetails
12982 12983 12984 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12982 def sub_exchange_details @sub_exchange_details end |
#targeting_option_id ⇒ String
Output only. A unique identifier for this targeting option. The tuple
targeting_type`, `targeting_option_id will be unique.
Corresponds to the JSON property targetingOptionId
12988 12989 12990 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12988 def targeting_option_id @targeting_option_id end |
#targeting_type ⇒ String
Output only. The type of this targeting option.
Corresponds to the JSON property targetingType
12993 12994 12995 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 12993 def targeting_type @targeting_type end |
#user_rewarded_content_details ⇒ Google::Apis::DisplayvideoV3::UserRewardedContentTargetingOptionDetails
Represents a targetable user rewarded content status for video ads only. This
will be populated in the user_rewarded_content_details field when
targeting_type is TARGETING_TYPE_USER_REWARDED_CONTENT.
Corresponds to the JSON property userRewardedContentDetails
13000 13001 13002 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13000 def user_rewarded_content_details @user_rewarded_content_details end |
#video_player_size_details ⇒ Google::Apis::DisplayvideoV3::VideoPlayerSizeTargetingOptionDetails
Represents a targetable video player size. This will be populated in the
video_player_size_details field when targeting_type is
TARGETING_TYPE_VIDEO_PLAYER_SIZE.
Corresponds to the JSON property videoPlayerSizeDetails
13007 13008 13009 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13007 def video_player_size_details @video_player_size_details end |
#viewability_details ⇒ Google::Apis::DisplayvideoV3::ViewabilityTargetingOptionDetails
Represents a targetable viewability. This will be populated in the
viewability_details field of a TargetingOption when targeting_type is
TARGETING_TYPE_VIEWABILITY.
Corresponds to the JSON property viewabilityDetails
13014 13015 13016 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13014 def viewability_details @viewability_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13021 13022 13023 13024 13025 13026 13027 13028 13029 13030 13031 13032 13033 13034 13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 13049 13050 13051 13052 13053 13054 13055 13056 13057 13058 13059 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13021 def update!(**args) @age_range_details = args[:age_range_details] if args.key?(:age_range_details) @app_category_details = args[:app_category_details] if args.key?(:app_category_details) @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details) @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details) @browser_details = args[:browser_details] if args.key?(:browser_details) @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details) @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details) @category_details = args[:category_details] if args.key?(:category_details) @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details) @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details) @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details) @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details) @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details) @content_theme_details = args[:content_theme_details] if args.key?(:content_theme_details) @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details) @device_type_details = args[:device_type_details] if args.key?(:device_type_details) @digital_content_label_details = args[:digital_content_label_details] if args.key?(:digital_content_label_details) @environment_details = args[:environment_details] if args.key?(:environment_details) @exchange_details = args[:exchange_details] if args.key?(:exchange_details) @gender_details = args[:gender_details] if args.key?(:gender_details) @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details) @household_income_details = args[:household_income_details] if args.key?(:household_income_details) @language_details = args[:language_details] if args.key?(:language_details) @name = args[:name] if args.key?(:name) @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details) @omid_details = args[:omid_details] if args.key?(:omid_details) @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details) @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details) @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details) @poi_details = args[:poi_details] if args.key?(:poi_details) @sensitive_category_details = args[:sensitive_category_details] if args.key?(:sensitive_category_details) @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details) @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id) @targeting_type = args[:targeting_type] if args.key?(:targeting_type) @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details) @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details) @viewability_details = args[:viewability_details] if args.key?(:viewability_details) end |