Class: Google::Apis::DisplayvideoV3::ThirdPartyUrl
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::ThirdPartyUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Tracking URLs from third parties to track interactions with an audio or a video creative.
Instance Attribute Summary collapse
-
#type ⇒ String
Optional.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ThirdPartyUrl
constructor
A new instance of ThirdPartyUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ThirdPartyUrl
Returns a new instance of ThirdPartyUrl.
13152 13153 13154 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#type ⇒ String
Optional. The type of interaction needs to be tracked by the tracking URL
Corresponds to the JSON property type
13143 13144 13145 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13143 def type @type end |
#url ⇒ String
Optional. Tracking URL used to track the interaction. Provide a URL with
optional path or query string, beginning with https:. For example, https://
www.example.com/path
Corresponds to the JSON property url
13150 13151 13152 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13150 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13157 13158 13159 13160 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13157 def update!(**args) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |