Class: Google::Apis::DisplayvideoV3::Transcode
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::Transcode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Represents information about the transcoded audio or video file.
Instance Attribute Summary collapse
-
#audio_bit_rate_kbps ⇒ Fixnum
Optional.
-
#audio_sample_rate_hz ⇒ Fixnum
Optional.
-
#bit_rate_kbps ⇒ Fixnum
Optional.
-
#dimensions ⇒ Google::Apis::DisplayvideoV3::Dimensions
Dimensions.
-
#file_size_bytes ⇒ Fixnum
Optional.
-
#frame_rate ⇒ Float
Optional.
-
#mime_type ⇒ String
Optional.
-
#name ⇒ String
Optional.
-
#transcoded ⇒ Boolean
(also: #transcoded?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Transcode
constructor
A new instance of Transcode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Transcode
Returns a new instance of Transcode.
13333 13334 13335 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_bit_rate_kbps ⇒ Fixnum
Optional. The bit rate for the audio stream of the transcoded video, or the
bit rate for the transcoded audio, in kilobits per second.
Corresponds to the JSON property audioBitRateKbps
13288 13289 13290 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13288 def audio_bit_rate_kbps @audio_bit_rate_kbps end |
#audio_sample_rate_hz ⇒ Fixnum
Optional. The sample rate for the audio stream of the transcoded video, or the
sample rate for the transcoded audio, in hertz.
Corresponds to the JSON property audioSampleRateHz
13294 13295 13296 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13294 def audio_sample_rate_hz @audio_sample_rate_hz end |
#bit_rate_kbps ⇒ Fixnum
Optional. The transcoding bit rate of the transcoded video, in kilobits per
second.
Corresponds to the JSON property bitRateKbps
13300 13301 13302 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13300 def bit_rate_kbps @bit_rate_kbps end |
#dimensions ⇒ Google::Apis::DisplayvideoV3::Dimensions
Dimensions.
Corresponds to the JSON property dimensions
13305 13306 13307 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13305 def dimensions @dimensions end |
#file_size_bytes ⇒ Fixnum
Optional. The size of the transcoded file, in bytes.
Corresponds to the JSON property fileSizeBytes
13310 13311 13312 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13310 def file_size_bytes @file_size_bytes end |
#frame_rate ⇒ Float
Optional. The frame rate of the transcoded video, in frames per second.
Corresponds to the JSON property frameRate
13315 13316 13317 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13315 def frame_rate @frame_rate end |
#mime_type ⇒ String
Optional. The MIME type of the transcoded file.
Corresponds to the JSON property mimeType
13320 13321 13322 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13320 def mime_type @mime_type end |
#name ⇒ String
Optional. The name of the transcoded file.
Corresponds to the JSON property name
13325 13326 13327 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13325 def name @name end |
#transcoded ⇒ Boolean Also known as: transcoded?
Optional. Indicates if the transcoding was successful.
Corresponds to the JSON property transcoded
13330 13331 13332 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13330 def transcoded @transcoded end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13338 13339 13340 13341 13342 13343 13344 13345 13346 13347 13348 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13338 def update!(**args) @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps) @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz) @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps) @dimensions = args[:dimensions] if args.key?(:dimensions) @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes) @frame_rate = args[:frame_rate] if args.key?(:frame_rate) @mime_type = args[:mime_type] if args.key?(:mime_type) @name = args[:name] if args.key?(:name) @transcoded = args[:transcoded] if args.key?(:transcoded) end |