Class: Google::Apis::DisplayvideoV3::VideoAdSequenceStep
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::VideoAdSequenceStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
The detail of a single step in a VideoAdSequence.
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
The ID of the corresponding ad group of the step.
-
#interaction_type ⇒ String
The interaction on the previous step that will lead the viewer to this step.
-
#previous_step_id ⇒ Fixnum
The ID of the previous step.
-
#step_id ⇒ Fixnum
The ID of the step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoAdSequenceStep
constructor
A new instance of VideoAdSequenceStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoAdSequenceStep
Returns a new instance of VideoAdSequenceStep.
13599 13600 13601 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
The ID of the corresponding ad group of the step.
Corresponds to the JSON property adGroupId
13581 13582 13583 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13581 def ad_group_id @ad_group_id end |
#interaction_type ⇒ String
The interaction on the previous step that will lead the viewer to this step.
The first step does not have interaction_type.
Corresponds to the JSON property interactionType
13587 13588 13589 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13587 def interaction_type @interaction_type end |
#previous_step_id ⇒ Fixnum
The ID of the previous step. The first step does not have previous step.
Corresponds to the JSON property previousStepId
13592 13593 13594 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13592 def previous_step_id @previous_step_id end |
#step_id ⇒ Fixnum
The ID of the step.
Corresponds to the JSON property stepId
13597 13598 13599 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13597 def step_id @step_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13604 13605 13606 13607 13608 13609 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13604 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @previous_step_id = args[:previous_step_id] if args.key?(:previous_step_id) @step_id = args[:step_id] if args.key?(:step_id) end |