Class: Google::Apis::DisplayvideoV3::VideoPerformanceAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a video performance ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPerformanceAd

Returns a new instance of VideoPerformanceAd.



13719
13720
13721
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelsArray<String>

The list of text assets shown on the call-to-action button. Corresponds to the JSON property actionButtonLabels

Returns:

  • (Array<String>)


13662
13663
13664
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13662

def action_button_labels
  @action_button_labels
end

#companion_bannersArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of companion banners used by this ad. Corresponds to the JSON property companionBanners



13667
13668
13669
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13667

def companion_banners
  @companion_banners
end

#custom_parametersHash<String,String>

The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


13672
13673
13674
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13672

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

The list of descriptions shown on the call-to-action banner. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


13677
13678
13679
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13677

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


13682
13683
13684
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13682

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


13687
13688
13689
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13687

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#domainString

The domain of the display URL. Corresponds to the JSON property domain

Returns:

  • (String)


13692
13693
13694
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13692

def domain
  @domain
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


13697
13698
13699
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13697

def final_url
  @final_url
end

#headlinesArray<String>

The list of headlines shown on the call-to-action banner. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


13702
13703
13704
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13702

def headlines
  @headlines
end

#long_headlinesArray<String>

The list of long headlines shown on the call-to-action banner. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


13707
13708
13709
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13707

def long_headlines
  @long_headlines
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


13712
13713
13714
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13712

def tracking_url
  @tracking_url
end

#videosArray<Google::Apis::DisplayvideoV3::YoutubeVideoDetails>

The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



13717
13718
13719
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13717

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13724
13725
13726
13727
13728
13729
13730
13731
13732
13733
13734
13735
13736
13737
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13724

def update!(**args)
  @action_button_labels = args[:action_button_labels] if args.key?(:action_button_labels)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @domain = args[:domain] if args.key?(:domain)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headlines = args[:headlines] if args.key?(:headlines)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end