Class: Google::Apis::DisplayvideoV3::VideoPerformanceAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Details for a video performance ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPerformanceAd

Returns a new instance of VideoPerformanceAd.



13403
13404
13405
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelsArray<String>

The list of text assets shown on the call-to-action button. Corresponds to the JSON property actionButtonLabels

Returns:

  • (Array<String>)


13346
13347
13348
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13346

def action_button_labels
  @action_button_labels
end

#companion_bannersArray<Google::Apis::DisplayvideoV3::ImageAsset>

The list of companion banners used by this ad. Corresponds to the JSON property companionBanners



13351
13352
13353
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13351

def companion_banners
  @companion_banners
end

#custom_parametersHash<String,String>

The custom parameters to pass custom values to tracking URL template. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


13356
13357
13358
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13356

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

The list of descriptions shown on the call-to-action banner. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


13361
13362
13363
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13361

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


13366
13367
13368
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13366

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


13371
13372
13373
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13371

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#domainString

The domain of the display URL. Corresponds to the JSON property domain

Returns:

  • (String)


13376
13377
13378
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13376

def domain
  @domain
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


13381
13382
13383
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13381

def final_url
  @final_url
end

#headlinesArray<String>

The list of headlines shown on the call-to-action banner. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


13386
13387
13388
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13386

def headlines
  @headlines
end

#long_headlinesArray<String>

The list of lone headlines shown on the call-to-action banner. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


13391
13392
13393
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13391

def long_headlines
  @long_headlines
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


13396
13397
13398
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13396

def tracking_url
  @tracking_url
end

#videosArray<Google::Apis::DisplayvideoV3::YoutubeVideoDetails>

The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



13401
13402
13403
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13401

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13408
13409
13410
13411
13412
13413
13414
13415
13416
13417
13418
13419
13420
13421
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13408

def update!(**args)
  @action_button_labels = args[:action_button_labels] if args.key?(:action_button_labels)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @domain = args[:domain] if args.key?(:domain)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headlines = args[:headlines] if args.key?(:headlines)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end