Class: Google::Apis::DisplayvideoV3::YoutubeAndPartnersInventorySourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings that control what YouTube related inventories the YouTube and Partners line item will target.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAndPartnersInventorySourceConfig

Returns a new instance of YoutubeAndPartnersInventorySourceConfig.



13586
13587
13588
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_google_tvBoolean Also known as: include_google_tv?

Optional. Whether to target inventory in video apps available with Google TV. Corresponds to the JSON property includeGoogleTv

Returns:

  • (Boolean)


13569
13570
13571
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13569

def include_google_tv
  @include_google_tv
end

#include_youtubeBoolean Also known as: include_youtube?

Optional. Whether to target inventory on YouTube. This includes both search, channels and videos. Corresponds to the JSON property includeYoutube

Returns:

  • (Boolean)


13576
13577
13578
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13576

def include_youtube
  @include_youtube
end

#include_youtube_video_partnersBoolean Also known as: include_youtube_video_partners?

Whether to target inventory on a collection of partner sites and apps that follow the same brand safety standards as YouTube. Corresponds to the JSON property includeYoutubeVideoPartners

Returns:

  • (Boolean)


13583
13584
13585
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13583

def include_youtube_video_partners
  @include_youtube_video_partners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13591
13592
13593
13594
13595
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13591

def update!(**args)
  @include_google_tv = args[:include_google_tv] if args.key?(:include_google_tv)
  @include_youtube = args[:include_youtube] if args.key?(:include_youtube)
  @include_youtube_video_partners = args[:include_youtube_video_partners] if args.key?(:include_youtube_video_partners)
end