Class: Google::Apis::DisplayvideoV3::YoutubeAndPartnersSettings
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV3::YoutubeAndPartnersSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb
Overview
Settings for YouTube and Partners line items.
Instance Attribute Summary collapse
-
#content_category ⇒ String
Output only.
-
#effective_content_category ⇒ String
Output only.
-
#inventory_source_settings ⇒ Google::Apis::DisplayvideoV3::YoutubeAndPartnersInventorySourceConfig
Settings that control what YouTube related inventories the YouTube and Partners line item will target.
-
#lead_form_id ⇒ Fixnum
Optional.
-
#linked_merchant_id ⇒ Fixnum
Optional.
-
#related_video_ids ⇒ Array<String>
Optional.
-
#target_frequency ⇒ Google::Apis::DisplayvideoV3::TargetFrequency
Setting that controls the average number of times the ads will show to the same person over a certain period of time.
-
#third_party_measurement_configs ⇒ Google::Apis::DisplayvideoV3::ThirdPartyMeasurementConfigs
Settings that control what third-party vendors are measuring specific line item metrics.
-
#video_ad_inventory_control ⇒ Google::Apis::DisplayvideoV3::VideoAdInventoryControl
The video ad inventory control used in certain YouTube line item types.
-
#video_ad_sequence_settings ⇒ Google::Apis::DisplayvideoV3::VideoAdSequenceSettings
Settings related to VideoAdSequence.
-
#view_frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAndPartnersSettings
constructor
A new instance of YoutubeAndPartnersSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAndPartnersSettings
Returns a new instance of YoutubeAndPartnersSettings.
13982 13983 13984 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_category ⇒ String
Output only. The kind of content on which the YouTube and Partners ads will be
shown. Warning: This field will be removed in the near future. Use
effective_content_category instead.
Corresponds to the JSON property contentCategory
13921 13922 13923 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13921 def content_category @content_category end |
#effective_content_category ⇒ String
Output only. The content category which takes effect when serving the line
item. When content category is set in both line item and advertiser, the
stricter one will take effect when serving the line item. New line items will
only inherit the advertiser level setting.
Corresponds to the JSON property effectiveContentCategory
13929 13930 13931 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13929 def effective_content_category @effective_content_category end |
#inventory_source_settings ⇒ Google::Apis::DisplayvideoV3::YoutubeAndPartnersInventorySourceConfig
Settings that control what YouTube related inventories the YouTube and
Partners line item will target.
Corresponds to the JSON property inventorySourceSettings
13935 13936 13937 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13935 def inventory_source_settings @inventory_source_settings end |
#lead_form_id ⇒ Fixnum
Optional. The ID of the form to generate leads.
Corresponds to the JSON property leadFormId
13940 13941 13942 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13940 def lead_form_id @lead_form_id end |
#linked_merchant_id ⇒ Fixnum
Optional. The ID of the Merchant Center account used to provide a product feed.
This Merchant Center account must already be linked to the advertiser.
Corresponds to the JSON property linkedMerchantId
13946 13947 13948 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13946 def linked_merchant_id @linked_merchant_id end |
#related_video_ids ⇒ Array<String>
Optional. The IDs of the videos appear below the primary video ad when the ad
is playing in the YouTube app on mobile devices.
Corresponds to the JSON property relatedVideoIds
13952 13953 13954 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13952 def @related_video_ids end |
#target_frequency ⇒ Google::Apis::DisplayvideoV3::TargetFrequency
Setting that controls the average number of times the ads will show to the
same person over a certain period of time.
Corresponds to the JSON property targetFrequency
13958 13959 13960 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13958 def target_frequency @target_frequency end |
#third_party_measurement_configs ⇒ Google::Apis::DisplayvideoV3::ThirdPartyMeasurementConfigs
Settings that control what third-party vendors are measuring specific line
item metrics.
Corresponds to the JSON property thirdPartyMeasurementConfigs
13964 13965 13966 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13964 def third_party_measurement_configs @third_party_measurement_configs end |
#video_ad_inventory_control ⇒ Google::Apis::DisplayvideoV3::VideoAdInventoryControl
The video ad inventory control used in certain YouTube line item types.
Corresponds to the JSON property videoAdInventoryControl
13969 13970 13971 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13969 def video_ad_inventory_control @video_ad_inventory_control end |
#video_ad_sequence_settings ⇒ Google::Apis::DisplayvideoV3::VideoAdSequenceSettings
Settings related to VideoAdSequence.
Corresponds to the JSON property videoAdSequenceSettings
13974 13975 13976 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13974 def video_ad_sequence_settings @video_ad_sequence_settings end |
#view_frequency_cap ⇒ Google::Apis::DisplayvideoV3::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property viewFrequencyCap
13980 13981 13982 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13980 def view_frequency_cap @view_frequency_cap end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13987 13988 13989 13990 13991 13992 13993 13994 13995 13996 13997 13998 13999 |
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13987 def update!(**args) @content_category = args[:content_category] if args.key?(:content_category) @effective_content_category = args[:effective_content_category] if args.key?(:effective_content_category) @inventory_source_settings = args[:inventory_source_settings] if args.key?(:inventory_source_settings) @lead_form_id = args[:lead_form_id] if args.key?(:lead_form_id) @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id) @related_video_ids = args[:related_video_ids] if args.key?(:related_video_ids) @target_frequency = args[:target_frequency] if args.key?(:target_frequency) @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs) @video_ad_inventory_control = args[:video_ad_inventory_control] if args.key?(:video_ad_inventory_control) @video_ad_sequence_settings = args[:video_ad_sequence_settings] if args.key?(:video_ad_sequence_settings) @view_frequency_cap = args[:view_frequency_cap] if args.key?(:view_frequency_cap) end |