Class: Google::Apis::DisplayvideoV3::YoutubeAndPartnersSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v3/classes.rb,
lib/google/apis/displayvideo_v3/representations.rb,
lib/google/apis/displayvideo_v3/representations.rb

Overview

Settings for YouTube and Partners line items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAndPartnersSettings

Returns a new instance of YoutubeAndPartnersSettings.



13668
13669
13670
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_categoryString

Output only. The kind of content on which the YouTube and Partners ads will be shown. Warning: This field will be removed in the near future. Use effective_content_category instead. Corresponds to the JSON property contentCategory

Returns:

  • (String)


13607
13608
13609
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13607

def 
  @content_category
end

#effective_content_categoryString

Output only. The content category which takes effect when serving the line item. When content category is set in both line item and advertiser, the stricter one will take effect when serving the line item. New line items will only inherit the advertiser level setting. Corresponds to the JSON property effectiveContentCategory

Returns:

  • (String)


13615
13616
13617
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13615

def 
  @effective_content_category
end

#inventory_source_settingsGoogle::Apis::DisplayvideoV3::YoutubeAndPartnersInventorySourceConfig

Settings that control what YouTube related inventories the YouTube and Partners line item will target. Corresponds to the JSON property inventorySourceSettings



13621
13622
13623
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13621

def inventory_source_settings
  @inventory_source_settings
end

#lead_form_idFixnum

Optional. The ID of the form to generate leads. Corresponds to the JSON property leadFormId

Returns:

  • (Fixnum)


13626
13627
13628
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13626

def lead_form_id
  @lead_form_id
end

#linked_merchant_idFixnum

Optional. The ID of the merchant which is linked to the line item for product feed. Corresponds to the JSON property linkedMerchantId

Returns:

  • (Fixnum)


13632
13633
13634
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13632

def linked_merchant_id
  @linked_merchant_id
end

Optional. The IDs of the videos appear below the primary video ad when the ad is playing in the YouTube app on mobile devices. Corresponds to the JSON property relatedVideoIds

Returns:

  • (Array<String>)


13638
13639
13640
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13638

def related_video_ids
  @related_video_ids
end

#target_frequencyGoogle::Apis::DisplayvideoV3::TargetFrequency

Setting that controls the average number of times the ads will show to the same person over a certain period of time. Corresponds to the JSON property targetFrequency



13644
13645
13646
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13644

def target_frequency
  @target_frequency
end

#third_party_measurement_configsGoogle::Apis::DisplayvideoV3::ThirdPartyMeasurementConfigs

Settings that control what third-party vendors are measuring specific line item metrics. Corresponds to the JSON property thirdPartyMeasurementConfigs



13650
13651
13652
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13650

def third_party_measurement_configs
  @third_party_measurement_configs
end

#video_ad_inventory_controlGoogle::Apis::DisplayvideoV3::VideoAdInventoryControl

The video ad inventory control used in certain YouTube line item types. Corresponds to the JSON property videoAdInventoryControl



13655
13656
13657
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13655

def video_ad_inventory_control
  @video_ad_inventory_control
end

#video_ad_sequence_settingsGoogle::Apis::DisplayvideoV3::VideoAdSequenceSettings

Settings related to VideoAdSequence. Corresponds to the JSON property videoAdSequenceSettings



13660
13661
13662
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13660

def video_ad_sequence_settings
  @video_ad_sequence_settings
end

#view_frequency_capGoogle::Apis::DisplayvideoV3::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property viewFrequencyCap



13666
13667
13668
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13666

def view_frequency_cap
  @view_frequency_cap
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13673
13674
13675
13676
13677
13678
13679
13680
13681
13682
13683
13684
13685
# File 'lib/google/apis/displayvideo_v3/classes.rb', line 13673

def update!(**args)
  @content_category = args[:content_category] if args.key?(:content_category)
  @effective_content_category = args[:effective_content_category] if args.key?(:effective_content_category)
  @inventory_source_settings = args[:inventory_source_settings] if args.key?(:inventory_source_settings)
  @lead_form_id = args[:lead_form_id] if args.key?(:lead_form_id)
  @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id)
  @related_video_ids = args[:related_video_ids] if args.key?(:related_video_ids)
  @target_frequency = args[:target_frequency] if args.key?(:target_frequency)
  @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs)
  @video_ad_inventory_control = args[:video_ad_inventory_control] if args.key?(:video_ad_inventory_control)
  @video_ad_sequence_settings = args[:video_ad_sequence_settings] if args.key?(:video_ad_sequence_settings)
  @view_frequency_cap = args[:view_frequency_cap] if args.key?(:view_frequency_cap)
end